/**
  ******************************************************************************
  * @file    bsp_spi_flash.c
  * @author  ӦÿŶ
  * @version 
  * @date    
  * @brief   This file provides firmware functions to manage the following 
  *          functionalities of the Analog to 7SEG LED Display peripheral:
  *           + Initialization and Configuration
  *           + 
  *           + Interrupts and flags management
  *
  *  @verbatim
================================================================================
                      ##### How to use this driver #####
================================================================================
    [..]


  *  @endverbatim
  *
  ******************************************************************************
  * @attention
  *
  * 
  *
  * 
  * 
  * 
  *
  *    
  *
  * 
  * 
  * 
  * 
  * 
  *
  ******************************************************************************
  */
/* Includes ------------------------------------------------------------------*/
#include "bsp_spi_flash.h"

/** @addtogroup PT32F0xx_StdPeriph_Driver
  * @{
  */

/** @defgroup bsp_spi_flash 
  * @brief SPI FLASH driver modules
  * @{
  */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
static __IO uint32_t  SPITimeout = SPIT_LONG_TIMEOUT;    
/* Private function prototypes -----------------------------------------------*/
static uint16_t SPI_TIMEOUT_UserCallback(uint8_t errorCode);
/* Private functions ---------------------------------------------------------*/
/**
  * @brief  SPI_FLASHʼ
  * @param  
  * @retval 
  */
void SPI_FLASH_Init(void)
{
  SPI_InitTypeDef  SPI_InitStructure;
  GPIO_InitTypeDef GPIO_InitStructure;
  /* SPIܽŵĸù */
//  GPIO_PinAFConfig(FLASH_SPI_CS_PORT, GPIO_PinSource4, GPIO_AF_0);
//  GPIO_PinAFConfig(FLASH_SPI_SCK_PORT, GPIO_PinSource5, GPIO_AF_0);
//  GPIO_PinAFConfig(FLASH_SPI_MISO_PORT, GPIO_PinSource6, GPIO_AF_0);
//  GPIO_PinAFConfig(FLASH_SPI_MOSI_PORT, GPIO_PinSource7, GPIO_AF_0);
    CMSDK_PA->ALTFUNCSET |= (1<<16);	  // spi1_cs   altfunc0
    CMSDK_PA->ALTFUNCSET |= (1<<20);	// spi1_sck  altfunc0
    CMSDK_PA->ALTFUNCSET |= (1<<24);	// spi1_miso altfunc0
    CMSDK_PA->ALTFUNCSET |= (1<<28);	// spi1_mosi altfunc0	
  /* SPI ģʽ */
  // FLASHоƬ ֧SPIģʽ0ģʽ3ݴCPOL CPHA
  SPI_InitStructure.SPI_Mode = SPI_Mode_Master;
  SPI_InitStructure.SPI_DataSize = SPI_DataSize_8b;
  SPI_InitStructure.SPI_CPOL = SPI_CPOL_Low;
  SPI_InitStructure.SPI_CPHA = SPI_CPHA_1Edge;
  SPI_InitStructure.SPI_NSS = SPI_NSS_Soft;
  SPI_InitStructure.SPI_BaudRatePrescaler = 2;
  SPI_InitStructure.SPI_BaudRatePostPrescaler = 0;
  SPI_Init(FLASH_SPIx , &SPI_InitStructure);

  /* ʹ SPI  */
  SPI_Cmd(FLASH_SPIx , ENABLE);	
}

 /**
  * @brief  FLASH
  * @param  SectorAddrҪַ
  * @retval 
  */
void SPI_FLASH_SectorErase(uint32_t SectorAddr)
{
  /* FLASHдʹ */
  SPI_FLASH_WriteEnable();
  SPI_FLASH_WaitForWriteEnd();
  /*  */
  /* ѡFLASH: CS͵ƽ */
  SPI_FLASH_CS_LOW();
  /* ָ*/
  SPI_FLASH_SendByte(W25X_SectorErase);
  /*Ͳַĸλ*/
  SPI_FLASH_SendByte((SectorAddr & 0xFF0000) >> 16);
  /* Ͳַλ */
  SPI_FLASH_SendByte((SectorAddr & 0xFF00) >> 8);
  /* Ͳַĵλ */
  SPI_FLASH_SendByte(SectorAddr & 0xFF);
  /* ֹͣź FLASH: CS ߵƽ */
  SPI_FLASH_CS_HIGH();
  /* ȴ*/
  SPI_FLASH_WaitForWriteEnd();
}

 /**
  * @brief  FLASHƬ
  * @param  
  * @retval 
  */
void SPI_FLASH_BulkErase(void)
{
  /* FLASHдʹ */
  SPI_FLASH_WriteEnable();

  /*  Erase */
  /* ѡFLASH: CS͵ƽ */
  SPI_FLASH_CS_LOW();
  /* ָ*/
  SPI_FLASH_SendByte(W25X_ChipErase);
  /* ֹͣź FLASH: CS ߵƽ */
  SPI_FLASH_CS_HIGH();

  /* ȴ*/
  SPI_FLASH_WaitForWriteEnd();
}

 /**
  * @brief  FLASHҳдݣñдǰҪȲ
  * @param	pBufferҪдݵָ
  * @param WriteAddrдַ
  * @param  NumByteToWriteдݳȣСڵSPI_FLASH_PerWritePageSize
  * @retval 
  */
void SPI_FLASH_PageWrite(uint8_t* pBuffer, uint32_t WriteAddr, uint16_t NumByteToWrite)
{
  /* FLASHдʹ */
  SPI_FLASH_WriteEnable();

  /* ѡFLASH: CS͵ƽ */
  SPI_FLASH_CS_LOW();
  /* дҳдָ*/
  SPI_FLASH_SendByte(W25X_PageProgram);
  /*дַĸλ*/
  SPI_FLASH_SendByte((WriteAddr & 0xFF0000) >> 16);
  /*дַλ*/
  SPI_FLASH_SendByte((WriteAddr & 0xFF00) >> 8);
  /*дַĵλ*/
  SPI_FLASH_SendByte(WriteAddr & 0xFF);

  if(NumByteToWrite > SPI_FLASH_PerWritePageSize)
  {
     NumByteToWrite = SPI_FLASH_PerWritePageSize;
     FLASH_ERROR("SPI_FLASH_PageWrite too large!"); 
  }

  /* д*/
  while (NumByteToWrite--)
  {
    /* ͵ǰҪдֽ */
    SPI_FLASH_SendByte(*pBuffer);
    /* ָһֽ */
    pBuffer++;
  }

  /* ֹͣź FLASH: CS ߵƽ */
  SPI_FLASH_CS_HIGH();

  /* ȴд*/
  SPI_FLASH_WaitForWriteEnd();
}

 /**
  * @brief  FLASHдݣñдǰҪȲ
  * @param	pBufferҪдݵָ
  * @param  WriteAddrдַ
  * @param  NumByteToWriteдݳ
  * @retval 
  */
void SPI_FLASH_BufferWrite(uint8_t* pBuffer, uint32_t WriteAddr, uint16_t NumByteToWrite)
{
  uint8_t NumOfPage = 0, NumOfSingle = 0, Addr = 0, count = 0, temp = 0;
	
	/*mod࣬writeAddrSPI_FLASH_PageSizeAddrֵΪ0*/
  Addr = WriteAddr % SPI_FLASH_PageSize;
	
	/*countֵպÿԶ뵽ҳַ*/
  count = SPI_FLASH_PageSize - Addr;
	/*Ҫдҳ*/
  NumOfPage =  NumByteToWrite / SPI_FLASH_PageSize;
	/*mod࣬ʣ಻һҳֽ*/
  NumOfSingle = NumByteToWrite % SPI_FLASH_PageSize;
	
	/* Addr=0,WriteAddr պðҳ aligned  */
  if (Addr == 0)
  {
		/* NumByteToWrite < SPI_FLASH_PageSize */
    if (NumOfPage == 0) 
    {
      SPI_FLASH_PageWrite(pBuffer, WriteAddr, NumByteToWrite);
    }
    else /* NumByteToWrite > SPI_FLASH_PageSize */
    { 
			/*Ȱҳд*/
      while (NumOfPage--)
      {
        SPI_FLASH_PageWrite(pBuffer, WriteAddr, SPI_FLASH_PageSize);
        WriteAddr +=  SPI_FLASH_PageSize;
        pBuffer += SPI_FLASH_PageSize;
      }
			/*жĲһҳݣд*/
      SPI_FLASH_PageWrite(pBuffer, WriteAddr, NumOfSingle);
    }
  }
	/* ַ SPI_FLASH_PageSize   */
  else 
  {
		/* NumByteToWrite < SPI_FLASH_PageSize */
    if (NumOfPage == 0)
    {
			/*ǰҳʣcountλñNumOfSingleСһҳд*/
      if (NumOfSingle > count) 
      {
        temp = NumOfSingle - count;
				/*дǰҳ*/
        SPI_FLASH_PageWrite(pBuffer, WriteAddr, count);
				
        WriteAddr +=  count;
        pBuffer += count;
				/*дʣ*/
        SPI_FLASH_PageWrite(pBuffer, WriteAddr, temp);
      }
      else /*ǰҳʣcountλдNumOfSingle*/
      {
        SPI_FLASH_PageWrite(pBuffer, WriteAddr, NumByteToWrite);
      }
    }
    else /* NumByteToWrite > SPI_FLASH_PageSize */
    {
			/*ַcountֿ*/
      NumByteToWrite -= count;
      NumOfPage =  NumByteToWrite / SPI_FLASH_PageSize;
      NumOfSingle = NumByteToWrite % SPI_FLASH_PageSize;
			
			/* дcountݣΪһҪдĵַ */
      SPI_FLASH_PageWrite(pBuffer, WriteAddr, count);
			
			/* ظַ */
      WriteAddr +=  count;
      pBuffer += count;
			/*ҳд*/
      while (NumOfPage--)
      {
        SPI_FLASH_PageWrite(pBuffer, WriteAddr, SPI_FLASH_PageSize);
        WriteAddr +=  SPI_FLASH_PageSize;
        pBuffer += SPI_FLASH_PageSize;
      }
			/*жĲһҳݣд*/
      if (NumOfSingle != 0)
      {
        SPI_FLASH_PageWrite(pBuffer, WriteAddr, NumOfSingle);
      }
    }
  }
}

 /**
  * @brief  ȡFLASH
  * @param 	pBuffer洢ݵָ
  * @param   ReadAddrȡַ
  * @param   NumByteToReadȡݳ
  * @retval 
  */
void SPI_FLASH_BufferRead(uint8_t* pBuffer, uint32_t ReadAddr, uint16_t NumByteToRead)
{
  /* ѡFLASH: CS͵ƽ */
  SPI_FLASH_CS_LOW();

  /*   ָ */
  SPI_FLASH_SendByte(W25X_ReadData);

  /*   ַλ */
  SPI_FLASH_SendByte((ReadAddr & 0xFF0000) >> 16);
  /*   ַλ */
  SPI_FLASH_SendByte((ReadAddr& 0xFF00) >> 8);
  /*   ַλ */
  SPI_FLASH_SendByte(ReadAddr & 0xFF);
	
	/* ȡ */
  while (NumByteToRead--) /* while there is data to be read */
  {
    /* ȡһֽ*/
    *pBuffer = SPI_FLASH_SendByte(Dummy_Byte);
    /* ָһֽڻ */
    pBuffer++;
  }

  /* ֹͣź FLASH: CS ߵƽ */
  SPI_FLASH_CS_HIGH();
}

 /**
  * @brief  ȡFLASH ID
  * @param 	
  * @retval FLASH ID
  */
uint32_t SPI_FLASH_ReadID(void)
{
  uint32_t Temp = 0, Temp0 = 0, Temp1 = 0, Temp2 = 0;

  /* ʼͨѶCS͵ƽ */
  SPI_FLASH_CS_LOW();

  /* JEDECָȡID */
  SPI_FLASH_SendByte(W25X_JedecDeviceID);

  /* ȡһֽ */
  Temp0 = SPI_FLASH_SendByte(Dummy_Byte);

  /* ȡһֽ */
  Temp1 = SPI_FLASH_SendByte(Dummy_Byte);

  /* ȡһֽ */
  Temp2 = SPI_FLASH_SendByte(Dummy_Byte);

 /* ֹͣͨѶCSߵƽ */
  SPI_FLASH_CS_HIGH();

  /*Ϊķֵ*/
	Temp = (Temp0 << 16) | (Temp1 << 8) | Temp2;

  return Temp;
}
 /**
  * @brief  ȡFLASH Device ID
  * @param 	
  * @retval FLASH Device ID
  */
uint32_t SPI_FLASH_ReadDeviceID(void)
{
  uint32_t Temp1 = 0 ,Temp = 0;

  /* Select the FLASH: Chip Select low */
  SPI_FLASH_CS_LOW();

  /* Send "RDID " instruction */
  SPI_FLASH_SendByte(W25X_DeviceID);
  SPI_FLASH_SendByte(Dummy_Byte);
  SPI_FLASH_SendByte(Dummy_Byte);
  SPI_FLASH_SendByte(Dummy_Byte);
  
  /* Read a byte from the FLASH */
  Temp = SPI_FLASH_SendByte(Dummy_Byte);
  /* Deselect the FLASH: Chip Select high */
  SPI_FLASH_CS_HIGH();

  return Temp;
}
/*******************************************************************************
* Function Name  : SPI_FLASH_StartReadSequence
* Description    : Initiates a read data byte (READ) sequence from the Flash.
*                  This is done by driving the /CS line low to select the device,
*                  then the READ instruction is transmitted followed by 3 bytes
*                  address. This function exit and keep the /CS line low, so the
*                  Flash still being selected. With this technique the whole
*                  content of the Flash is read with a single READ instruction.
* Input          : - ReadAddr : FLASH's internal address to read from.
* Output         : None
* Return         : None
*******************************************************************************/
void SPI_FLASH_StartReadSequence(uint32_t ReadAddr)
{
  /* Select the FLASH: Chip Select low */
  SPI_FLASH_CS_LOW();

  /* Send "Read from Memory " instruction */
  SPI_FLASH_SendByte(W25X_ReadData);

  /* Send the 24-bit address of the address to read from -----------------------*/
  /* Send ReadAddr high nibble address byte */
  SPI_FLASH_SendByte((ReadAddr & 0xFF0000) >> 16);
  /* Send ReadAddr medium nibble address byte */
  SPI_FLASH_SendByte((ReadAddr& 0xFF00) >> 8);
  /* Send ReadAddr low nibble address byte */
  SPI_FLASH_SendByte(ReadAddr & 0xFF);
}


 /**
  * @brief  ʹSPIȡһֽڵ
  * @param  
  * @retval ؽյ
  */
uint8_t SPI_FLASH_ReadByte(void)
{
  return (SPI_FLASH_SendByte(Dummy_Byte));
}

 /**
  * @brief  ʹSPIһֽڵ
  * @param  byteҪ͵
  * @retval ؽյ
  */
uint8_t SPI_FLASH_SendByte(uint8_t byte)
{
	 SPITimeout = SPIT_FLAG_TIMEOUT;
  /* ȴͻΪգTXE¼ */
  while (SPI_GetFlagStatus(FLASH_SPIx , SPI_FLAG_TFNF) == RESET)
	{
    if((SPITimeout--) == 0) return SPI_TIMEOUT_UserCallback(0);
   }

  /* дݼĴҪдд뷢ͻ */
  SPI_SendData8(FLASH_SPIx , byte);

	SPITimeout = SPIT_FLAG_TIMEOUT;
  /* ȴջǿգRXNE¼ */
  while (SPI_GetFlagStatus(FLASH_SPIx , SPI_FLAG_RFNE) == RESET)
  {
    if((SPITimeout--) == 0) return SPI_TIMEOUT_UserCallback(1);
   }

  /* ȡݼĴȡջ */
  return SPI_ReceiveData8(FLASH_SPIx );
}

 /**
  * @brief  ʹSPIֽڵ
  * @param  byteҪ͵
  * @retval ؽյ
  */
uint16_t SPI_FLASH_SendHalfWord(uint16_t HalfWord)
{
	  SPITimeout = SPIT_FLAG_TIMEOUT;
  /* ȴͻΪգTXE¼ */
  while (SPI_GetFlagStatus(FLASH_SPIx , SPI_FLAG_TFE) == RESET)
	{
    if((SPITimeout--) == 0) return SPI_TIMEOUT_UserCallback(2);
   }
	
  /* дݼĴҪдд뷢ͻ */
  SPI_SendData(FLASH_SPIx , HalfWord);

	 SPITimeout = SPIT_FLAG_TIMEOUT;
  /* ȴջǿգRXNE¼ */
  while (SPI_GetFlagStatus(FLASH_SPIx , SPI_FLAG_RFNE) == RESET)
	 {
    if((SPITimeout--) == 0) return SPI_TIMEOUT_UserCallback(3);
   }
  /* ȡݼĴȡջ */
  return SPI_ReceiveData(FLASH_SPIx );
}

 /**
  * @brief  FLASH дʹ 
  * @param  none
  * @retval none
  */
void SPI_FLASH_WriteEnable(void)
{
  /* ͨѶʼCS */
  SPI_FLASH_CS_LOW();

  /* дʹ*/
  SPI_FLASH_SendByte(W25X_WriteEnable);

  /*ͨѶCS */
  SPI_FLASH_CS_HIGH();
}

/* WIP(busy)־FLASHڲд */
#define WIP_Flag                  0x01

 /**
  * @brief  ȴWIP(BUSY)־0ȴFLASHڲд
  * @param  none
  * @retval none
  */
void SPI_FLASH_WaitForWriteEnd(void)
{
  uint8_t FLASH_Status = 0;

  /* ѡ FLASH: CS  */
  SPI_FLASH_CS_LOW();

  /*  ״̬Ĵ  */
  SPI_FLASH_SendByte(W25X_ReadStatusReg);

  /* FLASHæµȴ */
  do
  {
		/* ȡFLASHоƬ״̬Ĵ */
    FLASH_Status = SPI_FLASH_SendByte(Dummy_Byte);	 
  }
  while ((FLASH_Status & WIP_Flag) == SET);  /* д־ */

  /* ֹͣź  FLASH: CS  */
  SPI_FLASH_CS_HIGH();
}


//ģʽ
void SPI_Flash_PowerDown(void)   
{ 
  /* ͨѶʼCS */
  SPI_FLASH_CS_LOW();

  /*    */
  SPI_FLASH_SendByte(W25X_PowerDown);

  /*ͨѶCS */
  SPI_FLASH_CS_HIGH();
}   

//
void SPI_Flash_WAKEUP(void)   
{
  /*ѡ FLASH: CS  */
  SPI_FLASH_CS_LOW();

  /*  ϵ  */
  SPI_FLASH_SendByte(W25X_ReleasePowerDown);

   /* ֹͣź FLASH: CS  */
  SPI_FLASH_CS_HIGH();
}   
   

/**
  * @brief  ȴʱص
  * @param  None.
  * @retval None.
  */
static  uint16_t SPI_TIMEOUT_UserCallback(uint8_t errorCode)
{
  /* ȴʱĴ,Ϣ */
  FLASH_ERROR("SPI ȴʱ!errorCode = %d",errorCode);
  return 0;
}