/*
 * Copyright (c) 2009-2019 ARM Limited. All rights reserved.
 * 
 * SPDX-License-Identifier: Apache-2.0
 * 
 * Licensed under the Apache License, Version 2.0 (the License); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 * @file     PT32X031.h
 * @brief    CMSIS HeaderFile
 * @version  1.0
 * @date     04. March 2021
 * @note     Generated by SVDConv V3.3.35 on Thursday, 04.03.2021 17:27:37
 *           from File 'PT32x031.svd',
 *           last modified on Thursday, 04.03.2021 09:26:12
 */



/** @addtogroup 
  * @{
  */


/** @addtogroup PT32X031
  * @{
  */


#ifndef PT32X031_H
#define PT32X031_H

#ifdef __cplusplus
extern "C" {
#endif


/** @addtogroup Configuration_of_CMSIS
  * @{
  */



/* =========================================================================================================================== */
/* ================                                Interrupt Number Definition                                ================ */
/* =========================================================================================================================== */

typedef enum {
/* ==========================================  PT32X031 Specific Interrupt Numbers  ========================================== */
} IRQn_Type;



/* =========================================================================================================================== */
/* ================                           Processor and Core Peripheral Section                           ================ */
/* =========================================================================================================================== */

/* =============================  Configuration of the undefined Processor and Core Peripherals  ============================= */
#define __UNDEF_REV                 0x0000U     /*!< undef Core Revision                                                       */
#define __NVIC_PRIO_BITS               0        /*!< Number of Bits used for Priority Levels                                   */
#define __Vendor_SysTickConfig         0        /*!< Set to 1 if different SysTick Config is used                              */


/** @} */ /* End of group Configuration_of_CMSIS */

#include "core_undef.h"                         /*!< undefined processor and core peripherals                                  */
#include "system_PT32X031.h"                    /*!< PT32X031 System                                                           */

#ifndef __IM                                    /*!< Fallback for older CMSIS versions                                         */
  #define __IM   __I
#endif
#ifndef __OM                                    /*!< Fallback for older CMSIS versions                                         */
  #define __OM   __O
#endif
#ifndef __IOM                                   /*!< Fallback for older CMSIS versions                                         */
  #define __IOM  __IO
#endif


/* ========================================  Start of section using anonymous unions  ======================================== */
#if defined (__CC_ARM)
  #pragma push
  #pragma anon_unions
#elif defined (__ICCARM__)
  #pragma language=extended
#elif defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
  #pragma clang diagnostic push
  #pragma clang diagnostic ignored "-Wc11-extensions"
  #pragma clang diagnostic ignored "-Wreserved-id-macro"
  #pragma clang diagnostic ignored "-Wgnu-anonymous-struct"
  #pragma clang diagnostic ignored "-Wnested-anon-types"
#elif defined (__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined (__TMS470__)
  /* anonymous unions are enabled by default */
#elif defined (__TASKING__)
  #pragma warning 586
#elif defined (__CSMC__)
  /* anonymous unions are enabled by default */
#else
  #warning Not supported compiler type
#endif


/* =========================================================================================================================== */
/* ================                            Device Specific Peripheral Section                             ================ */
/* =========================================================================================================================== */


/** @addtogroup Device_Peripheral_peripherals
  * @{
  */



/* =========================================================================================================================== */
/* ================                                       SYSTEM_CTRL0                                        ================ */
/* =========================================================================================================================== */


/**
  * @brief System control register (SYSTEM_CTRL0)
  */

typedef struct {                                /*!< (@ 0x4001F000) SYSTEM_CTRL0 Structure                                     */
  __IOM uint32_t  REMAP;                        /*!< (@ 0x00000000) Boot mode register                                         */
  __IM  uint32_t  RESERVED;
  __IOM uint32_t  RESERVED1;                    /*!< (@ 0x00000008) Processor lock reset control register                      */
  __IOM uint32_t  SYSCLK;                       /*!< (@ 0x0000000C) System clock select register                               */
  __IOM uint32_t  RSTINFO;                      /*!< (@ 0x00000010) Reset information registe                                  */
  __IOM uint32_t  RETRIMING;                    /*!< (@ 0x00000014) Restart control register                                   */
  __IOM uint32_t  RSTENCTRL;                    /*!< (@ 0x00000018) Reset enable control register                              */
  __IM  uint32_t  RESERVED1;
  __IM  uint32_t  CUSTOMER_ID_INFO;             /*!< (@ 0x00000020) CUSTOMER_ID Information register                           */
  __IM  uint32_t  FLASH_PROTECT;                /*!< (@ 0x00000024) Protection status register                                 */
  __IM  uint32_t  RESERVED2;
  __IM  uint32_t  AGENT_ID_INFO;                /*!< (@ 0x0000002C) AGENT_ ID Information register                             */
  __IM  uint32_t  UID_INFO1;                    /*!< (@ 0x00000030) Uid information [31:0] register                            */
  __IM  uint32_t  UID_INFO2;                    /*!< (@ 0x00000034) Uid information [63:32] register                           */
  __IM  uint32_t  UID_INFO3;                    /*!< (@ 0x00000038) Uid information [95:64] register                           */
  __IM  uint32_t  CID_INFO;                     /*!< (@ 0x0000003C) CID information register                                   */
  __IM  uint32_t  RESERVED3[996];
  __IM  uint32_t  PID0;                         /*!< (@ 0x00000FD0) Peripheral ID 0 register                                   */
  __IM  uint32_t  PID1;                         /*!< (@ 0x00000FD4) Peripheral ID 1 register                                   */
  __IM  uint32_t  PID2;                         /*!< (@ 0x00000FD8) Peripheral ID 2 register                                   */
  __IM  uint32_t  PID3;                         /*!< (@ 0x00000FDC) Peripheral ID 3 register                                   */
  __IM  uint32_t  PID4;                         /*!< (@ 0x00000FE0) Peripheral ID 4 register                                   */
  __IM  uint32_t  PID5;                         /*!< (@ 0x00000FE4) Peripheral ID 5 register                                   */
  __IM  uint32_t  PID6;                         /*!< (@ 0x00000FE8) Peripheral ID 6 register                                   */
  __IM  uint32_t  PID7;                         /*!< (@ 0x00000FEC) Peripheral ID 7 register                                   */
  __IM  uint32_t  CID0;                         /*!< (@ 0x00000FF0) Component ID 0 register                                    */
  __IM  uint32_t  CID1;                         /*!< (@ 0x00000FF4) Component ID 1 register                                    */
  __IM  uint32_t  CID2;                         /*!< (@ 0x00000FF8) Component ID 2 register                                    */
  __IM  uint32_t  CID3;                         /*!< (@ 0x00000FFC) Component ID 3 register                                    */
} SYSTEM_CTRL0_Type;                            /*!< Size = 4096 (0x1000)                                                      */



/* =========================================================================================================================== */
/* ================                                       SYSTEM_CTRL1                                        ================ */
/* =========================================================================================================================== */


/**
  * @brief System control register (SYSTEM_CTRL1)
  */

typedef struct {                                /*!< (@ 0xE000ED00) SYSTEM_CTRL1 Structure                                     */
  __IM  uint32_t  RESERVED[4];
  __IOM uint32_t  SCR;                          /*!< (@ 0x00000010) System control register                                    */
} SYSTEM_CTRL1_Type;                            /*!< Size = 20 (0x14)                                                          */



/* =========================================================================================================================== */
/* ================                                           NVIC                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief Vector interrupt control (NVIC)
  */

typedef struct {                                /*!< (@ 0xE000E100) NVIC Structure                                             */
  __IOM uint32_t  ISER;                         /*!< (@ 0x00000000) System interrupt enable register                           */
  __IM  uint32_t  RESERVED[31];
  __IOM uint32_t  ICER;                         /*!< (@ 0x00000080) System interrupt prohibit register                         */
  __IM  uint32_t  RESERVED1[31];
  __IOM uint32_t  ISPR;                         /*!< (@ 0x00000100) System interrupt suspend setting register                  */
  __IM  uint32_t  RESERVED2[31];
  __IOM uint32_t  ICPR;                         /*!< (@ 0x00000180) System interrupt suspend cleanup register                  */
} NVIC_Type;                                    /*!< Size = 388 (0x184)                                                        */



/* =========================================================================================================================== */
/* ================                                           GPIOA                                           ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose I/O (GPIOA)
  */

typedef struct {                                /*!< (@ 0x48000000) GPIOA Structure                                            */
  __IOM uint32_t  DATA;                         /*!< (@ 0x00000000) Port data register                                         */
  __IOM uint32_t  DATAOUT;                      /*!< (@ 0x00000004) Port data output latch register                            */
  __IOM uint32_t  OUTENABLESET;                 /*!< (@ 0x00000008) Port output enable set register                            */
  __IOM uint32_t  OUTENABLECLR;                 /*!< (@ 0x0000000C) Port output enable clear register                          */
  __IOM uint32_t  ALTFUNCSET;                   /*!< (@ 0x00000010) Peripheral multiplexing set register 0                     */
  __IOM uint32_t  ALTFUNCCLR;                   /*!< (@ 0x00000014) Peripheral multiplex clear register 0                      */
  __IOM uint32_t  INTENSET;                     /*!< (@ 0x00000018) Interrupt enable position register                         */
  __IOM uint32_t  INTENCLR;                     /*!< (@ 0x0000001C) Interrupt enable clear register                            */
  __IOM uint32_t  INTTYPESET;                   /*!< (@ 0x00000020) Interrupt type set register 0                              */
  __IOM uint32_t  INTTYPECLR;                   /*!< (@ 0x00000024) Interrupt type clear register 0                            */
  __IOM uint32_t  INTTYPESET1;                  /*!< (@ 0x00000028) Interrupt type set register 1                              */
  __IOM uint32_t  INTTYPECLR1;                  /*!< (@ 0x0000002C) Interrupt type clear register 1                            */
  __IOM uint32_t  INTPOLSET;                    /*!< (@ 0x00000030) Interrupt polarity setting register                        */
  __IOM uint32_t  INTPOLCLR;                    /*!< (@ 0x00000034) Interrupt polarity clear register                          */
  __IOM uint32_t  INTSTATUS_INTCLEAR;           /*!< (@ 0x00000038) Interrupt flag register                                    */
  __IOM uint32_t  PULLUPSET;                    /*!< (@ 0x0000003C) Internal pull-up enable set register                       */
  __IOM uint32_t  PULLUPCLR;                    /*!< (@ 0x00000040) Internal pull-up enables cleaning up register              */
  __IOM uint32_t  PULLDOWNSET;                  /*!< (@ 0x00000044) Internal pull down enable set register                     */
  __IOM uint32_t  PULLDOWNCLR;                  /*!< (@ 0x00000048) Internal pull down enable clear register                   */
  __IOM uint32_t  ODRSET;                       /*!< (@ 0x0000004C) Output leakage enable location register                    */
  __IOM uint32_t  ODRCLR;                       /*!< (@ 0x00000050) Output leakage enable clearing register                    */
  __IOM uint32_t  ANASET;                       /*!< (@ 0x00000054) Analog function enable set register                        */
  __IOM uint32_t  ANACLR;                       /*!< (@ 0x00000058) The analog function enables clear register                 */
  __IOM uint32_t  ALTFUNCSET1;                  /*!< (@ 0x0000005C) Peripheral multiplex bit register 1                        */
} GPIOA_Type;                                   /*!< Size = 96 (0x60)                                                          */



/* =========================================================================================================================== */
/* ================                                          Systick                                          ================ */
/* =========================================================================================================================== */


/**
  * @brief Systick (Systick)
  */

typedef struct {                                /*!< (@ 0xE000E000) Systick Structure                                          */
  __IM  uint32_t  RESERVED[4];
  __IOM uint32_t  CORET_CSR;                    /*!< (@ 0x00000010) Control status register                                    */
  __IOM uint32_t  CORET_RVR;                    /*!< (@ 0x00000014) Backfill value register                                    */
  __IOM uint32_t  CORET_CVR;                    /*!< (@ 0x00000018) Current value registe                                      */
} Systick_Type;                                 /*!< Size = 28 (0x1c)                                                          */



/* =========================================================================================================================== */
/* ================                                           TMR0                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief Advanced timer (TMR0)
  */

typedef struct {                                /*!< (@ 0x40012800) TMR0 Structure                                             */
  __IOM uint32_t  ISR;                          /*!< (@ 0x00000000) Timer TMRn interrupt register                              */
  __IOM uint32_t  TCR;                          /*!< (@ 0x00000004) Timer TMRn control register                                */
  __IOM uint32_t  INT_RPT;                      /*!< (@ 0x00000008) Timer TMRn cumulative interrupts control register          */
  __IOM uint32_t  INT_RPTC;                     /*!< (@ 0x0000000C) Timer TMRn interrupt cumulative count register             */
  __IOM uint32_t  PR;                           /*!< (@ 0x00000010) Timer TMRn prescaler factor register                       */
  __IOM uint32_t  PC;                           /*!< (@ 0x00000014) Timer TMRn prescaler current count value register          */
  __IOM uint32_t  TC;                           /*!< (@ 0x00000018) Timer TMRn current count value register                    */
  __IOM uint32_t  MCR;                          /*!< (@ 0x0000001C) Timer TMRn matching control register                       */
  __IOM uint32_t  MR0;                          /*!< (@ 0x00000020) Timer TMRn matching value register 0                       */
  __IOM uint32_t  MR1;                          /*!< (@ 0x00000024) Timer TMRn matching value register 1                       */
  __IOM uint32_t  MR2;                          /*!< (@ 0x00000028) Timer TMRn matching value register 2                       */
  __IOM uint32_t  MR3;                          /*!< (@ 0x0000002C) Timer TMRn matching value register 3                       */
  __IOM uint32_t  MR4;                          /*!< (@ 0x00000030) Timer TMRn matching value register 4                       */
  __IOM uint32_t  CCR;                          /*!< (@ 0x00000034) Timer TMRn capture control register                        */
  __IOM uint32_t  CR1;                          /*!< (@ 0x00000038) Timer TMRn capture value register 1                        */
  __IOM uint32_t  CR2;                          /*!< (@ 0x0000003C) Timer TMRn capture value register 2                        */
  __IOM uint32_t  CR3;                          /*!< (@ 0x00000040) Timer TMRn capture value register 3                        */
  __IOM uint32_t  CR4;                          /*!< (@ 0x00000044) Timer TMRn capture value register 4                        */
  __IOM uint32_t  CMR;                          /*!< (@ 0x00000048) Timer TMRn compare output control register                 */
  __IOM uint32_t  DT;                           /*!< (@ 0x0000004C) Timer TMRn dead time control register                      */
} TMR0_Type;                                    /*!< Size = 80 (0x50)                                                          */



/* =========================================================================================================================== */
/* ================                                           TMR2                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose timer (TMR2)
  */

typedef struct {                                /*!< (@ 0x40001000) TMR2 Structure                                             */
  __IOM uint32_t  ISR;                          /*!< (@ 0x00000000) Timer TMRn interrupt register                              */
  __IOM uint32_t  TCR;                          /*!< (@ 0x00000004) Timer TMRn Control Register                                */
  __IOM uint32_t  PR;                           /*!< (@ 0x00000008) Timer TMRn prescaler factor register                       */
  __IOM uint32_t  PC;                           /*!< (@ 0x0000000C) Timer TMRn pre-frequency current count value
                                                                    register                                                   */
  __IOM uint32_t  TC;                           /*!< (@ 0x00000010) Timer TMRn current count value register                    */
  __IOM uint32_t  MCR;                          /*!< (@ 0x00000014) Timer TMRn matching control register                       */
  __IOM uint32_t  MR0;                          /*!< (@ 0x00000018) Timer TMRn match value register                            */
} TMR2_Type;                                    /*!< Size = 28 (0x1c)                                                          */



/* =========================================================================================================================== */
/* ================                                           BEEP                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose Beep (BEEP)
  */

typedef struct {                                /*!< (@ 0x40002800) BEEP Structure                                             */
  __IOM uint32_t  CR;                           /*!< (@ 0x00000000) Buzzer control register                                    */
} BEEP_Type;                                    /*!< Size = 4 (0x4)                                                            */



/* =========================================================================================================================== */
/* ================                                          SYSWDG                                           ================ */
/* =========================================================================================================================== */


/**
  * @brief System Watch Dog (SYSWDG)
  */

typedef struct {                                /*!< (@ 0x40002000) SYSWDG Structure                                           */
  __IOM uint32_t  RLR;                          /*!< (@ 0x00000000) SYSWDG count overload register                             */
  __IOM uint32_t  COUNT;                        /*!< (@ 0x00000004) SYSWDG count value register                                */
  __IOM uint32_t  CR;                           /*!< (@ 0x00000008) SYSWDG control register                                    */
  __OM  uint32_t  FWDG;                         /*!< (@ 0x0000000C) SYSWDG interrupt clear register                            */
  __IM  uint32_t  RIS;                          /*!< (@ 0x00000010) SYSWDG original interrupt flag register                    */
  __IM  uint32_t  EIS;                          /*!< (@ 0x00000014) SYSWDG masking interrupt flag register                     */
  __IM  uint32_t  RESERVED[250];
  __OM  uint32_t  KR;                           /*!< (@ 0x00000400) SYSWDG lock control register                               */
} SYSWDG_Type;                                  /*!< Size = 1028 (0x404)                                                       */



/* =========================================================================================================================== */
/* ================                                           UART0                                           ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose UART (UART0)
  */

typedef struct {                                /*!< (@ 0x40004400) UART0 Structure                                            */
  __IOM uint32_t  BR;                           /*!< (@ 0x00000000) Receive and send data FIFO buffer register                 */
  __IOM uint32_t  CR;                           /*!< (@ 0x00000004) Module control register                                    */
  __IOM uint32_t  BRR;                          /*!< (@ 0x00000008) Baud rate control register                                 */
  __IOM uint32_t  IER;                          /*!< (@ 0x0000000C) Interrupt control register                                 */
  
  union {
    __IOM uint32_t SR;                          /*!< (@ 0x00000010) Status register                                            */
    __OM  uint32_t SRCLR;                       /*!< (@ 0x00000010) State clear register                                       */
  };
  __IOM uint32_t  GTR;                          /*!< (@ 0x00000014) Frame interval time register                               */
  __IOM uint32_t  TOR;                          /*!< (@ 0x00000018) Timeout control register                                   */
  __OM  uint32_t  TRR;                          /*!< (@ 0x0000001C) Send queue reset register                                  */
  __IM  uint32_t  RRR;                          /*!< (@ 0x00000020) Receive queue reset register                               */
  __IOM uint32_t  ISO7816_CR;                   /*!< (@ 0x00000024) ISO7816 transceiver control register                       */
  __IOM uint32_t  IR_CR;                        /*!< (@ 0x00000028) Infrared transmit demodulate control register              */
  __IOM uint32_t  IRTX_PWMC;                    /*!< (@ 0x0000002C) Infrared sending duty cycle control register               */
} UART0_Type;                                   /*!< Size = 48 (0x30)                                                          */



/* =========================================================================================================================== */
/* ================                                           SPI0                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose SPI (SPI0)
  */

typedef struct {                                /*!< (@ 0x40013000) SPI0 Structure                                             */
  __IOM uint32_t  CR0;                          /*!< (@ 0x00000000) SPIn control register 0                                    */
  __IOM uint32_t  CR1;                          /*!< (@ 0x00000004) SPIn control register 1                                    */
  __IOM uint32_t  DR;                           /*!< (@ 0x00000008) SPIn data register                                         */
  __IM  uint32_t  SR;                           /*!< (@ 0x0000000C) SPIn status register                                       */
  __IOM uint32_t  CPSR;                         /*!< (@ 0x00000010) SPIn clock Prescaler                                       */
  __IOM uint32_t  IE;                           /*!< (@ 0x00000014) SPIn interrupt enable register                             */
  __IM  uint32_t  RIS;                          /*!< (@ 0x00000018) SPIn original interrupt flag register                      */
  __IM  uint32_t  EIS;                          /*!< (@ 0x0000001C) SPIn enable interrupt flag register                        */
  __OM  uint32_t  ICR;                          /*!< (@ 0x00000020) SPIn interrupt flag clear register                         */
  __IM  uint32_t  RESERVED;
  __IOM uint32_t  CSCR;                         /*!< (@ 0x00000028) SPIn chip selection signal control register                */
} SPI0_Type;                                    /*!< Size = 44 (0x2c)                                                          */



/* =========================================================================================================================== */
/* ================                                           IIC0                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose IIC (IIC0)
  */

typedef struct {                                /*!< (@ 0x40005400) IIC0 Structure                                             */
  __IOM uint32_t  CSR;                          /*!< (@ 0x00000000) I2C control setting register                               */
  __IM  uint32_t  SR;                           /*!< (@ 0x00000004) I2C control setting register                               */
  __IOM uint32_t  DR;                           /*!< (@ 0x00000008) I2C data register                                          */
  __IOM uint32_t  OAR;                          /*!< (@ 0x0000000C) I2C address register                                       */
  __IM  uint32_t  RESERVED[2];
  __OM  uint32_t  CCR;                          /*!< (@ 0x00000018) I2C control clear register                                 */
} IIC0_Type;                                    /*!< Size = 28 (0x1c)                                                          */



/* =========================================================================================================================== */
/* ================                                            ADC                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose ADC (ADC)
  */

typedef struct {                                /*!< (@ 0x40012400) ADC Structure                                              */
  __IOM uint32_t  CR;                           /*!< (@ 0x00000000) ADC control register                                       */
  __IOM uint32_t  TRSTN;                        /*!< (@ 0x00000004) ADC reset release time register                            */
  __IM  uint32_t  SR;                           /*!< (@ 0x00000008) ADC status register                                        */
  __IM  uint32_t  DR;                           /*!< (@ 0x0000000C) ADC status register                                        */
} ADC_Type;                                     /*!< Size = 16 (0x10)                                                          */



/* =========================================================================================================================== */
/* ================                                            LED                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose LED (LED)
  */

typedef struct {                                /*!< (@ 0x40002C00) LED Structure                                              */
  __IOM uint32_t  CR;                           /*!< (@ 0x00000000) LED control register                                       */
  __IOM uint32_t  CPSR;                         /*!< (@ 0x00000004) Led prescaler factor register                              */
  __IOM uint32_t  TR;                           /*!< (@ 0x00000008) Led time register                                          */
  __IOM uint32_t  DR0;                          /*!< (@ 0x0000000C) Led data register 0                                        */
  __IOM uint32_t  DR1;                          /*!< (@ 0x00000010) Led data register 1                                        */
  __IOM uint32_t  DR2;                          /*!< (@ 0x00000014) Led data register 2                                        */
  __IOM uint32_t  DR3;                          /*!< (@ 0x00000018) Led data register 3                                        */
  __IM  uint32_t  EIS;                          /*!< (@ 0x0000001C) Led interrupt register                                     */
} LED_Type;                                     /*!< Size = 32 (0x20)                                                          */



/* =========================================================================================================================== */
/* ================                                           COMP0                                           ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose CMP0 (COMP0)
  */

typedef struct {                                /*!< (@ 0x40000800) COMP0 Structure                                            */
  __IOM uint32_t  CR1;                          /*!< (@ 0x00000000) Comparator control register                                */
  __IOM uint32_t  CR2;                          /*!< (@ 0x00000004) Comparator control register                                */
  __IOM uint32_t  DAC;                          /*!< (@ 0x00000008) Comparator DAC input data register                         */
  __IOM uint32_t  IE;                           /*!< (@ 0x0000000C) Comparator interrupt control register                      */
  __IOM uint32_t  EIS;                          /*!< (@ 0x00000010) Comparator interrupt flag register                         */
  __IOM uint32_t  INITDELAY;                    /*!< (@ 0x00000014) Comparator initialization delay configuration
                                                                    register                                                   */
} COMP0_Type;                                   /*!< Size = 24 (0x18)                                                          */



/* =========================================================================================================================== */
/* ================                                            CRC                                            ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose CRC (CRC)
  */

typedef struct {                                /*!< (@ 0x40003C00) CRC Structure                                              */
  __IOM uint32_t  CR;                           /*!< (@ 0x00000000) CRC control register                                       */
  __IOM uint32_t  SDR;                          /*!< (@ 0x00000004) CRC seed register                                          */
  __IOM uint32_t  POLY;                         /*!< (@ 0x00000008) CRC polynomial register                                    */
  __OM  uint32_t  DIN;                          /*!< (@ 0x0000000C) CRC data input register                                    */
  __IM  uint32_t  DOUT;                         /*!< (@ 0x00000010) CRC data output register                                   */
} CRC_Type;                                     /*!< Size = 20 (0x14)                                                          */



/* =========================================================================================================================== */
/* ================                                        ANALOG_MISC                                        ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose ANALOG_MISC (ANALOG_MISC)
  */

typedef struct {                                /*!< (@ 0x40001800) ANALOG_MISC Structure                                      */
  __IOM uint32_t  VDDLVDCTRL;                   /*!< (@ 0x00000000) LVD control register                                       */
  __IOM uint32_t  LDOLVDCTRL;                   /*!< (@ 0x00000004) 1.5V LVD control register                                  */
  __IOM uint32_t  EOSCCON1;                     /*!< (@ 0x00000008) High frequency crystal oscillation control register
                                                                    1                                                          */
  __IOM uint32_t  EOSCCON2;                     /*!< (@ 0x0000000C) High frequency crystal oscillation control register
                                                                    2                                                          */
  __IOM uint32_t  IOSC24MCON;                   /*!< (@ 0x00000010) Internal 24m RC oscillation control register               */
  __IOM uint32_t  IOSC32KCON;                   /*!< (@ 0x00000014) Internal 32K RC oscillation control register               */
  __IOM uint32_t  FDCON;                        /*!< (@ 0x00000018) Frequency multiplication module control register           */
  __IOM uint32_t  DEGLITCHCON;                  /*!< (@ 0x0000001C) Deglitch delay control register                            */
  __IOM uint32_t  HSINKCON;                     /*!< (@ 0x00000020) Highsink GPIO control register                             */
  __IOM uint32_t  MCODIVCON;                    /*!< (@ 0x00000024) Master clock output frequency division control
                                                                    register                                                   */
} ANALOG_MISC_Type;                             /*!< Size = 40 (0x28)                                                          */



/* =========================================================================================================================== */
/* ================                                           FLASH                                           ================ */
/* =========================================================================================================================== */


/**
  * @brief General purpose FLASH (FLASH)
  */

typedef struct {                                /*!< (@ 0x40000000) FLASH Structure                                            */
  __IOM uint32_t  ACR;                          /*!< (@ 0x00000000) Flash command register                                     */
  __IOM uint32_t  ISR;                          /*!< (@ 0x00000004) Flash interrupt status register                            */
  __IOM uint32_t  IER;                          /*!< (@ 0x00000008) Flash interrupt enable register                            */
  __IOM uint32_t  AR;                           /*!< (@ 0x0000000C) Flash address register                                     */
  __IOM uint32_t  DR;                           /*!< (@ 0x00000010) Flash programming data register                            */
  __IM  uint32_t  RESERVED[5];
  __IOM uint32_t  DIV;                          /*!< (@ 0x00000028) Flash programming data register                            */
} FLASH_Type;                                   /*!< Size = 44 (0x2c)                                                          */


/** @} */ /* End of group Device_Peripheral_peripherals */


/* =========================================================================================================================== */
/* ================                          Device Specific Peripheral Address Map                           ================ */
/* =========================================================================================================================== */


/** @addtogroup Device_Peripheral_peripheralAddr
  * @{
  */

#define SYSTEM_CTRL0_BASE           0x4001F000UL
#define SYSTEM_CTRL1_BASE           0xE000ED00UL
#define NVIC_BASE                   0xE000E100UL
#define GPIOA_BASE                  0x48000000UL
#define GPIOB_BASE                  0x48001000UL
#define GPIOF_BASE                  0x48002000UL
#define Systick_BASE                0xE000E000UL
#define TMR0_BASE                   0x40012800UL
#define TMR1_BASE                   0x40012C00UL
#define TMR2_BASE                   0x40001000UL
#define TMR3_BASE                   0x40001400UL
#define TMR4_BASE                   0x40001C00UL
#define BEEP_BASE                   0x40002800UL
#define SYSWDG_BASE                 0x40002000UL
#define IWDG_BASE                   0x40003000UL
#define UART0_BASE                  0x40004400UL
#define UART1_BASE                  0x40013800UL
#define SPI0_BASE                   0x40013000UL
#define SPI1_BASE                   0x40003800UL
#define IIC0_BASE                   0x40005400UL
#define IIC1_BASE                   0x40005800UL
#define ADC_BASE                    0x40012400UL
#define LED_BASE                    0x40002C00UL
#define COMP0_BASE                  0x40000800UL
#define COMP1_BASE                  0x40000C00UL
#define CRC_BASE                    0x40003C00UL
#define ANALOG_MISC_BASE            0x40001800UL
#define FLASH_BASE                  0x40000000UL

/** @} */ /* End of group Device_Peripheral_peripheralAddr */


/* =========================================================================================================================== */
/* ================                                  Peripheral declaration                                   ================ */
/* =========================================================================================================================== */


/** @addtogroup Device_Peripheral_declaration
  * @{
  */

#define SYSTEM_CTRL0                ((SYSTEM_CTRL0_Type*)      SYSTEM_CTRL0_BASE)
#define SYSTEM_CTRL1                ((SYSTEM_CTRL1_Type*)      SYSTEM_CTRL1_BASE)
#define NVIC                        ((NVIC_Type*)              NVIC_BASE)
#define GPIOA                       ((GPIOA_Type*)             GPIOA_BASE)
#define GPIOB                       ((GPIOA_Type*)             GPIOB_BASE)
#define GPIOF                       ((GPIOA_Type*)             GPIOF_BASE)
#define Systick                     ((Systick_Type*)           Systick_BASE)
#define TMR0                        ((TMR0_Type*)              TMR0_BASE)
#define TMR1                        ((TMR0_Type*)              TMR1_BASE)
#define TMR2                        ((TMR2_Type*)              TMR2_BASE)
#define TMR3                        ((TMR2_Type*)              TMR3_BASE)
#define TMR4                        ((TMR2_Type*)              TMR4_BASE)
#define BEEP                        ((BEEP_Type*)              BEEP_BASE)
#define SYSWDG                      ((SYSWDG_Type*)            SYSWDG_BASE)
#define IWDG                        ((SYSWDG_Type*)            IWDG_BASE)
#define UART0                       ((UART0_Type*)             UART0_BASE)
#define UART1                       ((UART0_Type*)             UART1_BASE)
#define SPI0                        ((SPI0_Type*)              SPI0_BASE)
#define SPI1                        ((SPI0_Type*)              SPI1_BASE)
#define IIC0                        ((IIC0_Type*)              IIC0_BASE)
#define IIC1                        ((IIC0_Type*)              IIC1_BASE)
#define ADC                         ((ADC_Type*)               ADC_BASE)
#define LED                         ((LED_Type*)               LED_BASE)
#define COMP0                       ((COMP0_Type*)             COMP0_BASE)
#define COMP1                       ((COMP0_Type*)             COMP1_BASE)
#define CRC                         ((CRC_Type*)               CRC_BASE)
#define ANALOG_MISC                 ((ANALOG_MISC_Type*)       ANALOG_MISC_BASE)
#define FLASH                       ((FLASH_Type*)             FLASH_BASE)

/** @} */ /* End of group Device_Peripheral_declaration */


/* =========================================  End of section using anonymous unions  ========================================= */
#if defined (__CC_ARM)
  #pragma pop
#elif defined (__ICCARM__)
  /* leave anonymous unions enabled */
#elif defined(__ARMCC_VERSION) && (__ARMCC_VERSION >= 6010050)
  #pragma clang diagnostic pop
#elif defined (__GNUC__)
  /* anonymous unions are enabled by default */
#elif defined (__TMS470__)
  /* anonymous unions are enabled by default */
#elif defined (__TASKING__)
  #pragma warning restore
#elif defined (__CSMC__)
  /* anonymous unions are enabled by default */
#endif


/* =========================================================================================================================== */
/* ================                                Pos/Mask Peripheral Section                                ================ */
/* =========================================================================================================================== */


/** @addtogroup PosMask_peripherals
  * @{
  */



/* =========================================================================================================================== */
/* ================                                       SYSTEM_CTRL0                                        ================ */
/* =========================================================================================================================== */

/* =========================================================  REMAP  ========================================================= */
#define SYSTEM_CTRL0_REMAP_BOOT_Pos       (0UL)                     /*!< BOOT (Bit 0)                                          */
#define SYSTEM_CTRL0_REMAP_BOOT_Msk       (0x1UL)                   /*!< BOOT (Bitfield-Mask: 0x01)                            */
/* =======================================================  RESERVED1  ======================================================= */
#define SYSTEM_CTRL0_RESERVED1_RST_Pos    (0UL)                     /*!< RST (Bit 0)                                           */
#define SYSTEM_CTRL0_RESERVED1_RST_Msk    (0x1UL)                   /*!< RST (Bitfield-Mask: 0x01)                             */
/* ========================================================  SYSCLK  ========================================================= */
#define SYSTEM_CTRL0_SYSCLK_SYSCLKSEL_Pos (0UL)                     /*!< SYSCLKSEL (Bit 0)                                     */
#define SYSTEM_CTRL0_SYSCLK_SYSCLKSEL_Msk (0x3UL)                   /*!< SYSCLKSEL (Bitfield-Mask: 0x03)                       */
#define SYSTEM_CTRL0_SYSCLK_FDCLKSEL_Pos  (2UL)                     /*!< FDCLKSEL (Bit 2)                                      */
#define SYSTEM_CTRL0_SYSCLK_FDCLKSEL_Msk  (0xcUL)                   /*!< FDCLKSEL (Bitfield-Mask: 0x03)                        */
#define SYSTEM_CTRL0_SYSCLK_HCLKDIV_Pos   (4UL)                     /*!< HCLKDIV (Bit 4)                                       */
#define SYSTEM_CTRL0_SYSCLK_HCLKDIV_Msk   (0x70UL)                  /*!< HCLKDIV (Bitfield-Mask: 0x07)                         */
#define SYSTEM_CTRL0_SYSCLK_PCLKDIV_Pos   (8UL)                     /*!< PCLKDIV (Bit 8)                                       */
#define SYSTEM_CTRL0_SYSCLK_PCLKDIV_Msk   (0x700UL)                 /*!< PCLKDIV (Bitfield-Mask: 0x07)                         */
#define SYSTEM_CTRL0_SYSCLK_EOSFAIL_DETECTEN_Pos (12UL)             /*!< EOSFAIL_DETECTEN (Bit 12)                             */
#define SYSTEM_CTRL0_SYSCLK_EOSFAIL_DETECTEN_Msk (0x1000UL)         /*!< EOSFAIL_DETECTEN (Bitfield-Mask: 0x01)                */
#define SYSTEM_CTRL0_SYSCLK_EOSFAIL_STATUS_Pos (13UL)               /*!< EOSFAIL_STATUS (Bit 13)                               */
#define SYSTEM_CTRL0_SYSCLK_EOSFAIL_STATUS_Msk (0x2000UL)           /*!< EOSFAIL_STATUS (Bitfield-Mask: 0x01)                  */
#define SYSTEM_CTRL0_SYSCLK_FDFAIL_DETECTEN_Pos (14UL)              /*!< FDFAIL_DETECTEN (Bit 14)                              */
#define SYSTEM_CTRL0_SYSCLK_FDFAIL_DETECTEN_Msk (0x4000UL)          /*!< FDFAIL_DETECTEN (Bitfield-Mask: 0x01)                 */
#define SYSTEM_CTRL0_SYSCLK_FDFAIL_STATUS_Pos (15UL)                /*!< FDFAIL_STATUS (Bit 15)                                */
#define SYSTEM_CTRL0_SYSCLK_FDFAIL_STATUS_Msk (0x8000UL)            /*!< FDFAIL_STATUS (Bitfield-Mask: 0x01)                   */
#define SYSTEM_CTRL0_SYSCLK_WAKE_DELAY_Pos (16UL)                   /*!< WAKE_DELAY (Bit 16)                                   */
#define SYSTEM_CTRL0_SYSCLK_WAKE_DELAY_Msk (0x30000UL)              /*!< WAKE_DELAY (Bitfield-Mask: 0x03)                      */
#define SYSTEM_CTRL0_SYSCLK_RECOVER_SEL_Pos (20UL)                  /*!< RECOVER_SEL (Bit 20)                                  */
#define SYSTEM_CTRL0_SYSCLK_RECOVER_SEL_Msk (0x100000UL)            /*!< RECOVER_SEL (Bitfield-Mask: 0x01)                     */
/* ========================================================  RSTINFO  ======================================================== */
#define SYSTEM_CTRL0_RSTINFO_SYSSOFTRST_Pos (0UL)                   /*!< SYSSOFTRST (Bit 0)                                    */
#define SYSTEM_CTRL0_RSTINFO_SYSSOFTRST_Msk (0x1UL)                 /*!< SYSSOFTRST (Bitfield-Mask: 0x01)                      */
#define SYSTEM_CTRL0_RSTINFO_IWDGRST_Pos  (1UL)                     /*!< IWDGRST (Bit 1)                                       */
#define SYSTEM_CTRL0_RSTINFO_IWDGRST_Msk  (0x2UL)                   /*!< IWDGRST (Bitfield-Mask: 0x01)                         */
#define SYSTEM_CTRL0_RSTINFO_LOCKUPRST_Pos (2UL)                    /*!< LOCKUPRST (Bit 2)                                     */
#define SYSTEM_CTRL0_RSTINFO_LOCKUPRST_Msk (0x4UL)                  /*!< LOCKUPRST (Bitfield-Mask: 0x01)                       */
#define SYSTEM_CTRL0_RSTINFO_WWDGRST_Pos  (3UL)                     /*!< WWDGRST (Bit 3)                                       */
#define SYSTEM_CTRL0_RSTINFO_WWDGRST_Msk  (0x8UL)                   /*!< WWDGRST (Bitfield-Mask: 0x01)                         */
#define SYSTEM_CTRL0_RSTINFO_EOSFAILRST_Pos (4UL)                   /*!< EOSFAILRST (Bit 4)                                    */
#define SYSTEM_CTRL0_RSTINFO_EOSFAILRST_Msk (0x10UL)                /*!< EOSFAILRST (Bitfield-Mask: 0x01)                      */
#define SYSTEM_CTRL0_RSTINFO_FDFAILRST_Pos (5UL)                    /*!< FDFAILRST (Bit 5)                                     */
#define SYSTEM_CTRL0_RSTINFO_FDFAILRST_Msk (0x20UL)                 /*!< FDFAILRST (Bitfield-Mask: 0x01)                       */
#define SYSTEM_CTRL0_RSTINFO_PORST_Pos    (6UL)                     /*!< PORST (Bit 6)                                         */
#define SYSTEM_CTRL0_RSTINFO_PORST_Msk    (0x40UL)                  /*!< PORST (Bitfield-Mask: 0x01)                           */
#define SYSTEM_CTRL0_RSTINFO_EXRST_Pos    (7UL)                     /*!< EXRST (Bit 7)                                         */
#define SYSTEM_CTRL0_RSTINFO_EXRST_Msk    (0x80UL)                  /*!< EXRST (Bitfield-Mask: 0x01)                           */
#define SYSTEM_CTRL0_RSTINFO_LVD5VRST_Pos (8UL)                     /*!< LVD5VRST (Bit 8)                                      */
#define SYSTEM_CTRL0_RSTINFO_LVD5VRST_Msk (0x100UL)                 /*!< LVD5VRST (Bitfield-Mask: 0x01)                        */
#define SYSTEM_CTRL0_RSTINFO_LVD1V5RST_Pos (9UL)                    /*!< LVD1V5RST (Bit 9)                                     */
#define SYSTEM_CTRL0_RSTINFO_LVD1V5RST_Msk (0x200UL)                /*!< LVD1V5RST (Bitfield-Mask: 0x01)                       */
/* =======================================================  RETRIMING  ======================================================= */
#define SYSTEM_CTRL0_RETRIMING_RETRIMING_CTRL_Pos (0UL)             /*!< RETRIMING_CTRL (Bit 0)                                */
#define SYSTEM_CTRL0_RETRIMING_RETRIMING_CTRL_Msk (0xffffUL)        /*!< RETRIMING_CTRL (Bitfield-Mask: 0xffff)                */
/* =======================================================  RSTENCTRL  ======================================================= */
#define SYSTEM_CTRL0_RSTENCTRL_EOSFAILRSTEN_Pos (4UL)               /*!< EOSFAILRSTEN (Bit 4)                                  */
#define SYSTEM_CTRL0_RSTENCTRL_EOSFAILRSTEN_Msk (0x10UL)            /*!< EOSFAILRSTEN (Bitfield-Mask: 0x01)                    */
#define SYSTEM_CTRL0_RSTENCTRL_FDFAILRSTEN_Pos (5UL)                /*!< FDFAILRSTEN (Bit 5)                                   */
#define SYSTEM_CTRL0_RSTENCTRL_FDFAILRSTEN_Msk (0x20UL)             /*!< FDFAILRSTEN (Bitfield-Mask: 0x01)                     */
#define SYSTEM_CTRL0_RSTENCTRL_BGRSTEN_Pos (6UL)                    /*!< BGRSTEN (Bit 6)                                       */
#define SYSTEM_CTRL0_RSTENCTRL_BGRSTEN_Msk (0x40UL)                 /*!< BGRSTEN (Bitfield-Mask: 0x01)                         */
#define SYSTEM_CTRL0_RSTENCTRL_VDDLVDRSTEN_Pos (8UL)                /*!< VDDLVDRSTEN (Bit 8)                                   */
#define SYSTEM_CTRL0_RSTENCTRL_VDDLVDRSTEN_Msk (0x100UL)            /*!< VDDLVDRSTEN (Bitfield-Mask: 0x01)                     */
#define SYSTEM_CTRL0_RSTENCTRL_LDOLVDRSTEN_Pos (9UL)                /*!< LDOLVDRSTEN (Bit 9)                                   */
#define SYSTEM_CTRL0_RSTENCTRL_LDOLVDRSTEN_Msk (0x200UL)            /*!< LDOLVDRSTEN (Bitfield-Mask: 0x01)                     */
#define SYSTEM_CTRL0_RSTENCTRL_RETRIMINGEN_Pos (10UL)               /*!< RETRIMINGEN (Bit 10)                                  */
#define SYSTEM_CTRL0_RSTENCTRL_RETRIMINGEN_Msk (0x400UL)            /*!< RETRIMINGEN (Bitfield-Mask: 0x01)                     */
/* ===================================================  CUSTOMER_ID_INFO  ==================================================== */
#define SYSTEM_CTRL0_CUSTOMER_ID_INFO_CUSTOMER_ID_Pos (0UL)         /*!< CUSTOMER_ID (Bit 0)                                   */
#define SYSTEM_CTRL0_CUSTOMER_ID_INFO_CUSTOMER_ID_Msk (0xffffffffUL) /*!< CUSTOMER_ID (Bitfield-Mask: 0xffffffff)              */
/* =====================================================  FLASH_PROTECT  ===================================================== */
#define SYSTEM_CTRL0_FLASH_PROTECT_PROTECT_Pos (0UL)                /*!< PROTECT (Bit 0)                                       */
#define SYSTEM_CTRL0_FLASH_PROTECT_PROTECT_Msk (0x1UL)              /*!< PROTECT (Bitfield-Mask: 0x01)                         */
/* =====================================================  AGENT_ID_INFO  ===================================================== */
#define SYSTEM_CTRL0_AGENT_ID_INFO_AGENT_ID_Pos (0UL)               /*!< AGENT_ID (Bit 0)                                      */
#define SYSTEM_CTRL0_AGENT_ID_INFO_AGENT_ID_Msk (0xffffffffUL)      /*!< AGENT_ID (Bitfield-Mask: 0xffffffff)                  */
/* =======================================================  UID_INFO1  ======================================================= */
#define SYSTEM_CTRL0_UID_INFO1_UID_INFO1_Pos (0UL)                  /*!< UID_INFO1 (Bit 0)                                     */
#define SYSTEM_CTRL0_UID_INFO1_UID_INFO1_Msk (0xffffffffUL)         /*!< UID_INFO1 (Bitfield-Mask: 0xffffffff)                 */
/* =======================================================  UID_INFO2  ======================================================= */
#define SYSTEM_CTRL0_UID_INFO2_UID_INFO2_Pos (0UL)                  /*!< UID_INFO2 (Bit 0)                                     */
#define SYSTEM_CTRL0_UID_INFO2_UID_INFO2_Msk (0xffffffffUL)         /*!< UID_INFO2 (Bitfield-Mask: 0xffffffff)                 */
/* =======================================================  UID_INFO3  ======================================================= */
#define SYSTEM_CTRL0_UID_INFO3_UID_INFO3_Pos (0UL)                  /*!< UID_INFO3 (Bit 0)                                     */
#define SYSTEM_CTRL0_UID_INFO3_UID_INFO3_Msk (0xffffffffUL)         /*!< UID_INFO3 (Bitfield-Mask: 0xffffffff)                 */
/* =======================================================  CID_INFO  ======================================================== */
#define SYSTEM_CTRL0_CID_INFO_FLASH_SIZE_Pos (0UL)                  /*!< FLASH_SIZE (Bit 0)                                    */
#define SYSTEM_CTRL0_CID_INFO_FLASH_SIZE_Msk (0xfUL)                /*!< FLASH_SIZE (Bitfield-Mask: 0x0f)                      */
#define SYSTEM_CTRL0_CID_INFO_SRAM_SIZE_Pos (4UL)                   /*!< SRAM_SIZE (Bit 4)                                     */
#define SYSTEM_CTRL0_CID_INFO_SRAM_SIZE_Msk (0xf0UL)                /*!< SRAM_SIZE (Bitfield-Mask: 0x0f)                       */
#define SYSTEM_CTRL0_CID_INFO_PACK_Pos    (8UL)                     /*!< PACK (Bit 8)                                          */
#define SYSTEM_CTRL0_CID_INFO_PACK_Msk    (0x100UL)                 /*!< PACK (Bitfield-Mask: 0x01)                            */
#define SYSTEM_CTRL0_CID_INFO_CID_Pos     (9UL)                     /*!< CID (Bit 9)                                           */
#define SYSTEM_CTRL0_CID_INFO_CID_Msk     (0xfffffe00UL)            /*!< CID (Bitfield-Mask: 0x7fffff)                         */
/* =========================================================  PID0  ========================================================== */
#define SYSTEM_CTRL0_PID0_JEP106CODE_Pos  (0UL)                     /*!< JEP106CODE (Bit 0)                                    */
#define SYSTEM_CTRL0_PID0_JEP106CODE_Msk  (0xfUL)                   /*!< JEP106CODE (Bitfield-Mask: 0x0f)                      */
#define SYSTEM_CTRL0_PID0_BLOCKCOUNT_Pos  (4UL)                     /*!< BLOCKCOUNT (Bit 4)                                    */
#define SYSTEM_CTRL0_PID0_BLOCKCOUNT_Msk  (0xf0UL)                  /*!< BLOCKCOUNT (Bitfield-Mask: 0x0f)                      */
/* =========================================================  PID1  ========================================================== */
/* =========================================================  PID2  ========================================================== */
/* =========================================================  PID3  ========================================================== */
/* =========================================================  PID4  ========================================================== */
#define SYSTEM_CTRL0_PID4_Part_Number_Pos (0UL)                     /*!< Part_Number (Bit 0)                                   */
#define SYSTEM_CTRL0_PID4_Part_Number_Msk (0xffUL)                  /*!< Part_Number (Bitfield-Mask: 0xff)                     */
/* =========================================================  PID5  ========================================================== */
#define SYSTEM_CTRL0_PID5_Part_Number_Pos (0UL)                     /*!< Part_Number (Bit 0)                                   */
#define SYSTEM_CTRL0_PID5_Part_Number_Msk (0xfUL)                   /*!< Part_Number (Bitfield-Mask: 0x0f)                     */
#define SYSTEM_CTRL0_PID5_jep106_id_3_0_Pos (4UL)                   /*!< jep106_id_3_0 (Bit 4)                                 */
#define SYSTEM_CTRL0_PID5_jep106_id_3_0_Msk (0xf0UL)                /*!< jep106_id_3_0 (Bitfield-Mask: 0x0f)                   */
/* =========================================================  PID6  ========================================================== */
#define SYSTEM_CTRL0_PID6_jep106_id_6_4_Pos (0UL)                   /*!< jep106_id_6_4 (Bit 0)                                 */
#define SYSTEM_CTRL0_PID6_jep106_id_6_4_Msk (0x7UL)                 /*!< jep106_id_6_4 (Bitfield-Mask: 0x07)                   */
#define SYSTEM_CTRL0_PID6_jedec_used_Pos  (3UL)                     /*!< jedec_used (Bit 3)                                    */
#define SYSTEM_CTRL0_PID6_jedec_used_Msk  (0x8UL)                   /*!< jedec_used (Bitfield-Mask: 0x01)                      */
#define SYSTEM_CTRL0_PID6_revision_Pos    (4UL)                     /*!< revision (Bit 4)                                      */
#define SYSTEM_CTRL0_PID6_revision_Msk    (0xf0UL)                  /*!< revision (Bitfield-Mask: 0x0f)                        */
/* =========================================================  PID7  ========================================================== */
#define SYSTEM_CTRL0_PID7_customer_modification_number_Pos (0UL)    /*!< customer_modification_number (Bit 0)                  */
#define SYSTEM_CTRL0_PID7_customer_modification_number_Msk (0xfUL)  /*!< customer_modification_number (Bitfield-Mask: 0x0f)    */
#define SYSTEM_CTRL0_PID7_ECO_revision_number_Pos (4UL)             /*!< ECO_revision_number (Bit 4)                           */
#define SYSTEM_CTRL0_PID7_ECO_revision_number_Msk (0x0UL)           /*!< ECO_revision_number (Bitfield-Mask: 0x00)             */ Even number for MASK detected!
/* =========================================================  CID0  ========================================================== */
#define SYSTEM_CTRL0_CID0_CID0_Pos        (0UL)                     /*!< CID0 (Bit 0)                                          */
#define SYSTEM_CTRL0_CID0_CID0_Msk        (0xffffffffUL)            /*!< CID0 (Bitfield-Mask: 0xffffffff)                      */
/* =========================================================  CID1  ========================================================== */
#define SYSTEM_CTRL0_CID1_CID1_Pos        (0UL)                     /*!< CID1 (Bit 0)                                          */
#define SYSTEM_CTRL0_CID1_CID1_Msk        (0xffffffffUL)            /*!< CID1 (Bitfield-Mask: 0xffffffff)                      */
/* =========================================================  CID2  ========================================================== */
#define SYSTEM_CTRL0_CID2_CID2_Pos        (0UL)                     /*!< CID2 (Bit 0)                                          */
#define SYSTEM_CTRL0_CID2_CID2_Msk        (0xffffffffUL)            /*!< CID2 (Bitfield-Mask: 0xffffffff)                      */
/* =========================================================  CID3  ========================================================== */
#define SYSTEM_CTRL0_CID3_CID3_Pos        (0UL)                     /*!< CID3 (Bit 0)                                          */
#define SYSTEM_CTRL0_CID3_CID3_Msk        (0xffffffffUL)            /*!< CID3 (Bitfield-Mask: 0xffffffff)                      */


/* =========================================================================================================================== */
/* ================                                       SYSTEM_CTRL1                                        ================ */
/* =========================================================================================================================== */

/* ==========================================================  SCR  ========================================================== */
#define SYSTEM_CTRL1_SCR_SLEEPONEXIT_Pos  (1UL)                     /*!< SLEEPONEXIT (Bit 1)                                   */
#define SYSTEM_CTRL1_SCR_SLEEPONEXIT_Msk  (0x2UL)                   /*!< SLEEPONEXIT (Bitfield-Mask: 0x01)                     */
#define SYSTEM_CTRL1_SCR_SLEEPDEEP_Pos    (2UL)                     /*!< SLEEPDEEP (Bit 2)                                     */
#define SYSTEM_CTRL1_SCR_SLEEPDEEP_Msk    (0x4UL)                   /*!< SLEEPDEEP (Bitfield-Mask: 0x01)                       */
#define SYSTEM_CTRL1_SCR_SEVONPEND_Pos    (4UL)                     /*!< SEVONPEND (Bit 4)                                     */
#define SYSTEM_CTRL1_SCR_SEVONPEND_Msk    (0x10UL)                  /*!< SEVONPEND (Bitfield-Mask: 0x01)                       */


/* =========================================================================================================================== */
/* ================                                           NVIC                                            ================ */
/* =========================================================================================================================== */

/* =========================================================  ISER  ========================================================== */
#define NVIC_ISER_SWDG_Pos                (0UL)                     /*!< SWDG (Bit 0)                                          */
#define NVIC_ISER_SWDG_Msk                (0x1UL)                   /*!< SWDG (Bitfield-Mask: 0x01)                            */
#define NVIC_ISER_CLK_FAIL_Pos            (1UL)                     /*!< CLK_FAIL (Bit 1)                                      */
#define NVIC_ISER_CLK_FAIL_Msk            (0x2UL)                   /*!< CLK_FAIL (Bitfield-Mask: 0x01)                        */
#define NVIC_ISER_FLASH_Pos               (3UL)                     /*!< FLASH (Bit 3)                                         */
#define NVIC_ISER_FLASH_Msk               (0x8UL)                   /*!< FLASH (Bitfield-Mask: 0x01)                           */
#define NVIC_ISER_PA_Pos                  (5UL)                     /*!< PA (Bit 5)                                            */
#define NVIC_ISER_PA_Msk                  (0x20UL)                  /*!< PA (Bitfield-Mask: 0x01)                              */
#define NVIC_ISER_PB_Pos                  (6UL)                     /*!< PB (Bit 6)                                            */
#define NVIC_ISER_PB_Msk                  (0x40UL)                  /*!< PB (Bitfield-Mask: 0x01)                              */
#define NVIC_ISER_PF_Pos                  (7UL)                     /*!< PF (Bit 7)                                            */
#define NVIC_ISER_PF_Msk                  (0x80UL)                  /*!< PF (Bitfield-Mask: 0x01)                              */
#define NVIC_ISER_COMPARATOR0_Pos         (9UL)                     /*!< COMPARATOR0 (Bit 9)                                   */
#define NVIC_ISER_COMPARATOR0_Msk         (0x200UL)                 /*!< COMPARATOR0 (Bitfield-Mask: 0x01)                     */
#define NVIC_ISER_COMPARATOR1_Pos         (10UL)                    /*!< COMPARATOR1 (Bit 10)                                  */
#define NVIC_ISER_COMPARATOR1_Msk         (0x400UL)                 /*!< COMPARATOR1 (Bitfield-Mask: 0x01)                     */
#define NVIC_ISER_ADC_Pos                 (12UL)                    /*!< ADC (Bit 12)                                          */
#define NVIC_ISER_ADC_Msk                 (0x1000UL)                /*!< ADC (Bitfield-Mask: 0x01)                             */
#define NVIC_ISER_TIMER1_Pos              (13UL)                    /*!< TIMER1 (Bit 13)                                       */
#define NVIC_ISER_TIMER1_Msk              (0x2000UL)                /*!< TIMER1 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISER_TIMER0_Pos              (14UL)                    /*!< TIMER0 (Bit 14)                                       */
#define NVIC_ISER_TIMER0_Msk              (0x4000UL)                /*!< TIMER0 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISER_TIMER4_Pos              (15UL)                    /*!< TIMER4 (Bit 15)                                       */
#define NVIC_ISER_TIMER4_Msk              (0x8000UL)                /*!< TIMER4 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISER_TIMER3_Pos              (16UL)                    /*!< TIMER3 (Bit 16)                                       */
#define NVIC_ISER_TIMER3_Msk              (0x10000UL)               /*!< TIMER3 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISER_TIMER2_Pos              (17UL)                    /*!< TIMER2 (Bit 17)                                       */
#define NVIC_ISER_TIMER2_Msk              (0x20000UL)               /*!< TIMER2 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISER_LED_Pos                 (18UL)                    /*!< LED (Bit 18)                                          */
#define NVIC_ISER_LED_Msk                 (0x40000UL)               /*!< LED (Bitfield-Mask: 0x01)                             */
#define NVIC_ISER_PVD_Pos                 (20UL)                    /*!< PVD (Bit 20)                                          */
#define NVIC_ISER_PVD_Msk                 (0x100000UL)              /*!< PVD (Bitfield-Mask: 0x01)                             */
#define NVIC_ISER_LVD_Pos                 (21UL)                    /*!< LVD (Bit 21)                                          */
#define NVIC_ISER_LVD_Msk                 (0x200000UL)              /*!< LVD (Bitfield-Mask: 0x01)                             */
#define NVIC_ISER_I2C0_Pos                (23UL)                    /*!< I2C0 (Bit 23)                                         */
#define NVIC_ISER_I2C0_Msk                (0x800000UL)              /*!< I2C0 (Bitfield-Mask: 0x01)                            */
#define NVIC_ISER_I2C1_Pos                (24UL)                    /*!< I2C1 (Bit 24)                                         */
#define NVIC_ISER_I2C1_Msk                (0x1000000UL)             /*!< I2C1 (Bitfield-Mask: 0x01)                            */
#define NVIC_ISER_SPI0_Pos                (25UL)                    /*!< SPI0 (Bit 25)                                         */
#define NVIC_ISER_SPI0_Msk                (0x2000000UL)             /*!< SPI0 (Bitfield-Mask: 0x01)                            */
#define NVIC_ISER_SPI1_Pos                (26UL)                    /*!< SPI1 (Bit 26)                                         */
#define NVIC_ISER_SPI1_Msk                (0x4000000UL)             /*!< SPI1 (Bitfield-Mask: 0x01)                            */
#define NVIC_ISER_UART0_Pos               (27UL)                    /*!< UART0 (Bit 27)                                        */
#define NVIC_ISER_UART0_Msk               (0x8000000UL)             /*!< UART0 (Bitfield-Mask: 0x01)                           */
#define NVIC_ISER_UART1_Pos               (28UL)                    /*!< UART1 (Bit 28)                                        */
#define NVIC_ISER_UART1_Msk               (0x10000000UL)            /*!< UART1 (Bitfield-Mask: 0x01)                           */
/* =========================================================  ICER  ========================================================== */
#define NVIC_ICER_SWDG_Pos                (0UL)                     /*!< SWDG (Bit 0)                                          */
#define NVIC_ICER_SWDG_Msk                (0x1UL)                   /*!< SWDG (Bitfield-Mask: 0x01)                            */
#define NVIC_ICER_CLK_FAIL_Pos            (1UL)                     /*!< CLK_FAIL (Bit 1)                                      */
#define NVIC_ICER_CLK_FAIL_Msk            (0x2UL)                   /*!< CLK_FAIL (Bitfield-Mask: 0x01)                        */
#define NVIC_ICER_FLASH_Pos               (3UL)                     /*!< FLASH (Bit 3)                                         */
#define NVIC_ICER_FLASH_Msk               (0x8UL)                   /*!< FLASH (Bitfield-Mask: 0x01)                           */
#define NVIC_ICER_PA_Pos                  (5UL)                     /*!< PA (Bit 5)                                            */
#define NVIC_ICER_PA_Msk                  (0x20UL)                  /*!< PA (Bitfield-Mask: 0x01)                              */
#define NVIC_ICER_PB_Pos                  (6UL)                     /*!< PB (Bit 6)                                            */
#define NVIC_ICER_PB_Msk                  (0x40UL)                  /*!< PB (Bitfield-Mask: 0x01)                              */
#define NVIC_ICER_PF_Pos                  (7UL)                     /*!< PF (Bit 7)                                            */
#define NVIC_ICER_PF_Msk                  (0x80UL)                  /*!< PF (Bitfield-Mask: 0x01)                              */
#define NVIC_ICER_COMPARATOR0_Pos         (9UL)                     /*!< COMPARATOR0 (Bit 9)                                   */
#define NVIC_ICER_COMPARATOR0_Msk         (0x200UL)                 /*!< COMPARATOR0 (Bitfield-Mask: 0x01)                     */
#define NVIC_ICER_COMPARATOR1_Pos         (10UL)                    /*!< COMPARATOR1 (Bit 10)                                  */
#define NVIC_ICER_COMPARATOR1_Msk         (0x400UL)                 /*!< COMPARATOR1 (Bitfield-Mask: 0x01)                     */
#define NVIC_ICER_ADC_Pos                 (12UL)                    /*!< ADC (Bit 12)                                          */
#define NVIC_ICER_ADC_Msk                 (0x1000UL)                /*!< ADC (Bitfield-Mask: 0x01)                             */
#define NVIC_ICER_TIMER1_Pos              (13UL)                    /*!< TIMER1 (Bit 13)                                       */
#define NVIC_ICER_TIMER1_Msk              (0x2000UL)                /*!< TIMER1 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICER_TIMER0_Pos              (14UL)                    /*!< TIMER0 (Bit 14)                                       */
#define NVIC_ICER_TIMER0_Msk              (0x4000UL)                /*!< TIMER0 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICER_TIMER4_Pos              (15UL)                    /*!< TIMER4 (Bit 15)                                       */
#define NVIC_ICER_TIMER4_Msk              (0x8000UL)                /*!< TIMER4 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICER_TIMER3_Pos              (16UL)                    /*!< TIMER3 (Bit 16)                                       */
#define NVIC_ICER_TIMER3_Msk              (0x10000UL)               /*!< TIMER3 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICER_TIMER2_Pos              (17UL)                    /*!< TIMER2 (Bit 17)                                       */
#define NVIC_ICER_TIMER2_Msk              (0x20000UL)               /*!< TIMER2 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICER_LED_Pos                 (18UL)                    /*!< LED (Bit 18)                                          */
#define NVIC_ICER_LED_Msk                 (0x40000UL)               /*!< LED (Bitfield-Mask: 0x01)                             */
#define NVIC_ICER_PVD_Pos                 (20UL)                    /*!< PVD (Bit 20)                                          */
#define NVIC_ICER_PVD_Msk                 (0x100000UL)              /*!< PVD (Bitfield-Mask: 0x01)                             */
#define NVIC_ICER_LVD_Pos                 (21UL)                    /*!< LVD (Bit 21)                                          */
#define NVIC_ICER_LVD_Msk                 (0x200000UL)              /*!< LVD (Bitfield-Mask: 0x01)                             */
#define NVIC_ICER_I2C0_Pos                (23UL)                    /*!< I2C0 (Bit 23)                                         */
#define NVIC_ICER_I2C0_Msk                (0x800000UL)              /*!< I2C0 (Bitfield-Mask: 0x01)                            */
#define NVIC_ICER_I2C1_Pos                (24UL)                    /*!< I2C1 (Bit 24)                                         */
#define NVIC_ICER_I2C1_Msk                (0x1000000UL)             /*!< I2C1 (Bitfield-Mask: 0x01)                            */
#define NVIC_ICER_SPI0_Pos                (25UL)                    /*!< SPI0 (Bit 25)                                         */
#define NVIC_ICER_SPI0_Msk                (0x2000000UL)             /*!< SPI0 (Bitfield-Mask: 0x01)                            */
#define NVIC_ICER_SPI1_Pos                (26UL)                    /*!< SPI1 (Bit 26)                                         */
#define NVIC_ICER_SPI1_Msk                (0x4000000UL)             /*!< SPI1 (Bitfield-Mask: 0x01)                            */
#define NVIC_ICER_UART0_Pos               (27UL)                    /*!< UART0 (Bit 27)                                        */
#define NVIC_ICER_UART0_Msk               (0x8000000UL)             /*!< UART0 (Bitfield-Mask: 0x01)                           */
#define NVIC_ICER_UART1_Pos               (28UL)                    /*!< UART1 (Bit 28)                                        */
#define NVIC_ICER_UART1_Msk               (0x10000000UL)            /*!< UART1 (Bitfield-Mask: 0x01)                           */
/* =========================================================  ISPR  ========================================================== */
#define NVIC_ISPR_SWDG_Pos                (0UL)                     /*!< SWDG (Bit 0)                                          */
#define NVIC_ISPR_SWDG_Msk                (0x1UL)                   /*!< SWDG (Bitfield-Mask: 0x01)                            */
#define NVIC_ISPR_CLK_FAIL_Pos            (1UL)                     /*!< CLK_FAIL (Bit 1)                                      */
#define NVIC_ISPR_CLK_FAIL_Msk            (0x2UL)                   /*!< CLK_FAIL (Bitfield-Mask: 0x01)                        */
#define NVIC_ISPR_FLASH_Pos               (3UL)                     /*!< FLASH (Bit 3)                                         */
#define NVIC_ISPR_FLASH_Msk               (0x8UL)                   /*!< FLASH (Bitfield-Mask: 0x01)                           */
#define NVIC_ISPR_PA_Pos                  (5UL)                     /*!< PA (Bit 5)                                            */
#define NVIC_ISPR_PA_Msk                  (0x20UL)                  /*!< PA (Bitfield-Mask: 0x01)                              */
#define NVIC_ISPR_PB_Pos                  (6UL)                     /*!< PB (Bit 6)                                            */
#define NVIC_ISPR_PB_Msk                  (0x40UL)                  /*!< PB (Bitfield-Mask: 0x01)                              */
#define NVIC_ISPR_PF_Pos                  (7UL)                     /*!< PF (Bit 7)                                            */
#define NVIC_ISPR_PF_Msk                  (0x80UL)                  /*!< PF (Bitfield-Mask: 0x01)                              */
#define NVIC_ISPR_COMPARATOR0_Pos         (9UL)                     /*!< COMPARATOR0 (Bit 9)                                   */
#define NVIC_ISPR_COMPARATOR0_Msk         (0x200UL)                 /*!< COMPARATOR0 (Bitfield-Mask: 0x01)                     */
#define NVIC_ISPR_COMPARATOR1_Pos         (10UL)                    /*!< COMPARATOR1 (Bit 10)                                  */
#define NVIC_ISPR_COMPARATOR1_Msk         (0x400UL)                 /*!< COMPARATOR1 (Bitfield-Mask: 0x01)                     */
#define NVIC_ISPR_ADC_Pos                 (12UL)                    /*!< ADC (Bit 12)                                          */
#define NVIC_ISPR_ADC_Msk                 (0x1000UL)                /*!< ADC (Bitfield-Mask: 0x01)                             */
#define NVIC_ISPR_TIMER1_Pos              (13UL)                    /*!< TIMER1 (Bit 13)                                       */
#define NVIC_ISPR_TIMER1_Msk              (0x2000UL)                /*!< TIMER1 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISPR_TIMER0_Pos              (14UL)                    /*!< TIMER0 (Bit 14)                                       */
#define NVIC_ISPR_TIMER0_Msk              (0x4000UL)                /*!< TIMER0 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISPR_TIMER4_Pos              (15UL)                    /*!< TIMER4 (Bit 15)                                       */
#define NVIC_ISPR_TIMER4_Msk              (0x8000UL)                /*!< TIMER4 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISPR_TIMER3_Pos              (16UL)                    /*!< TIMER3 (Bit 16)                                       */
#define NVIC_ISPR_TIMER3_Msk              (0x10000UL)               /*!< TIMER3 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISPR_TIMER2_Pos              (17UL)                    /*!< TIMER2 (Bit 17)                                       */
#define NVIC_ISPR_TIMER2_Msk              (0x20000UL)               /*!< TIMER2 (Bitfield-Mask: 0x01)                          */
#define NVIC_ISPR_LED_Pos                 (18UL)                    /*!< LED (Bit 18)                                          */
#define NVIC_ISPR_LED_Msk                 (0x40000UL)               /*!< LED (Bitfield-Mask: 0x01)                             */
#define NVIC_ISPR_PVD_Pos                 (20UL)                    /*!< PVD (Bit 20)                                          */
#define NVIC_ISPR_PVD_Msk                 (0x100000UL)              /*!< PVD (Bitfield-Mask: 0x01)                             */
#define NVIC_ISPR_LVD_Pos                 (21UL)                    /*!< LVD (Bit 21)                                          */
#define NVIC_ISPR_LVD_Msk                 (0x200000UL)              /*!< LVD (Bitfield-Mask: 0x01)                             */
#define NVIC_ISPR_I2C0_Pos                (23UL)                    /*!< I2C0 (Bit 23)                                         */
#define NVIC_ISPR_I2C0_Msk                (0x800000UL)              /*!< I2C0 (Bitfield-Mask: 0x01)                            */
#define NVIC_ISPR_I2C1_Pos                (24UL)                    /*!< I2C1 (Bit 24)                                         */
#define NVIC_ISPR_I2C1_Msk                (0x1000000UL)             /*!< I2C1 (Bitfield-Mask: 0x01)                            */
#define NVIC_ISPR_SPI0_Pos                (25UL)                    /*!< SPI0 (Bit 25)                                         */
#define NVIC_ISPR_SPI0_Msk                (0x2000000UL)             /*!< SPI0 (Bitfield-Mask: 0x01)                            */
#define NVIC_ISPR_SPI1_Pos                (26UL)                    /*!< SPI1 (Bit 26)                                         */
#define NVIC_ISPR_SPI1_Msk                (0x4000000UL)             /*!< SPI1 (Bitfield-Mask: 0x01)                            */
#define NVIC_ISPR_UART0_Pos               (27UL)                    /*!< UART0 (Bit 27)                                        */
#define NVIC_ISPR_UART0_Msk               (0x8000000UL)             /*!< UART0 (Bitfield-Mask: 0x01)                           */
#define NVIC_ISPR_UART1_Pos               (28UL)                    /*!< UART1 (Bit 28)                                        */
#define NVIC_ISPR_UART1_Msk               (0x10000000UL)            /*!< UART1 (Bitfield-Mask: 0x01)                           */
/* =========================================================  ICPR  ========================================================== */
#define NVIC_ICPR_SWDG_Pos                (0UL)                     /*!< SWDG (Bit 0)                                          */
#define NVIC_ICPR_SWDG_Msk                (0x1UL)                   /*!< SWDG (Bitfield-Mask: 0x01)                            */
#define NVIC_ICPR_CLK_FAIL_Pos            (1UL)                     /*!< CLK_FAIL (Bit 1)                                      */
#define NVIC_ICPR_CLK_FAIL_Msk            (0x2UL)                   /*!< CLK_FAIL (Bitfield-Mask: 0x01)                        */
#define NVIC_ICPR_FLASH_Pos               (3UL)                     /*!< FLASH (Bit 3)                                         */
#define NVIC_ICPR_FLASH_Msk               (0x8UL)                   /*!< FLASH (Bitfield-Mask: 0x01)                           */
#define NVIC_ICPR_PA_Pos                  (5UL)                     /*!< PA (Bit 5)                                            */
#define NVIC_ICPR_PA_Msk                  (0x20UL)                  /*!< PA (Bitfield-Mask: 0x01)                              */
#define NVIC_ICPR_PB_Pos                  (6UL)                     /*!< PB (Bit 6)                                            */
#define NVIC_ICPR_PB_Msk                  (0x40UL)                  /*!< PB (Bitfield-Mask: 0x01)                              */
#define NVIC_ICPR_PF_Pos                  (7UL)                     /*!< PF (Bit 7)                                            */
#define NVIC_ICPR_PF_Msk                  (0x80UL)                  /*!< PF (Bitfield-Mask: 0x01)                              */
#define NVIC_ICPR_COMPARATOR0_Pos         (9UL)                     /*!< COMPARATOR0 (Bit 9)                                   */
#define NVIC_ICPR_COMPARATOR0_Msk         (0x200UL)                 /*!< COMPARATOR0 (Bitfield-Mask: 0x01)                     */
#define NVIC_ICPR_COMPARATOR1_Pos         (10UL)                    /*!< COMPARATOR1 (Bit 10)                                  */
#define NVIC_ICPR_COMPARATOR1_Msk         (0x400UL)                 /*!< COMPARATOR1 (Bitfield-Mask: 0x01)                     */
#define NVIC_ICPR_ADC_Pos                 (12UL)                    /*!< ADC (Bit 12)                                          */
#define NVIC_ICPR_ADC_Msk                 (0x1000UL)                /*!< ADC (Bitfield-Mask: 0x01)                             */
#define NVIC_ICPR_TIMER1_Pos              (13UL)                    /*!< TIMER1 (Bit 13)                                       */
#define NVIC_ICPR_TIMER1_Msk              (0x2000UL)                /*!< TIMER1 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICPR_TIMER0_Pos              (14UL)                    /*!< TIMER0 (Bit 14)                                       */
#define NVIC_ICPR_TIMER0_Msk              (0x4000UL)                /*!< TIMER0 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICPR_TIMER4_Pos              (15UL)                    /*!< TIMER4 (Bit 15)                                       */
#define NVIC_ICPR_TIMER4_Msk              (0x8000UL)                /*!< TIMER4 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICPR_TIMER3_Pos              (16UL)                    /*!< TIMER3 (Bit 16)                                       */
#define NVIC_ICPR_TIMER3_Msk              (0x10000UL)               /*!< TIMER3 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICPR_TIMER2_Pos              (17UL)                    /*!< TIMER2 (Bit 17)                                       */
#define NVIC_ICPR_TIMER2_Msk              (0x20000UL)               /*!< TIMER2 (Bitfield-Mask: 0x01)                          */
#define NVIC_ICPR_LED_Pos                 (18UL)                    /*!< LED (Bit 18)                                          */
#define NVIC_ICPR_LED_Msk                 (0x40000UL)               /*!< LED (Bitfield-Mask: 0x01)                             */
#define NVIC_ICPR_PVD_Pos                 (20UL)                    /*!< PVD (Bit 20)                                          */
#define NVIC_ICPR_PVD_Msk                 (0x100000UL)              /*!< PVD (Bitfield-Mask: 0x01)                             */
#define NVIC_ICPR_LVD_Pos                 (21UL)                    /*!< LVD (Bit 21)                                          */
#define NVIC_ICPR_LVD_Msk                 (0x200000UL)              /*!< LVD (Bitfield-Mask: 0x01)                             */
#define NVIC_ICPR_I2C0_Pos                (23UL)                    /*!< I2C0 (Bit 23)                                         */
#define NVIC_ICPR_I2C0_Msk                (0x800000UL)              /*!< I2C0 (Bitfield-Mask: 0x01)                            */
#define NVIC_ICPR_I2C1_Pos                (24UL)                    /*!< I2C1 (Bit 24)                                         */
#define NVIC_ICPR_I2C1_Msk                (0x1000000UL)             /*!< I2C1 (Bitfield-Mask: 0x01)                            */
#define NVIC_ICPR_SPI0_Pos                (25UL)                    /*!< SPI0 (Bit 25)                                         */
#define NVIC_ICPR_SPI0_Msk                (0x2000000UL)             /*!< SPI0 (Bitfield-Mask: 0x01)                            */
#define NVIC_ICPR_SPI1_Pos                (26UL)                    /*!< SPI1 (Bit 26)                                         */
#define NVIC_ICPR_SPI1_Msk                (0x4000000UL)             /*!< SPI1 (Bitfield-Mask: 0x01)                            */
#define NVIC_ICPR_UART0_Pos               (27UL)                    /*!< UART0 (Bit 27)                                        */
#define NVIC_ICPR_UART0_Msk               (0x8000000UL)             /*!< UART0 (Bitfield-Mask: 0x01)                           */
#define NVIC_ICPR_UART1_Pos               (28UL)                    /*!< UART1 (Bit 28)                                        */
#define NVIC_ICPR_UART1_Msk               (0x10000000UL)            /*!< UART1 (Bitfield-Mask: 0x01)                           */


/* =========================================================================================================================== */
/* ================                                           GPIOA                                           ================ */
/* =========================================================================================================================== */

/* =========================================================  DATA  ========================================================== */
#define GPIOA_DATA_DATA0_Pos              (0UL)                     /*!< DATA0 (Bit 0)                                         */
#define GPIOA_DATA_DATA0_Msk              (0x1UL)                   /*!< DATA0 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA1_Pos              (1UL)                     /*!< DATA1 (Bit 1)                                         */
#define GPIOA_DATA_DATA1_Msk              (0x2UL)                   /*!< DATA1 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA2_Pos              (2UL)                     /*!< DATA2 (Bit 2)                                         */
#define GPIOA_DATA_DATA2_Msk              (0x4UL)                   /*!< DATA2 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA3_Pos              (3UL)                     /*!< DATA3 (Bit 3)                                         */
#define GPIOA_DATA_DATA3_Msk              (0x8UL)                   /*!< DATA3 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA4_Pos              (4UL)                     /*!< DATA4 (Bit 4)                                         */
#define GPIOA_DATA_DATA4_Msk              (0x10UL)                  /*!< DATA4 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA5_Pos              (5UL)                     /*!< DATA5 (Bit 5)                                         */
#define GPIOA_DATA_DATA5_Msk              (0x20UL)                  /*!< DATA5 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA6_Pos              (6UL)                     /*!< DATA6 (Bit 6)                                         */
#define GPIOA_DATA_DATA6_Msk              (0x40UL)                  /*!< DATA6 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA7_Pos              (7UL)                     /*!< DATA7 (Bit 7)                                         */
#define GPIOA_DATA_DATA7_Msk              (0x80UL)                  /*!< DATA7 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA8_Pos              (8UL)                     /*!< DATA8 (Bit 8)                                         */
#define GPIOA_DATA_DATA8_Msk              (0x100UL)                 /*!< DATA8 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA9_Pos              (9UL)                     /*!< DATA9 (Bit 9)                                         */
#define GPIOA_DATA_DATA9_Msk              (0x200UL)                 /*!< DATA9 (Bitfield-Mask: 0x01)                           */
#define GPIOA_DATA_DATA10_Pos             (10UL)                    /*!< DATA10 (Bit 10)                                       */
#define GPIOA_DATA_DATA10_Msk             (0x400UL)                 /*!< DATA10 (Bitfield-Mask: 0x01)                          */
#define GPIOA_DATA_DATA11_Pos             (11UL)                    /*!< DATA11 (Bit 11)                                       */
#define GPIOA_DATA_DATA11_Msk             (0x800UL)                 /*!< DATA11 (Bitfield-Mask: 0x01)                          */
#define GPIOA_DATA_DATA12_Pos             (12UL)                    /*!< DATA12 (Bit 12)                                       */
#define GPIOA_DATA_DATA12_Msk             (0x1000UL)                /*!< DATA12 (Bitfield-Mask: 0x01)                          */
#define GPIOA_DATA_DATA13_Pos             (13UL)                    /*!< DATA13 (Bit 13)                                       */
#define GPIOA_DATA_DATA13_Msk             (0x2000UL)                /*!< DATA13 (Bitfield-Mask: 0x01)                          */
#define GPIOA_DATA_DATA14_Pos             (14UL)                    /*!< DATA14 (Bit 14)                                       */
#define GPIOA_DATA_DATA14_Msk             (0x4000UL)                /*!< DATA14 (Bitfield-Mask: 0x01)                          */
#define GPIOA_DATA_DATA15_Pos             (15UL)                    /*!< DATA15 (Bit 15)                                       */
#define GPIOA_DATA_DATA15_Msk             (0x8000UL)                /*!< DATA15 (Bitfield-Mask: 0x01)                          */
/* ========================================================  DATAOUT  ======================================================== */
#define GPIOA_DATAOUT_DATAOUT0_Pos        (0UL)                     /*!< DATAOUT0 (Bit 0)                                      */
#define GPIOA_DATAOUT_DATAOUT0_Msk        (0x1UL)                   /*!< DATAOUT0 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT1_Pos        (1UL)                     /*!< DATAOUT1 (Bit 1)                                      */
#define GPIOA_DATAOUT_DATAOUT1_Msk        (0x2UL)                   /*!< DATAOUT1 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT2_Pos        (2UL)                     /*!< DATAOUT2 (Bit 2)                                      */
#define GPIOA_DATAOUT_DATAOUT2_Msk        (0x4UL)                   /*!< DATAOUT2 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT3_Pos        (3UL)                     /*!< DATAOUT3 (Bit 3)                                      */
#define GPIOA_DATAOUT_DATAOUT3_Msk        (0x8UL)                   /*!< DATAOUT3 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT4_Pos        (4UL)                     /*!< DATAOUT4 (Bit 4)                                      */
#define GPIOA_DATAOUT_DATAOUT4_Msk        (0x10UL)                  /*!< DATAOUT4 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT5_Pos        (5UL)                     /*!< DATAOUT5 (Bit 5)                                      */
#define GPIOA_DATAOUT_DATAOUT5_Msk        (0x20UL)                  /*!< DATAOUT5 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT6_Pos        (6UL)                     /*!< DATAOUT6 (Bit 6)                                      */
#define GPIOA_DATAOUT_DATAOUT6_Msk        (0x40UL)                  /*!< DATAOUT6 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT7_Pos        (7UL)                     /*!< DATAOUT7 (Bit 7)                                      */
#define GPIOA_DATAOUT_DATAOUT7_Msk        (0x80UL)                  /*!< DATAOUT7 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT8_Pos        (8UL)                     /*!< DATAOUT8 (Bit 8)                                      */
#define GPIOA_DATAOUT_DATAOUT8_Msk        (0x100UL)                 /*!< DATAOUT8 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT9_Pos        (9UL)                     /*!< DATAOUT9 (Bit 9)                                      */
#define GPIOA_DATAOUT_DATAOUT9_Msk        (0x200UL)                 /*!< DATAOUT9 (Bitfield-Mask: 0x01)                        */
#define GPIOA_DATAOUT_DATAOUT10_Pos       (10UL)                    /*!< DATAOUT10 (Bit 10)                                    */
#define GPIOA_DATAOUT_DATAOUT10_Msk       (0x400UL)                 /*!< DATAOUT10 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DATAOUT_DATAOUT11_Pos       (11UL)                    /*!< DATAOUT11 (Bit 11)                                    */
#define GPIOA_DATAOUT_DATAOUT11_Msk       (0x800UL)                 /*!< DATAOUT11 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DATAOUT_DATAOUT12_Pos       (12UL)                    /*!< DATAOUT12 (Bit 12)                                    */
#define GPIOA_DATAOUT_DATAOUT12_Msk       (0x1000UL)                /*!< DATAOUT12 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DATAOUT_DATAOUT13_Pos       (13UL)                    /*!< DATAOUT13 (Bit 13)                                    */
#define GPIOA_DATAOUT_DATAOUT13_Msk       (0x2000UL)                /*!< DATAOUT13 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DATAOUT_DATAOUT14_Pos       (14UL)                    /*!< DATAOUT14 (Bit 14)                                    */
#define GPIOA_DATAOUT_DATAOUT14_Msk       (0x4000UL)                /*!< DATAOUT14 (Bitfield-Mask: 0x01)                       */
#define GPIOA_DATAOUT_DATAOUT15_Pos       (15UL)                    /*!< DATAOUT15 (Bit 15)                                    */
#define GPIOA_DATAOUT_DATAOUT15_Msk       (0x8000UL)                /*!< DATAOUT15 (Bitfield-Mask: 0x01)                       */
/* =====================================================  OUTENABLESET  ====================================================== */
#define GPIOA_OUTENABLESET_OES0_Pos       (0UL)                     /*!< OES0 (Bit 0)                                          */
#define GPIOA_OUTENABLESET_OES0_Msk       (0x1UL)                   /*!< OES0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES1_Pos       (1UL)                     /*!< OES1 (Bit 1)                                          */
#define GPIOA_OUTENABLESET_OES1_Msk       (0x2UL)                   /*!< OES1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES2_Pos       (2UL)                     /*!< OES2 (Bit 2)                                          */
#define GPIOA_OUTENABLESET_OES2_Msk       (0x4UL)                   /*!< OES2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES3_Pos       (3UL)                     /*!< OES3 (Bit 3)                                          */
#define GPIOA_OUTENABLESET_OES3_Msk       (0x8UL)                   /*!< OES3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES4_Pos       (4UL)                     /*!< OES4 (Bit 4)                                          */
#define GPIOA_OUTENABLESET_OES4_Msk       (0x10UL)                  /*!< OES4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES5_Pos       (5UL)                     /*!< OES5 (Bit 5)                                          */
#define GPIOA_OUTENABLESET_OES5_Msk       (0x20UL)                  /*!< OES5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES6_Pos       (6UL)                     /*!< OES6 (Bit 6)                                          */
#define GPIOA_OUTENABLESET_OES6_Msk       (0x40UL)                  /*!< OES6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES7_Pos       (7UL)                     /*!< OES7 (Bit 7)                                          */
#define GPIOA_OUTENABLESET_OES7_Msk       (0x80UL)                  /*!< OES7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES8_Pos       (8UL)                     /*!< OES8 (Bit 8)                                          */
#define GPIOA_OUTENABLESET_OES8_Msk       (0x100UL)                 /*!< OES8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES9_Pos       (9UL)                     /*!< OES9 (Bit 9)                                          */
#define GPIOA_OUTENABLESET_OES9_Msk       (0x200UL)                 /*!< OES9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLESET_OES10_Pos      (10UL)                    /*!< OES10 (Bit 10)                                        */
#define GPIOA_OUTENABLESET_OES10_Msk      (0x400UL)                 /*!< OES10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLESET_OES11_Pos      (11UL)                    /*!< OES11 (Bit 11)                                        */
#define GPIOA_OUTENABLESET_OES11_Msk      (0x800UL)                 /*!< OES11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLESET_OES12_Pos      (12UL)                    /*!< OES12 (Bit 12)                                        */
#define GPIOA_OUTENABLESET_OES12_Msk      (0x1000UL)                /*!< OES12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLESET_OES13_Pos      (13UL)                    /*!< OES13 (Bit 13)                                        */
#define GPIOA_OUTENABLESET_OES13_Msk      (0x2000UL)                /*!< OES13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLESET_OES14_Pos      (14UL)                    /*!< OES14 (Bit 14)                                        */
#define GPIOA_OUTENABLESET_OES14_Msk      (0x4000UL)                /*!< OES14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLESET_OES15_Pos      (15UL)                    /*!< OES15 (Bit 15)                                        */
#define GPIOA_OUTENABLESET_OES15_Msk      (0x8000UL)                /*!< OES15 (Bitfield-Mask: 0x01)                           */
/* =====================================================  OUTENABLECLR  ====================================================== */
#define GPIOA_OUTENABLECLR_OEC0_Pos       (0UL)                     /*!< OEC0 (Bit 0)                                          */
#define GPIOA_OUTENABLECLR_OEC0_Msk       (0x1UL)                   /*!< OEC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC1_Pos       (1UL)                     /*!< OEC1 (Bit 1)                                          */
#define GPIOA_OUTENABLECLR_OEC1_Msk       (0x2UL)                   /*!< OEC1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC2_Pos       (2UL)                     /*!< OEC2 (Bit 2)                                          */
#define GPIOA_OUTENABLECLR_OEC2_Msk       (0x4UL)                   /*!< OEC2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC3_Pos       (3UL)                     /*!< OEC3 (Bit 3)                                          */
#define GPIOA_OUTENABLECLR_OEC3_Msk       (0x8UL)                   /*!< OEC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC4_Pos       (4UL)                     /*!< OEC4 (Bit 4)                                          */
#define GPIOA_OUTENABLECLR_OEC4_Msk       (0x10UL)                  /*!< OEC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC5_Pos       (5UL)                     /*!< OEC5 (Bit 5)                                          */
#define GPIOA_OUTENABLECLR_OEC5_Msk       (0x20UL)                  /*!< OEC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC6_Pos       (6UL)                     /*!< OEC6 (Bit 6)                                          */
#define GPIOA_OUTENABLECLR_OEC6_Msk       (0x40UL)                  /*!< OEC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC7_Pos       (7UL)                     /*!< OEC7 (Bit 7)                                          */
#define GPIOA_OUTENABLECLR_OEC7_Msk       (0x80UL)                  /*!< OEC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC8_Pos       (8UL)                     /*!< OEC8 (Bit 8)                                          */
#define GPIOA_OUTENABLECLR_OEC8_Msk       (0x100UL)                 /*!< OEC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC9_Pos       (9UL)                     /*!< OEC9 (Bit 9)                                          */
#define GPIOA_OUTENABLECLR_OEC9_Msk       (0x200UL)                 /*!< OEC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_OUTENABLECLR_OEC10_Pos      (10UL)                    /*!< OEC10 (Bit 10)                                        */
#define GPIOA_OUTENABLECLR_OEC10_Msk      (0x400UL)                 /*!< OEC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLECLR_OEC11_Pos      (11UL)                    /*!< OEC11 (Bit 11)                                        */
#define GPIOA_OUTENABLECLR_OEC11_Msk      (0x800UL)                 /*!< OEC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLECLR_OEC12_Pos      (12UL)                    /*!< OEC12 (Bit 12)                                        */
#define GPIOA_OUTENABLECLR_OEC12_Msk      (0x1000UL)                /*!< OEC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLECLR_OEC13_Pos      (13UL)                    /*!< OEC13 (Bit 13)                                        */
#define GPIOA_OUTENABLECLR_OEC13_Msk      (0x2000UL)                /*!< OEC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLECLR_OEC14_Pos      (14UL)                    /*!< OEC14 (Bit 14)                                        */
#define GPIOA_OUTENABLECLR_OEC14_Msk      (0x4000UL)                /*!< OEC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_OUTENABLECLR_OEC15_Pos      (15UL)                    /*!< OEC15 (Bit 15)                                        */
#define GPIOA_OUTENABLECLR_OEC15_Msk      (0x8000UL)                /*!< OEC15 (Bitfield-Mask: 0x01)                           */
/* ======================================================  ALTFUNCSET  ======================================================= */
#define GPIOA_ALTFUNCSET_AFS0_Pos         (0UL)                     /*!< AFS0 (Bit 0)                                          */
#define GPIOA_ALTFUNCSET_AFS0_Msk         (0x7UL)                   /*!< AFS0 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET_AFS1_Pos         (4UL)                     /*!< AFS1 (Bit 4)                                          */
#define GPIOA_ALTFUNCSET_AFS1_Msk         (0x70UL)                  /*!< AFS1 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET_AFS2_Pos         (8UL)                     /*!< AFS2 (Bit 8)                                          */
#define GPIOA_ALTFUNCSET_AFS2_Msk         (0x700UL)                 /*!< AFS2 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET_AFS3_Pos         (12UL)                    /*!< AFS3 (Bit 12)                                         */
#define GPIOA_ALTFUNCSET_AFS3_Msk         (0x7000UL)                /*!< AFS3 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET_AFS4_Pos         (16UL)                    /*!< AFS4 (Bit 16)                                         */
#define GPIOA_ALTFUNCSET_AFS4_Msk         (0x70000UL)               /*!< AFS4 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET_AFS5_Pos         (20UL)                    /*!< AFS5 (Bit 20)                                         */
#define GPIOA_ALTFUNCSET_AFS5_Msk         (0x700000UL)              /*!< AFS5 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET_AFS6_Pos         (24UL)                    /*!< AFS6 (Bit 24)                                         */
#define GPIOA_ALTFUNCSET_AFS6_Msk         (0x7000000UL)             /*!< AFS6 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET_AFS7_Pos         (28UL)                    /*!< AFS7 (Bit 28)                                         */
#define GPIOA_ALTFUNCSET_AFS7_Msk         (0x70000000UL)            /*!< AFS7 (Bitfield-Mask: 0x07)                            */
/* ======================================================  ALTFUNCCLR  ======================================================= */
#define GPIOA_ALTFUNCCLR_AFC0_Pos         (0UL)                     /*!< AFC0 (Bit 0)                                          */
#define GPIOA_ALTFUNCCLR_AFC0_Msk         (0x1UL)                   /*!< AFC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC1_Pos         (1UL)                     /*!< AFC1 (Bit 1)                                          */
#define GPIOA_ALTFUNCCLR_AFC1_Msk         (0x2UL)                   /*!< AFC1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC2_Pos         (2UL)                     /*!< AFC2 (Bit 2)                                          */
#define GPIOA_ALTFUNCCLR_AFC2_Msk         (0x4UL)                   /*!< AFC2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC3_Pos         (3UL)                     /*!< AFC3 (Bit 3)                                          */
#define GPIOA_ALTFUNCCLR_AFC3_Msk         (0x8UL)                   /*!< AFC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC4_Pos         (4UL)                     /*!< AFC4 (Bit 4)                                          */
#define GPIOA_ALTFUNCCLR_AFC4_Msk         (0x10UL)                  /*!< AFC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC5_Pos         (5UL)                     /*!< AFC5 (Bit 5)                                          */
#define GPIOA_ALTFUNCCLR_AFC5_Msk         (0x20UL)                  /*!< AFC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC6_Pos         (6UL)                     /*!< AFC6 (Bit 6)                                          */
#define GPIOA_ALTFUNCCLR_AFC6_Msk         (0x40UL)                  /*!< AFC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC7_Pos         (7UL)                     /*!< AFC7 (Bit 7)                                          */
#define GPIOA_ALTFUNCCLR_AFC7_Msk         (0x80UL)                  /*!< AFC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC8_Pos         (8UL)                     /*!< AFC8 (Bit 8)                                          */
#define GPIOA_ALTFUNCCLR_AFC8_Msk         (0x100UL)                 /*!< AFC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC9_Pos         (9UL)                     /*!< AFC9 (Bit 9)                                          */
#define GPIOA_ALTFUNCCLR_AFC9_Msk         (0x200UL)                 /*!< AFC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ALTFUNCCLR_AFC10_Pos        (10UL)                    /*!< AFC10 (Bit 10)                                        */
#define GPIOA_ALTFUNCCLR_AFC10_Msk        (0x400UL)                 /*!< AFC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ALTFUNCCLR_AFC11_Pos        (11UL)                    /*!< AFC11 (Bit 11)                                        */
#define GPIOA_ALTFUNCCLR_AFC11_Msk        (0x800UL)                 /*!< AFC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ALTFUNCCLR_AFC12_Pos        (12UL)                    /*!< AFC12 (Bit 12)                                        */
#define GPIOA_ALTFUNCCLR_AFC12_Msk        (0x1000UL)                /*!< AFC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ALTFUNCCLR_AFC13_Pos        (13UL)                    /*!< AFC13 (Bit 13)                                        */
#define GPIOA_ALTFUNCCLR_AFC13_Msk        (0x2000UL)                /*!< AFC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ALTFUNCCLR_AFC14_Pos        (14UL)                    /*!< AFC14 (Bit 14)                                        */
#define GPIOA_ALTFUNCCLR_AFC14_Msk        (0x4000UL)                /*!< AFC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ALTFUNCCLR_AFC15_Pos        (15UL)                    /*!< AFC15 (Bit 15)                                        */
#define GPIOA_ALTFUNCCLR_AFC15_Msk        (0x8000UL)                /*!< AFC15 (Bitfield-Mask: 0x01)                           */
/* =======================================================  INTENSET  ======================================================== */
#define GPIOA_INTENSET_IES0_Pos           (0UL)                     /*!< IES0 (Bit 0)                                          */
#define GPIOA_INTENSET_IES0_Msk           (0x1UL)                   /*!< IES0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES1_Pos           (1UL)                     /*!< IES1 (Bit 1)                                          */
#define GPIOA_INTENSET_IES1_Msk           (0x2UL)                   /*!< IES1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES2_Pos           (2UL)                     /*!< IES2 (Bit 2)                                          */
#define GPIOA_INTENSET_IES2_Msk           (0x4UL)                   /*!< IES2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES3_Pos           (3UL)                     /*!< IES3 (Bit 3)                                          */
#define GPIOA_INTENSET_IES3_Msk           (0x8UL)                   /*!< IES3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES4_Pos           (4UL)                     /*!< IES4 (Bit 4)                                          */
#define GPIOA_INTENSET_IES4_Msk           (0x10UL)                  /*!< IES4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES5_Pos           (5UL)                     /*!< IES5 (Bit 5)                                          */
#define GPIOA_INTENSET_IES5_Msk           (0x20UL)                  /*!< IES5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES6_Pos           (6UL)                     /*!< IES6 (Bit 6)                                          */
#define GPIOA_INTENSET_IES6_Msk           (0x40UL)                  /*!< IES6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES7_Pos           (7UL)                     /*!< IES7 (Bit 7)                                          */
#define GPIOA_INTENSET_IES7_Msk           (0x80UL)                  /*!< IES7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES8_Pos           (8UL)                     /*!< IES8 (Bit 8)                                          */
#define GPIOA_INTENSET_IES8_Msk           (0x100UL)                 /*!< IES8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES9_Pos           (9UL)                     /*!< IES9 (Bit 9)                                          */
#define GPIOA_INTENSET_IES9_Msk           (0x200UL)                 /*!< IES9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENSET_IES10_Pos          (10UL)                    /*!< IES10 (Bit 10)                                        */
#define GPIOA_INTENSET_IES10_Msk          (0x400UL)                 /*!< IES10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENSET_IES11_Pos          (11UL)                    /*!< IES11 (Bit 11)                                        */
#define GPIOA_INTENSET_IES11_Msk          (0x800UL)                 /*!< IES11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENSET_D12_Pos            (12UL)                    /*!< D12 (Bit 12)                                          */
#define GPIOA_INTENSET_D12_Msk            (0x1000UL)                /*!< D12 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTENSET_IES13_Pos          (13UL)                    /*!< IES13 (Bit 13)                                        */
#define GPIOA_INTENSET_IES13_Msk          (0x2000UL)                /*!< IES13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENSET_IES14_Pos          (14UL)                    /*!< IES14 (Bit 14)                                        */
#define GPIOA_INTENSET_IES14_Msk          (0x4000UL)                /*!< IES14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENSET_IES15_Pos          (15UL)                    /*!< IES15 (Bit 15)                                        */
#define GPIOA_INTENSET_IES15_Msk          (0x8000UL)                /*!< IES15 (Bitfield-Mask: 0x01)                           */
/* =======================================================  INTENCLR  ======================================================== */
#define GPIOA_INTENCLR_IEC0_Pos           (0UL)                     /*!< IEC0 (Bit 0)                                          */
#define GPIOA_INTENCLR_IEC0_Msk           (0x1UL)                   /*!< IEC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_D1_Pos             (1UL)                     /*!< D1 (Bit 1)                                            */
#define GPIOA_INTENCLR_D1_Msk             (0x2UL)                   /*!< D1 (Bitfield-Mask: 0x01)                              */
#define GPIOA_INTENCLR_IEC2_Pos           (2UL)                     /*!< IEC2 (Bit 2)                                          */
#define GPIOA_INTENCLR_IEC2_Msk           (0x4UL)                   /*!< IEC2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_IEC3_Pos           (3UL)                     /*!< IEC3 (Bit 3)                                          */
#define GPIOA_INTENCLR_IEC3_Msk           (0x8UL)                   /*!< IEC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_IEC4_Pos           (4UL)                     /*!< IEC4 (Bit 4)                                          */
#define GPIOA_INTENCLR_IEC4_Msk           (0x10UL)                  /*!< IEC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_IEC5_Pos           (5UL)                     /*!< IEC5 (Bit 5)                                          */
#define GPIOA_INTENCLR_IEC5_Msk           (0x20UL)                  /*!< IEC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_IEC6_Pos           (6UL)                     /*!< IEC6 (Bit 6)                                          */
#define GPIOA_INTENCLR_IEC6_Msk           (0x40UL)                  /*!< IEC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_IEC7_Pos           (7UL)                     /*!< IEC7 (Bit 7)                                          */
#define GPIOA_INTENCLR_IEC7_Msk           (0x80UL)                  /*!< IEC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_IEC8_Pos           (8UL)                     /*!< IEC8 (Bit 8)                                          */
#define GPIOA_INTENCLR_IEC8_Msk           (0x100UL)                 /*!< IEC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_IEC9_Pos           (9UL)                     /*!< IEC9 (Bit 9)                                          */
#define GPIOA_INTENCLR_IEC9_Msk           (0x200UL)                 /*!< IEC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTENCLR_IEC10_Pos          (10UL)                    /*!< IEC10 (Bit 10)                                        */
#define GPIOA_INTENCLR_IEC10_Msk          (0x400UL)                 /*!< IEC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENCLR_IEC11_Pos          (11UL)                    /*!< IEC11 (Bit 11)                                        */
#define GPIOA_INTENCLR_IEC11_Msk          (0x800UL)                 /*!< IEC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENCLR_IEC12_Pos          (12UL)                    /*!< IEC12 (Bit 12)                                        */
#define GPIOA_INTENCLR_IEC12_Msk          (0x1000UL)                /*!< IEC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENCLR_IEC13_Pos          (13UL)                    /*!< IEC13 (Bit 13)                                        */
#define GPIOA_INTENCLR_IEC13_Msk          (0x2000UL)                /*!< IEC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENCLR_IEC14_Pos          (14UL)                    /*!< IEC14 (Bit 14)                                        */
#define GPIOA_INTENCLR_IEC14_Msk          (0x4000UL)                /*!< IEC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTENCLR_IEC15_Pos          (15UL)                    /*!< IEC15 (Bit 15)                                        */
#define GPIOA_INTENCLR_IEC15_Msk          (0x8000UL)                /*!< IEC15 (Bitfield-Mask: 0x01)                           */
/* ======================================================  INTTYPESET  ======================================================= */
#define GPIOA_INTTYPESET_ITS0_Pos         (0UL)                     /*!< ITS0 (Bit 0)                                          */
#define GPIOA_INTTYPESET_ITS0_Msk         (0x1UL)                   /*!< ITS0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS1_Pos         (1UL)                     /*!< ITS1 (Bit 1)                                          */
#define GPIOA_INTTYPESET_ITS1_Msk         (0x2UL)                   /*!< ITS1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS2_Pos         (2UL)                     /*!< ITS2 (Bit 2)                                          */
#define GPIOA_INTTYPESET_ITS2_Msk         (0x4UL)                   /*!< ITS2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS3_Pos         (3UL)                     /*!< ITS3 (Bit 3)                                          */
#define GPIOA_INTTYPESET_ITS3_Msk         (0x8UL)                   /*!< ITS3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS4_Pos         (4UL)                     /*!< ITS4 (Bit 4)                                          */
#define GPIOA_INTTYPESET_ITS4_Msk         (0x10UL)                  /*!< ITS4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS5_Pos         (5UL)                     /*!< ITS5 (Bit 5)                                          */
#define GPIOA_INTTYPESET_ITS5_Msk         (0x20UL)                  /*!< ITS5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS6_Pos         (6UL)                     /*!< ITS6 (Bit 6)                                          */
#define GPIOA_INTTYPESET_ITS6_Msk         (0x40UL)                  /*!< ITS6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS7_Pos         (7UL)                     /*!< ITS7 (Bit 7)                                          */
#define GPIOA_INTTYPESET_ITS7_Msk         (0x80UL)                  /*!< ITS7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS8_Pos         (8UL)                     /*!< ITS8 (Bit 8)                                          */
#define GPIOA_INTTYPESET_ITS8_Msk         (0x100UL)                 /*!< ITS8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS9_Pos         (9UL)                     /*!< ITS9 (Bit 9)                                          */
#define GPIOA_INTTYPESET_ITS9_Msk         (0x200UL)                 /*!< ITS9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET_ITS10_Pos        (10UL)                    /*!< ITS10 (Bit 10)                                        */
#define GPIOA_INTTYPESET_ITS10_Msk        (0x400UL)                 /*!< ITS10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET_ITS11_Pos        (11UL)                    /*!< ITS11 (Bit 11)                                        */
#define GPIOA_INTTYPESET_ITS11_Msk        (0x800UL)                 /*!< ITS11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET_ITS12_Pos        (12UL)                    /*!< ITS12 (Bit 12)                                        */
#define GPIOA_INTTYPESET_ITS12_Msk        (0x1000UL)                /*!< ITS12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET_ITS13_Pos        (13UL)                    /*!< ITS13 (Bit 13)                                        */
#define GPIOA_INTTYPESET_ITS13_Msk        (0x2000UL)                /*!< ITS13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET_ITS14_Pos        (14UL)                    /*!< ITS14 (Bit 14)                                        */
#define GPIOA_INTTYPESET_ITS14_Msk        (0x4000UL)                /*!< ITS14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET_ITS15_Pos        (15UL)                    /*!< ITS15 (Bit 15)                                        */
#define GPIOA_INTTYPESET_ITS15_Msk        (0x8000UL)                /*!< ITS15 (Bitfield-Mask: 0x01)                           */
/* ======================================================  INTTYPECLR  ======================================================= */
#define GPIOA_INTTYPECLR_ITC0_Pos         (0UL)                     /*!< ITC0 (Bit 0)                                          */
#define GPIOA_INTTYPECLR_ITC0_Msk         (0x1UL)                   /*!< ITC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC1_Pos         (1UL)                     /*!< ITC1 (Bit 1)                                          */
#define GPIOA_INTTYPECLR_ITC1_Msk         (0x2UL)                   /*!< ITC1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC2_Pos         (2UL)                     /*!< ITC2 (Bit 2)                                          */
#define GPIOA_INTTYPECLR_ITC2_Msk         (0x4UL)                   /*!< ITC2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC3_Pos         (3UL)                     /*!< ITC3 (Bit 3)                                          */
#define GPIOA_INTTYPECLR_ITC3_Msk         (0x8UL)                   /*!< ITC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC4_Pos         (4UL)                     /*!< ITC4 (Bit 4)                                          */
#define GPIOA_INTTYPECLR_ITC4_Msk         (0x10UL)                  /*!< ITC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC5_Pos         (5UL)                     /*!< ITC5 (Bit 5)                                          */
#define GPIOA_INTTYPECLR_ITC5_Msk         (0x20UL)                  /*!< ITC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC6_Pos         (6UL)                     /*!< ITC6 (Bit 6)                                          */
#define GPIOA_INTTYPECLR_ITC6_Msk         (0x40UL)                  /*!< ITC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC7_Pos         (7UL)                     /*!< ITC7 (Bit 7)                                          */
#define GPIOA_INTTYPECLR_ITC7_Msk         (0x80UL)                  /*!< ITC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC8_Pos         (8UL)                     /*!< ITC8 (Bit 8)                                          */
#define GPIOA_INTTYPECLR_ITC8_Msk         (0x100UL)                 /*!< ITC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC9_Pos         (9UL)                     /*!< ITC9 (Bit 9)                                          */
#define GPIOA_INTTYPECLR_ITC9_Msk         (0x200UL)                 /*!< ITC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR_ITC10_Pos        (10UL)                    /*!< ITC10 (Bit 10)                                        */
#define GPIOA_INTTYPECLR_ITC10_Msk        (0x400UL)                 /*!< ITC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR_ITC11_Pos        (11UL)                    /*!< ITC11 (Bit 11)                                        */
#define GPIOA_INTTYPECLR_ITC11_Msk        (0x800UL)                 /*!< ITC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR_ITC12_Pos        (12UL)                    /*!< ITC12 (Bit 12)                                        */
#define GPIOA_INTTYPECLR_ITC12_Msk        (0x1000UL)                /*!< ITC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR_ITC13_Pos        (13UL)                    /*!< ITC13 (Bit 13)                                        */
#define GPIOA_INTTYPECLR_ITC13_Msk        (0x2000UL)                /*!< ITC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR_ITC14_Pos        (14UL)                    /*!< ITC14 (Bit 14)                                        */
#define GPIOA_INTTYPECLR_ITC14_Msk        (0x4000UL)                /*!< ITC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR_ITC15_Pos        (15UL)                    /*!< ITC15 (Bit 15)                                        */
#define GPIOA_INTTYPECLR_ITC15_Msk        (0x8000UL)                /*!< ITC15 (Bitfield-Mask: 0x01)                           */
/* ======================================================  INTTYPESET1  ====================================================== */
#define GPIOA_INTTYPESET1_ITS0_Pos        (0UL)                     /*!< ITS0 (Bit 0)                                          */
#define GPIOA_INTTYPESET1_ITS0_Msk        (0x1UL)                   /*!< ITS0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS1_Pos        (1UL)                     /*!< ITS1 (Bit 1)                                          */
#define GPIOA_INTTYPESET1_ITS1_Msk        (0x2UL)                   /*!< ITS1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS2_Pos        (2UL)                     /*!< ITS2 (Bit 2)                                          */
#define GPIOA_INTTYPESET1_ITS2_Msk        (0x4UL)                   /*!< ITS2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS3_Pos        (3UL)                     /*!< ITS3 (Bit 3)                                          */
#define GPIOA_INTTYPESET1_ITS3_Msk        (0x8UL)                   /*!< ITS3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS4_Pos        (4UL)                     /*!< ITS4 (Bit 4)                                          */
#define GPIOA_INTTYPESET1_ITS4_Msk        (0x10UL)                  /*!< ITS4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS5_Pos        (5UL)                     /*!< ITS5 (Bit 5)                                          */
#define GPIOA_INTTYPESET1_ITS5_Msk        (0x20UL)                  /*!< ITS5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS6_Pos        (6UL)                     /*!< ITS6 (Bit 6)                                          */
#define GPIOA_INTTYPESET1_ITS6_Msk        (0x40UL)                  /*!< ITS6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS7_Pos        (7UL)                     /*!< ITS7 (Bit 7)                                          */
#define GPIOA_INTTYPESET1_ITS7_Msk        (0x80UL)                  /*!< ITS7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS8_Pos        (8UL)                     /*!< ITS8 (Bit 8)                                          */
#define GPIOA_INTTYPESET1_ITS8_Msk        (0x100UL)                 /*!< ITS8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS9_Pos        (9UL)                     /*!< ITS9 (Bit 9)                                          */
#define GPIOA_INTTYPESET1_ITS9_Msk        (0x200UL)                 /*!< ITS9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPESET1_ITS10_Pos       (10UL)                    /*!< ITS10 (Bit 10)                                        */
#define GPIOA_INTTYPESET1_ITS10_Msk       (0x400UL)                 /*!< ITS10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET1_ITS11_Pos       (11UL)                    /*!< ITS11 (Bit 11)                                        */
#define GPIOA_INTTYPESET1_ITS11_Msk       (0x800UL)                 /*!< ITS11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET1_ITS12_Pos       (12UL)                    /*!< ITS12 (Bit 12)                                        */
#define GPIOA_INTTYPESET1_ITS12_Msk       (0x1000UL)                /*!< ITS12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET1_ITS13_Pos       (13UL)                    /*!< ITS13 (Bit 13)                                        */
#define GPIOA_INTTYPESET1_ITS13_Msk       (0x2000UL)                /*!< ITS13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET1_ITS14_Pos       (14UL)                    /*!< ITS14 (Bit 14)                                        */
#define GPIOA_INTTYPESET1_ITS14_Msk       (0x4000UL)                /*!< ITS14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPESET1_ITS15_Pos       (15UL)                    /*!< ITS15 (Bit 15)                                        */
#define GPIOA_INTTYPESET1_ITS15_Msk       (0x8000UL)                /*!< ITS15 (Bitfield-Mask: 0x01)                           */
/* ======================================================  INTTYPECLR1  ====================================================== */
#define GPIOA_INTTYPECLR1_ITC0_Pos        (0UL)                     /*!< ITC0 (Bit 0)                                          */
#define GPIOA_INTTYPECLR1_ITC0_Msk        (0x1UL)                   /*!< ITC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC1_Pos        (1UL)                     /*!< ITC1 (Bit 1)                                          */
#define GPIOA_INTTYPECLR1_ITC1_Msk        (0x2UL)                   /*!< ITC1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC2_Pos        (2UL)                     /*!< ITC2 (Bit 2)                                          */
#define GPIOA_INTTYPECLR1_ITC2_Msk        (0x4UL)                   /*!< ITC2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC3_Pos        (3UL)                     /*!< ITC3 (Bit 3)                                          */
#define GPIOA_INTTYPECLR1_ITC3_Msk        (0x8UL)                   /*!< ITC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC4_Pos        (4UL)                     /*!< ITC4 (Bit 4)                                          */
#define GPIOA_INTTYPECLR1_ITC4_Msk        (0x10UL)                  /*!< ITC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC5_Pos        (5UL)                     /*!< ITC5 (Bit 5)                                          */
#define GPIOA_INTTYPECLR1_ITC5_Msk        (0x20UL)                  /*!< ITC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC6_Pos        (6UL)                     /*!< ITC6 (Bit 6)                                          */
#define GPIOA_INTTYPECLR1_ITC6_Msk        (0x40UL)                  /*!< ITC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC7_Pos        (7UL)                     /*!< ITC7 (Bit 7)                                          */
#define GPIOA_INTTYPECLR1_ITC7_Msk        (0x80UL)                  /*!< ITC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC8_Pos        (8UL)                     /*!< ITC8 (Bit 8)                                          */
#define GPIOA_INTTYPECLR1_ITC8_Msk        (0x100UL)                 /*!< ITC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC9_Pos        (9UL)                     /*!< ITC9 (Bit 9)                                          */
#define GPIOA_INTTYPECLR1_ITC9_Msk        (0x200UL)                 /*!< ITC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTTYPECLR1_ITC10_Pos       (10UL)                    /*!< ITC10 (Bit 10)                                        */
#define GPIOA_INTTYPECLR1_ITC10_Msk       (0x400UL)                 /*!< ITC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR1_ITC11_Pos       (11UL)                    /*!< ITC11 (Bit 11)                                        */
#define GPIOA_INTTYPECLR1_ITC11_Msk       (0x800UL)                 /*!< ITC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR1_ITC12_Pos       (12UL)                    /*!< ITC12 (Bit 12)                                        */
#define GPIOA_INTTYPECLR1_ITC12_Msk       (0x1000UL)                /*!< ITC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR1_ITC13_Pos       (13UL)                    /*!< ITC13 (Bit 13)                                        */
#define GPIOA_INTTYPECLR1_ITC13_Msk       (0x2000UL)                /*!< ITC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR1_ITC14_Pos       (14UL)                    /*!< ITC14 (Bit 14)                                        */
#define GPIOA_INTTYPECLR1_ITC14_Msk       (0x4000UL)                /*!< ITC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTTYPECLR1_ITC15_Pos       (15UL)                    /*!< ITC15 (Bit 15)                                        */
#define GPIOA_INTTYPECLR1_ITC15_Msk       (0x8000UL)                /*!< ITC15 (Bitfield-Mask: 0x01)                           */
/* =======================================================  INTPOLSET  ======================================================= */
#define GPIOA_INTPOLSET_PLS0_Pos          (0UL)                     /*!< PLS0 (Bit 0)                                          */
#define GPIOA_INTPOLSET_PLS0_Msk          (0x1UL)                   /*!< PLS0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS1_Pos          (1UL)                     /*!< PLS1 (Bit 1)                                          */
#define GPIOA_INTPOLSET_PLS1_Msk          (0x2UL)                   /*!< PLS1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS2_Pos          (2UL)                     /*!< PLS2 (Bit 2)                                          */
#define GPIOA_INTPOLSET_PLS2_Msk          (0x4UL)                   /*!< PLS2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS3_Pos          (3UL)                     /*!< PLS3 (Bit 3)                                          */
#define GPIOA_INTPOLSET_PLS3_Msk          (0x8UL)                   /*!< PLS3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS4_Pos          (4UL)                     /*!< PLS4 (Bit 4)                                          */
#define GPIOA_INTPOLSET_PLS4_Msk          (0x10UL)                  /*!< PLS4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS5_Pos          (5UL)                     /*!< PLS5 (Bit 5)                                          */
#define GPIOA_INTPOLSET_PLS5_Msk          (0x20UL)                  /*!< PLS5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS6_Pos          (6UL)                     /*!< PLS6 (Bit 6)                                          */
#define GPIOA_INTPOLSET_PLS6_Msk          (0x40UL)                  /*!< PLS6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS7_Pos          (7UL)                     /*!< PLS7 (Bit 7)                                          */
#define GPIOA_INTPOLSET_PLS7_Msk          (0x80UL)                  /*!< PLS7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS8_Pos          (8UL)                     /*!< PLS8 (Bit 8)                                          */
#define GPIOA_INTPOLSET_PLS8_Msk          (0x100UL)                 /*!< PLS8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS9_Pos          (9UL)                     /*!< PLS9 (Bit 9)                                          */
#define GPIOA_INTPOLSET_PLS9_Msk          (0x200UL)                 /*!< PLS9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLSET_PLS10_Pos         (10UL)                    /*!< PLS10 (Bit 10)                                        */
#define GPIOA_INTPOLSET_PLS10_Msk         (0x400UL)                 /*!< PLS10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLSET_PLS11_Pos         (11UL)                    /*!< PLS11 (Bit 11)                                        */
#define GPIOA_INTPOLSET_PLS11_Msk         (0x800UL)                 /*!< PLS11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLSET_PLS12_Pos         (12UL)                    /*!< PLS12 (Bit 12)                                        */
#define GPIOA_INTPOLSET_PLS12_Msk         (0x1000UL)                /*!< PLS12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLSET_PLS13_Pos         (13UL)                    /*!< PLS13 (Bit 13)                                        */
#define GPIOA_INTPOLSET_PLS13_Msk         (0x2000UL)                /*!< PLS13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLSET_PLS14_Pos         (14UL)                    /*!< PLS14 (Bit 14)                                        */
#define GPIOA_INTPOLSET_PLS14_Msk         (0x4000UL)                /*!< PLS14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLSET_PLS15_Pos         (15UL)                    /*!< PLS15 (Bit 15)                                        */
#define GPIOA_INTPOLSET_PLS15_Msk         (0x8000UL)                /*!< PLS15 (Bitfield-Mask: 0x01)                           */
/* =======================================================  INTPOLCLR  ======================================================= */
#define GPIOA_INTPOLCLR_PLC0_Pos          (0UL)                     /*!< PLC0 (Bit 0)                                          */
#define GPIOA_INTPOLCLR_PLC0_Msk          (0x1UL)                   /*!< PLC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_PLC1_Pos          (1UL)                     /*!< PLC1 (Bit 1)                                          */
#define GPIOA_INTPOLCLR_PLC1_Msk          (0x2UL)                   /*!< PLC1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_D2_Pos            (2UL)                     /*!< D2 (Bit 2)                                            */
#define GPIOA_INTPOLCLR_D2_Msk            (0x4UL)                   /*!< D2 (Bitfield-Mask: 0x01)                              */
#define GPIOA_INTPOLCLR_PLC3_Pos          (3UL)                     /*!< PLC3 (Bit 3)                                          */
#define GPIOA_INTPOLCLR_PLC3_Msk          (0x8UL)                   /*!< PLC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_PLC4_Pos          (4UL)                     /*!< PLC4 (Bit 4)                                          */
#define GPIOA_INTPOLCLR_PLC4_Msk          (0x10UL)                  /*!< PLC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_PLC5_Pos          (5UL)                     /*!< PLC5 (Bit 5)                                          */
#define GPIOA_INTPOLCLR_PLC5_Msk          (0x20UL)                  /*!< PLC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_PLC6_Pos          (6UL)                     /*!< PLC6 (Bit 6)                                          */
#define GPIOA_INTPOLCLR_PLC6_Msk          (0x40UL)                  /*!< PLC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_PLC7_Pos          (7UL)                     /*!< PLC7 (Bit 7)                                          */
#define GPIOA_INTPOLCLR_PLC7_Msk          (0x80UL)                  /*!< PLC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_PLC8_Pos          (8UL)                     /*!< PLC8 (Bit 8)                                          */
#define GPIOA_INTPOLCLR_PLC8_Msk          (0x100UL)                 /*!< PLC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_PLC9_Pos          (9UL)                     /*!< PLC9 (Bit 9)                                          */
#define GPIOA_INTPOLCLR_PLC9_Msk          (0x200UL)                 /*!< PLC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTPOLCLR_PLC10_Pos         (10UL)                    /*!< PLC10 (Bit 10)                                        */
#define GPIOA_INTPOLCLR_PLC10_Msk         (0x400UL)                 /*!< PLC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLCLR_PLC11_Pos         (11UL)                    /*!< PLC11 (Bit 11)                                        */
#define GPIOA_INTPOLCLR_PLC11_Msk         (0x800UL)                 /*!< PLC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLCLR_PLC12_Pos         (12UL)                    /*!< PLC12 (Bit 12)                                        */
#define GPIOA_INTPOLCLR_PLC12_Msk         (0x1000UL)                /*!< PLC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLCLR_PLC13_Pos         (13UL)                    /*!< PLC13 (Bit 13)                                        */
#define GPIOA_INTPOLCLR_PLC13_Msk         (0x2000UL)                /*!< PLC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLCLR_PLC14_Pos         (14UL)                    /*!< PLC14 (Bit 14)                                        */
#define GPIOA_INTPOLCLR_PLC14_Msk         (0x4000UL)                /*!< PLC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_INTPOLCLR_PLC15_Pos         (15UL)                    /*!< PLC15 (Bit 15)                                        */
#define GPIOA_INTPOLCLR_PLC15_Msk         (0x8000UL)                /*!< PLC15 (Bitfield-Mask: 0x01)                           */
/* ==================================================  INTSTATUS_INTCLEAR  =================================================== */
#define GPIOA_INTSTATUS_INTCLEAR_PR0_Pos  (0UL)                     /*!< PR0 (Bit 0)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR0_Msk  (0x1UL)                   /*!< PR0 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR1_Pos  (1UL)                     /*!< PR1 (Bit 1)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR1_Msk  (0x2UL)                   /*!< PR1 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR2_Pos  (2UL)                     /*!< PR2 (Bit 2)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR2_Msk  (0x4UL)                   /*!< PR2 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR3_Pos  (3UL)                     /*!< PR3 (Bit 3)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR3_Msk  (0x8UL)                   /*!< PR3 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR4_Pos  (4UL)                     /*!< PR4 (Bit 4)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR4_Msk  (0x10UL)                  /*!< PR4 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR5_Pos  (5UL)                     /*!< PR5 (Bit 5)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR5_Msk  (0x20UL)                  /*!< PR5 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR6_Pos  (6UL)                     /*!< PR6 (Bit 6)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR6_Msk  (0x40UL)                  /*!< PR6 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR7_Pos  (7UL)                     /*!< PR7 (Bit 7)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR7_Msk  (0x80UL)                  /*!< PR7 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR8_Pos  (8UL)                     /*!< PR8 (Bit 8)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR8_Msk  (0x100UL)                 /*!< PR8 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR9_Pos  (9UL)                     /*!< PR9 (Bit 9)                                           */
#define GPIOA_INTSTATUS_INTCLEAR_PR9_Msk  (0x200UL)                 /*!< PR9 (Bitfield-Mask: 0x01)                             */
#define GPIOA_INTSTATUS_INTCLEAR_PR10_Pos (10UL)                    /*!< PR10 (Bit 10)                                         */
#define GPIOA_INTSTATUS_INTCLEAR_PR10_Msk (0x400UL)                 /*!< PR10 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTSTATUS_INTCLEAR_PR11_Pos (11UL)                    /*!< PR11 (Bit 11)                                         */
#define GPIOA_INTSTATUS_INTCLEAR_PR11_Msk (0x800UL)                 /*!< PR11 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTSTATUS_INTCLEAR_PR12_Pos (12UL)                    /*!< PR12 (Bit 12)                                         */
#define GPIOA_INTSTATUS_INTCLEAR_PR12_Msk (0x1000UL)                /*!< PR12 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTSTATUS_INTCLEAR_PR13_Pos (13UL)                    /*!< PR13 (Bit 13)                                         */
#define GPIOA_INTSTATUS_INTCLEAR_PR13_Msk (0x2000UL)                /*!< PR13 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTSTATUS_INTCLEAR_PR14_Pos (14UL)                    /*!< PR14 (Bit 14)                                         */
#define GPIOA_INTSTATUS_INTCLEAR_PR14_Msk (0x4000UL)                /*!< PR14 (Bitfield-Mask: 0x01)                            */
#define GPIOA_INTSTATUS_INTCLEAR_PR15_Pos (15UL)                    /*!< PR15 (Bit 15)                                         */
#define GPIOA_INTSTATUS_INTCLEAR_PR15_Msk (0x8000UL)                /*!< PR15 (Bitfield-Mask: 0x01)                            */
/* =======================================================  PULLUPSET  ======================================================= */
#define GPIOA_PULLUPSET_PUS0_Pos          (0UL)                     /*!< PUS0 (Bit 0)                                          */
#define GPIOA_PULLUPSET_PUS0_Msk          (0x1UL)                   /*!< PUS0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS1_Pos          (1UL)                     /*!< PUS1 (Bit 1)                                          */
#define GPIOA_PULLUPSET_PUS1_Msk          (0x2UL)                   /*!< PUS1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS2_Pos          (2UL)                     /*!< PUS2 (Bit 2)                                          */
#define GPIOA_PULLUPSET_PUS2_Msk          (0x4UL)                   /*!< PUS2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS3_Pos          (3UL)                     /*!< PUS3 (Bit 3)                                          */
#define GPIOA_PULLUPSET_PUS3_Msk          (0x8UL)                   /*!< PUS3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS4_Pos          (4UL)                     /*!< PUS4 (Bit 4)                                          */
#define GPIOA_PULLUPSET_PUS4_Msk          (0x10UL)                  /*!< PUS4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS5_Pos          (5UL)                     /*!< PUS5 (Bit 5)                                          */
#define GPIOA_PULLUPSET_PUS5_Msk          (0x20UL)                  /*!< PUS5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS6_Pos          (6UL)                     /*!< PUS6 (Bit 6)                                          */
#define GPIOA_PULLUPSET_PUS6_Msk          (0x40UL)                  /*!< PUS6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS7_Pos          (7UL)                     /*!< PUS7 (Bit 7)                                          */
#define GPIOA_PULLUPSET_PUS7_Msk          (0x80UL)                  /*!< PUS7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS8_Pos          (8UL)                     /*!< PUS8 (Bit 8)                                          */
#define GPIOA_PULLUPSET_PUS8_Msk          (0x100UL)                 /*!< PUS8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS9_Pos          (9UL)                     /*!< PUS9 (Bit 9)                                          */
#define GPIOA_PULLUPSET_PUS9_Msk          (0x200UL)                 /*!< PUS9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPSET_PUS10_Pos         (10UL)                    /*!< PUS10 (Bit 10)                                        */
#define GPIOA_PULLUPSET_PUS10_Msk         (0x400UL)                 /*!< PUS10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPSET_PUS11_Pos         (11UL)                    /*!< PUS11 (Bit 11)                                        */
#define GPIOA_PULLUPSET_PUS11_Msk         (0x800UL)                 /*!< PUS11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPSET_PUS12_Pos         (12UL)                    /*!< PUS12 (Bit 12)                                        */
#define GPIOA_PULLUPSET_PUS12_Msk         (0x1000UL)                /*!< PUS12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPSET_PUS13_Pos         (13UL)                    /*!< PUS13 (Bit 13)                                        */
#define GPIOA_PULLUPSET_PUS13_Msk         (0x2000UL)                /*!< PUS13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPSET_PUS14_Pos         (14UL)                    /*!< PUS14 (Bit 14)                                        */
#define GPIOA_PULLUPSET_PUS14_Msk         (0x4000UL)                /*!< PUS14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPSET_PUS15_Pos         (15UL)                    /*!< PUS15 (Bit 15)                                        */
#define GPIOA_PULLUPSET_PUS15_Msk         (0x8000UL)                /*!< PUS15 (Bitfield-Mask: 0x01)                           */
/* =======================================================  PULLUPCLR  ======================================================= */
#define GPIOA_PULLUPCLR_PUC0_Pos          (0UL)                     /*!< PUC0 (Bit 0)                                          */
#define GPIOA_PULLUPCLR_PUC0_Msk          (0x1UL)                   /*!< PUC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC1_Pos          (1UL)                     /*!< PUC1 (Bit 1)                                          */
#define GPIOA_PULLUPCLR_PUC1_Msk          (0x2UL)                   /*!< PUC1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC2_Pos          (2UL)                     /*!< PUC2 (Bit 2)                                          */
#define GPIOA_PULLUPCLR_PUC2_Msk          (0x4UL)                   /*!< PUC2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC3_Pos          (3UL)                     /*!< PUC3 (Bit 3)                                          */
#define GPIOA_PULLUPCLR_PUC3_Msk          (0x8UL)                   /*!< PUC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC4_Pos          (4UL)                     /*!< PUC4 (Bit 4)                                          */
#define GPIOA_PULLUPCLR_PUC4_Msk          (0x10UL)                  /*!< PUC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC5_Pos          (5UL)                     /*!< PUC5 (Bit 5)                                          */
#define GPIOA_PULLUPCLR_PUC5_Msk          (0x20UL)                  /*!< PUC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC6_Pos          (6UL)                     /*!< PUC6 (Bit 6)                                          */
#define GPIOA_PULLUPCLR_PUC6_Msk          (0x40UL)                  /*!< PUC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC7_Pos          (7UL)                     /*!< PUC7 (Bit 7)                                          */
#define GPIOA_PULLUPCLR_PUC7_Msk          (0x80UL)                  /*!< PUC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC8_Pos          (8UL)                     /*!< PUC8 (Bit 8)                                          */
#define GPIOA_PULLUPCLR_PUC8_Msk          (0x100UL)                 /*!< PUC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC9_Pos          (9UL)                     /*!< PUC9 (Bit 9)                                          */
#define GPIOA_PULLUPCLR_PUC9_Msk          (0x200UL)                 /*!< PUC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLUPCLR_PUC10_Pos         (10UL)                    /*!< PUC10 (Bit 10)                                        */
#define GPIOA_PULLUPCLR_PUC10_Msk         (0x400UL)                 /*!< PUC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPCLR_PUC11_Pos         (11UL)                    /*!< PUC11 (Bit 11)                                        */
#define GPIOA_PULLUPCLR_PUC11_Msk         (0x800UL)                 /*!< PUC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPCLR_PUC12_Pos         (12UL)                    /*!< PUC12 (Bit 12)                                        */
#define GPIOA_PULLUPCLR_PUC12_Msk         (0x1000UL)                /*!< PUC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPCLR_PUC13_Pos         (13UL)                    /*!< PUC13 (Bit 13)                                        */
#define GPIOA_PULLUPCLR_PUC13_Msk         (0x2000UL)                /*!< PUC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPCLR_PUC14_Pos         (14UL)                    /*!< PUC14 (Bit 14)                                        */
#define GPIOA_PULLUPCLR_PUC14_Msk         (0x4000UL)                /*!< PUC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLUPCLR_PUC15_Pos         (15UL)                    /*!< PUC15 (Bit 15)                                        */
#define GPIOA_PULLUPCLR_PUC15_Msk         (0x8000UL)                /*!< PUC15 (Bitfield-Mask: 0x01)                           */
/* ======================================================  PULLDOWNSET  ====================================================== */
#define GPIOA_PULLDOWNSET_PDS0_Pos        (0UL)                     /*!< PDS0 (Bit 0)                                          */
#define GPIOA_PULLDOWNSET_PDS0_Msk        (0x1UL)                   /*!< PDS0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS1_Pos        (1UL)                     /*!< PDS1 (Bit 1)                                          */
#define GPIOA_PULLDOWNSET_PDS1_Msk        (0x2UL)                   /*!< PDS1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS2_Pos        (2UL)                     /*!< PDS2 (Bit 2)                                          */
#define GPIOA_PULLDOWNSET_PDS2_Msk        (0x4UL)                   /*!< PDS2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS3_Pos        (3UL)                     /*!< PDS3 (Bit 3)                                          */
#define GPIOA_PULLDOWNSET_PDS3_Msk        (0x8UL)                   /*!< PDS3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS4_Pos        (4UL)                     /*!< PDS4 (Bit 4)                                          */
#define GPIOA_PULLDOWNSET_PDS4_Msk        (0x10UL)                  /*!< PDS4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS5_Pos        (5UL)                     /*!< PDS5 (Bit 5)                                          */
#define GPIOA_PULLDOWNSET_PDS5_Msk        (0x20UL)                  /*!< PDS5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS6_Pos        (6UL)                     /*!< PDS6 (Bit 6)                                          */
#define GPIOA_PULLDOWNSET_PDS6_Msk        (0x40UL)                  /*!< PDS6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS7_Pos        (7UL)                     /*!< PDS7 (Bit 7)                                          */
#define GPIOA_PULLDOWNSET_PDS7_Msk        (0x80UL)                  /*!< PDS7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS8_Pos        (8UL)                     /*!< PDS8 (Bit 8)                                          */
#define GPIOA_PULLDOWNSET_PDS8_Msk        (0x100UL)                 /*!< PDS8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS9_Pos        (9UL)                     /*!< PDS9 (Bit 9)                                          */
#define GPIOA_PULLDOWNSET_PDS9_Msk        (0x200UL)                 /*!< PDS9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNSET_PDS10_Pos       (10UL)                    /*!< PDS10 (Bit 10)                                        */
#define GPIOA_PULLDOWNSET_PDS10_Msk       (0x400UL)                 /*!< PDS10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNSET_PDS11_Pos       (11UL)                    /*!< PDS11 (Bit 11)                                        */
#define GPIOA_PULLDOWNSET_PDS11_Msk       (0x800UL)                 /*!< PDS11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNSET_PDS12_Pos       (12UL)                    /*!< PDS12 (Bit 12)                                        */
#define GPIOA_PULLDOWNSET_PDS12_Msk       (0x1000UL)                /*!< PDS12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNSET_PDS13_Pos       (13UL)                    /*!< PDS13 (Bit 13)                                        */
#define GPIOA_PULLDOWNSET_PDS13_Msk       (0x2000UL)                /*!< PDS13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNSET_PDS14_Pos       (14UL)                    /*!< PDS14 (Bit 14)                                        */
#define GPIOA_PULLDOWNSET_PDS14_Msk       (0x4000UL)                /*!< PDS14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNSET_PDS15_Pos       (15UL)                    /*!< PDS15 (Bit 15)                                        */
#define GPIOA_PULLDOWNSET_PDS15_Msk       (0x8000UL)                /*!< PDS15 (Bitfield-Mask: 0x01)                           */
/* ======================================================  PULLDOWNCLR  ====================================================== */
#define GPIOA_PULLDOWNCLR_PDC0_Pos        (0UL)                     /*!< PDC0 (Bit 0)                                          */
#define GPIOA_PULLDOWNCLR_PDC0_Msk        (0x1UL)                   /*!< PDC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC1_Pos        (1UL)                     /*!< PDC1 (Bit 1)                                          */
#define GPIOA_PULLDOWNCLR_PDC1_Msk        (0x2UL)                   /*!< PDC1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC2_Pos        (2UL)                     /*!< PDC2 (Bit 2)                                          */
#define GPIOA_PULLDOWNCLR_PDC2_Msk        (0x4UL)                   /*!< PDC2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC3_Pos        (3UL)                     /*!< PDC3 (Bit 3)                                          */
#define GPIOA_PULLDOWNCLR_PDC3_Msk        (0x8UL)                   /*!< PDC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC4_Pos        (4UL)                     /*!< PDC4 (Bit 4)                                          */
#define GPIOA_PULLDOWNCLR_PDC4_Msk        (0x10UL)                  /*!< PDC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC5_Pos        (5UL)                     /*!< PDC5 (Bit 5)                                          */
#define GPIOA_PULLDOWNCLR_PDC5_Msk        (0x20UL)                  /*!< PDC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC6_Pos        (6UL)                     /*!< PDC6 (Bit 6)                                          */
#define GPIOA_PULLDOWNCLR_PDC6_Msk        (0x40UL)                  /*!< PDC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC7_Pos        (7UL)                     /*!< PDC7 (Bit 7)                                          */
#define GPIOA_PULLDOWNCLR_PDC7_Msk        (0x80UL)                  /*!< PDC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC8_Pos        (8UL)                     /*!< PDC8 (Bit 8)                                          */
#define GPIOA_PULLDOWNCLR_PDC8_Msk        (0x100UL)                 /*!< PDC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC9_Pos        (9UL)                     /*!< PDC9 (Bit 9)                                          */
#define GPIOA_PULLDOWNCLR_PDC9_Msk        (0x200UL)                 /*!< PDC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_PULLDOWNCLR_PDC10_Pos       (10UL)                    /*!< PDC10 (Bit 10)                                        */
#define GPIOA_PULLDOWNCLR_PDC10_Msk       (0x400UL)                 /*!< PDC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNCLR_PDC11_Pos       (11UL)                    /*!< PDC11 (Bit 11)                                        */
#define GPIOA_PULLDOWNCLR_PDC11_Msk       (0x800UL)                 /*!< PDC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNCLR_PDC12_Pos       (12UL)                    /*!< PDC12 (Bit 12)                                        */
#define GPIOA_PULLDOWNCLR_PDC12_Msk       (0x1000UL)                /*!< PDC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNCLR_PDC13_Pos       (13UL)                    /*!< PDC13 (Bit 13)                                        */
#define GPIOA_PULLDOWNCLR_PDC13_Msk       (0x2000UL)                /*!< PDC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNCLR_PDC14_Pos       (14UL)                    /*!< PDC14 (Bit 14)                                        */
#define GPIOA_PULLDOWNCLR_PDC14_Msk       (0x4000UL)                /*!< PDC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_PULLDOWNCLR_PDC15_Pos       (15UL)                    /*!< PDC15 (Bit 15)                                        */
#define GPIOA_PULLDOWNCLR_PDC15_Msk       (0x8000UL)                /*!< PDC15 (Bitfield-Mask: 0x01)                           */
/* ========================================================  ODRSET  ========================================================= */
#define GPIOA_ODRSET_ODS0_Pos             (0UL)                     /*!< ODS0 (Bit 0)                                          */
#define GPIOA_ODRSET_ODS0_Msk             (0x1UL)                   /*!< ODS0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS1_Pos             (1UL)                     /*!< ODS1 (Bit 1)                                          */
#define GPIOA_ODRSET_ODS1_Msk             (0x2UL)                   /*!< ODS1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS2_Pos             (2UL)                     /*!< ODS2 (Bit 2)                                          */
#define GPIOA_ODRSET_ODS2_Msk             (0x4UL)                   /*!< ODS2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS3_Pos             (3UL)                     /*!< ODS3 (Bit 3)                                          */
#define GPIOA_ODRSET_ODS3_Msk             (0x8UL)                   /*!< ODS3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS4_Pos             (4UL)                     /*!< ODS4 (Bit 4)                                          */
#define GPIOA_ODRSET_ODS4_Msk             (0x10UL)                  /*!< ODS4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS5_Pos             (5UL)                     /*!< ODS5 (Bit 5)                                          */
#define GPIOA_ODRSET_ODS5_Msk             (0x20UL)                  /*!< ODS5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS6_Pos             (6UL)                     /*!< ODS6 (Bit 6)                                          */
#define GPIOA_ODRSET_ODS6_Msk             (0x40UL)                  /*!< ODS6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS7_Pos             (7UL)                     /*!< ODS7 (Bit 7)                                          */
#define GPIOA_ODRSET_ODS7_Msk             (0x80UL)                  /*!< ODS7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS8_Pos             (8UL)                     /*!< ODS8 (Bit 8)                                          */
#define GPIOA_ODRSET_ODS8_Msk             (0x100UL)                 /*!< ODS8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS9_Pos             (9UL)                     /*!< ODS9 (Bit 9)                                          */
#define GPIOA_ODRSET_ODS9_Msk             (0x200UL)                 /*!< ODS9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRSET_ODS10_Pos            (10UL)                    /*!< ODS10 (Bit 10)                                        */
#define GPIOA_ODRSET_ODS10_Msk            (0x400UL)                 /*!< ODS10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRSET_ODS11_Pos            (11UL)                    /*!< ODS11 (Bit 11)                                        */
#define GPIOA_ODRSET_ODS11_Msk            (0x800UL)                 /*!< ODS11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRSET_ODS12_Pos            (12UL)                    /*!< ODS12 (Bit 12)                                        */
#define GPIOA_ODRSET_ODS12_Msk            (0x1000UL)                /*!< ODS12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRSET_ODS13_Pos            (13UL)                    /*!< ODS13 (Bit 13)                                        */
#define GPIOA_ODRSET_ODS13_Msk            (0x2000UL)                /*!< ODS13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRSET_ODS14_Pos            (14UL)                    /*!< ODS14 (Bit 14)                                        */
#define GPIOA_ODRSET_ODS14_Msk            (0x4000UL)                /*!< ODS14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRSET_ODS15_Pos            (15UL)                    /*!< ODS15 (Bit 15)                                        */
#define GPIOA_ODRSET_ODS15_Msk            (0x8000UL)                /*!< ODS15 (Bitfield-Mask: 0x01)                           */
/* ========================================================  ODRCLR  ========================================================= */
#define GPIOA_ODRCLR_ODC0_Pos             (0UL)                     /*!< ODC0 (Bit 0)                                          */
#define GPIOA_ODRCLR_ODC0_Msk             (0x1UL)                   /*!< ODC0 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC1_Pos             (1UL)                     /*!< ODC1 (Bit 1)                                          */
#define GPIOA_ODRCLR_ODC1_Msk             (0x2UL)                   /*!< ODC1 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC2_Pos             (2UL)                     /*!< ODC2 (Bit 2)                                          */
#define GPIOA_ODRCLR_ODC2_Msk             (0x4UL)                   /*!< ODC2 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC3_Pos             (3UL)                     /*!< ODC3 (Bit 3)                                          */
#define GPIOA_ODRCLR_ODC3_Msk             (0x8UL)                   /*!< ODC3 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC4_Pos             (4UL)                     /*!< ODC4 (Bit 4)                                          */
#define GPIOA_ODRCLR_ODC4_Msk             (0x10UL)                  /*!< ODC4 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC5_Pos             (5UL)                     /*!< ODC5 (Bit 5)                                          */
#define GPIOA_ODRCLR_ODC5_Msk             (0x20UL)                  /*!< ODC5 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC6_Pos             (6UL)                     /*!< ODC6 (Bit 6)                                          */
#define GPIOA_ODRCLR_ODC6_Msk             (0x40UL)                  /*!< ODC6 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC7_Pos             (7UL)                     /*!< ODC7 (Bit 7)                                          */
#define GPIOA_ODRCLR_ODC7_Msk             (0x80UL)                  /*!< ODC7 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC8_Pos             (8UL)                     /*!< ODC8 (Bit 8)                                          */
#define GPIOA_ODRCLR_ODC8_Msk             (0x100UL)                 /*!< ODC8 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC9_Pos             (9UL)                     /*!< ODC9 (Bit 9)                                          */
#define GPIOA_ODRCLR_ODC9_Msk             (0x200UL)                 /*!< ODC9 (Bitfield-Mask: 0x01)                            */
#define GPIOA_ODRCLR_ODC10_Pos            (10UL)                    /*!< ODC10 (Bit 10)                                        */
#define GPIOA_ODRCLR_ODC10_Msk            (0x400UL)                 /*!< ODC10 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRCLR_ODC11_Pos            (11UL)                    /*!< ODC11 (Bit 11)                                        */
#define GPIOA_ODRCLR_ODC11_Msk            (0x800UL)                 /*!< ODC11 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRCLR_ODC12_Pos            (12UL)                    /*!< ODC12 (Bit 12)                                        */
#define GPIOA_ODRCLR_ODC12_Msk            (0x1000UL)                /*!< ODC12 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRCLR_ODC13_Pos            (13UL)                    /*!< ODC13 (Bit 13)                                        */
#define GPIOA_ODRCLR_ODC13_Msk            (0x2000UL)                /*!< ODC13 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRCLR_ODC14_Pos            (14UL)                    /*!< ODC14 (Bit 14)                                        */
#define GPIOA_ODRCLR_ODC14_Msk            (0x4000UL)                /*!< ODC14 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ODRCLR_ODC15_Pos            (15UL)                    /*!< ODC15 (Bit 15)                                        */
#define GPIOA_ODRCLR_ODC15_Msk            (0x8000UL)                /*!< ODC15 (Bitfield-Mask: 0x01)                           */
/* ========================================================  ANASET  ========================================================= */
#define GPIOA_ANASET_ANAS0_Pos            (0UL)                     /*!< ANAS0 (Bit 0)                                         */
#define GPIOA_ANASET_ANAS0_Msk            (0x1UL)                   /*!< ANAS0 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS1_Pos            (1UL)                     /*!< ANAS1 (Bit 1)                                         */
#define GPIOA_ANASET_ANAS1_Msk            (0x2UL)                   /*!< ANAS1 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS2_Pos            (2UL)                     /*!< ANAS2 (Bit 2)                                         */
#define GPIOA_ANASET_ANAS2_Msk            (0x4UL)                   /*!< ANAS2 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS3_Pos            (3UL)                     /*!< ANAS3 (Bit 3)                                         */
#define GPIOA_ANASET_ANAS3_Msk            (0x8UL)                   /*!< ANAS3 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS4_Pos            (4UL)                     /*!< ANAS4 (Bit 4)                                         */
#define GPIOA_ANASET_ANAS4_Msk            (0x10UL)                  /*!< ANAS4 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS5_Pos            (5UL)                     /*!< ANAS5 (Bit 5)                                         */
#define GPIOA_ANASET_ANAS5_Msk            (0x20UL)                  /*!< ANAS5 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS6_Pos            (6UL)                     /*!< ANAS6 (Bit 6)                                         */
#define GPIOA_ANASET_ANAS6_Msk            (0x40UL)                  /*!< ANAS6 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS7_Pos            (7UL)                     /*!< ANAS7 (Bit 7)                                         */
#define GPIOA_ANASET_ANAS7_Msk            (0x80UL)                  /*!< ANAS7 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS8_Pos            (8UL)                     /*!< ANAS8 (Bit 8)                                         */
#define GPIOA_ANASET_ANAS8_Msk            (0x100UL)                 /*!< ANAS8 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS9_Pos            (9UL)                     /*!< ANAS9 (Bit 9)                                         */
#define GPIOA_ANASET_ANAS9_Msk            (0x200UL)                 /*!< ANAS9 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANASET_ANAS10_Pos           (10UL)                    /*!< ANAS10 (Bit 10)                                       */
#define GPIOA_ANASET_ANAS10_Msk           (0x400UL)                 /*!< ANAS10 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANASET_ANAS11_Pos           (11UL)                    /*!< ANAS11 (Bit 11)                                       */
#define GPIOA_ANASET_ANAS11_Msk           (0x800UL)                 /*!< ANAS11 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANASET_ANAS12_Pos           (12UL)                    /*!< ANAS12 (Bit 12)                                       */
#define GPIOA_ANASET_ANAS12_Msk           (0x1000UL)                /*!< ANAS12 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANASET_ANAS13_Pos           (13UL)                    /*!< ANAS13 (Bit 13)                                       */
#define GPIOA_ANASET_ANAS13_Msk           (0x2000UL)                /*!< ANAS13 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANASET_ANAS14_Pos           (14UL)                    /*!< ANAS14 (Bit 14)                                       */
#define GPIOA_ANASET_ANAS14_Msk           (0x4000UL)                /*!< ANAS14 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANASET_ANAS15_Pos           (15UL)                    /*!< ANAS15 (Bit 15)                                       */
#define GPIOA_ANASET_ANAS15_Msk           (0x8000UL)                /*!< ANAS15 (Bitfield-Mask: 0x01)                          */
/* ========================================================  ANACLR  ========================================================= */
#define GPIOA_ANACLR_ANAC0_Pos            (0UL)                     /*!< ANAC0 (Bit 0)                                         */
#define GPIOA_ANACLR_ANAC0_Msk            (0x1UL)                   /*!< ANAC0 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC1_Pos            (1UL)                     /*!< ANAC1 (Bit 1)                                         */
#define GPIOA_ANACLR_ANAC1_Msk            (0x2UL)                   /*!< ANAC1 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC2_Pos            (2UL)                     /*!< ANAC2 (Bit 2)                                         */
#define GPIOA_ANACLR_ANAC2_Msk            (0x4UL)                   /*!< ANAC2 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC3_Pos            (3UL)                     /*!< ANAC3 (Bit 3)                                         */
#define GPIOA_ANACLR_ANAC3_Msk            (0x8UL)                   /*!< ANAC3 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC4_Pos            (4UL)                     /*!< ANAC4 (Bit 4)                                         */
#define GPIOA_ANACLR_ANAC4_Msk            (0x10UL)                  /*!< ANAC4 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC5_Pos            (5UL)                     /*!< ANAC5 (Bit 5)                                         */
#define GPIOA_ANACLR_ANAC5_Msk            (0x20UL)                  /*!< ANAC5 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC6_Pos            (6UL)                     /*!< ANAC6 (Bit 6)                                         */
#define GPIOA_ANACLR_ANAC6_Msk            (0x40UL)                  /*!< ANAC6 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC7_Pos            (7UL)                     /*!< ANAC7 (Bit 7)                                         */
#define GPIOA_ANACLR_ANAC7_Msk            (0x80UL)                  /*!< ANAC7 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC8_Pos            (8UL)                     /*!< ANAC8 (Bit 8)                                         */
#define GPIOA_ANACLR_ANAC8_Msk            (0x100UL)                 /*!< ANAC8 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC9_Pos            (9UL)                     /*!< ANAC9 (Bit 9)                                         */
#define GPIOA_ANACLR_ANAC9_Msk            (0x200UL)                 /*!< ANAC9 (Bitfield-Mask: 0x01)                           */
#define GPIOA_ANACLR_ANAC10_Pos           (10UL)                    /*!< ANAC10 (Bit 10)                                       */
#define GPIOA_ANACLR_ANAC10_Msk           (0x400UL)                 /*!< ANAC10 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANACLR_ANAC11_Pos           (11UL)                    /*!< ANAC11 (Bit 11)                                       */
#define GPIOA_ANACLR_ANAC11_Msk           (0x800UL)                 /*!< ANAC11 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANACLR_ANAC12_Pos           (12UL)                    /*!< ANAC12 (Bit 12)                                       */
#define GPIOA_ANACLR_ANAC12_Msk           (0x1000UL)                /*!< ANAC12 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANACLR_ANAC13_Pos           (13UL)                    /*!< ANAC13 (Bit 13)                                       */
#define GPIOA_ANACLR_ANAC13_Msk           (0x2000UL)                /*!< ANAC13 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANACLR_ANAC14_Pos           (14UL)                    /*!< ANAC14 (Bit 14)                                       */
#define GPIOA_ANACLR_ANAC14_Msk           (0x4000UL)                /*!< ANAC14 (Bitfield-Mask: 0x01)                          */
#define GPIOA_ANACLR_ANAC15_Pos           (15UL)                    /*!< ANAC15 (Bit 15)                                       */
#define GPIOA_ANACLR_ANAC15_Msk           (0x8000UL)                /*!< ANAC15 (Bitfield-Mask: 0x01)                          */
/* ======================================================  ALTFUNCSET1  ====================================================== */
#define GPIOA_ALTFUNCSET1_AFS8_Pos        (0UL)                     /*!< AFS8 (Bit 0)                                          */
#define GPIOA_ALTFUNCSET1_AFS8_Msk        (0x7UL)                   /*!< AFS8 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET1_AFS9_Pos        (4UL)                     /*!< AFS9 (Bit 4)                                          */
#define GPIOA_ALTFUNCSET1_AFS9_Msk        (0x70UL)                  /*!< AFS9 (Bitfield-Mask: 0x07)                            */
#define GPIOA_ALTFUNCSET1_AFS10_Pos       (8UL)                     /*!< AFS10 (Bit 8)                                         */
#define GPIOA_ALTFUNCSET1_AFS10_Msk       (0x700UL)                 /*!< AFS10 (Bitfield-Mask: 0x07)                           */
#define GPIOA_ALTFUNCSET1_AFS11_Pos       (12UL)                    /*!< AFS11 (Bit 12)                                        */
#define GPIOA_ALTFUNCSET1_AFS11_Msk       (0x7000UL)                /*!< AFS11 (Bitfield-Mask: 0x07)                           */
#define GPIOA_ALTFUNCSET1_AFS12_Pos       (16UL)                    /*!< AFS12 (Bit 16)                                        */
#define GPIOA_ALTFUNCSET1_AFS12_Msk       (0x70000UL)               /*!< AFS12 (Bitfield-Mask: 0x07)                           */
#define GPIOA_ALTFUNCSET1_AFS13_Pos       (20UL)                    /*!< AFS13 (Bit 20)                                        */
#define GPIOA_ALTFUNCSET1_AFS13_Msk       (0x700000UL)              /*!< AFS13 (Bitfield-Mask: 0x07)                           */
#define GPIOA_ALTFUNCSET1_AFS14_Pos       (24UL)                    /*!< AFS14 (Bit 24)                                        */
#define GPIOA_ALTFUNCSET1_AFS14_Msk       (0x7000000UL)             /*!< AFS14 (Bitfield-Mask: 0x07)                           */
#define GPIOA_ALTFUNCSET1_AFS15_Pos       (28UL)                    /*!< AFS15 (Bit 28)                                        */
#define GPIOA_ALTFUNCSET1_AFS15_Msk       (0x70000000UL)            /*!< AFS15 (Bitfield-Mask: 0x07)                           */


/* =========================================================================================================================== */
/* ================                                          Systick                                          ================ */
/* =========================================================================================================================== */

/* =======================================================  CORET_CSR  ======================================================= */
#define Systick_CORET_CSR_EN_Pos          (0UL)                     /*!< EN (Bit 0)                                            */
#define Systick_CORET_CSR_EN_Msk          (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define Systick_CORET_CSR_IE_Pos          (1UL)                     /*!< IE (Bit 1)                                            */
#define Systick_CORET_CSR_IE_Msk          (0x2UL)                   /*!< IE (Bitfield-Mask: 0x01)                              */
#define Systick_CORET_CSR_ZF_Pos          (16UL)                    /*!< ZF (Bit 16)                                           */
#define Systick_CORET_CSR_ZF_Msk          (0x10000UL)               /*!< ZF (Bitfield-Mask: 0x01)                              */
/* =======================================================  CORET_RVR  ======================================================= */
#define Systick_CORET_RVR_RELOAD_Pos      (0UL)                     /*!< RELOAD (Bit 0)                                        */
#define Systick_CORET_RVR_RELOAD_Msk      (0xffffffUL)              /*!< RELOAD (Bitfield-Mask: 0xffffff)                      */
/* =======================================================  CORET_CVR  ======================================================= */
#define Systick_CORET_CVR_CURRENT_Pos     (0UL)                     /*!< CURRENT (Bit 0)                                       */
#define Systick_CORET_CVR_CURRENT_Msk     (0xffffffUL)              /*!< CURRENT (Bitfield-Mask: 0xffffff)                     */


/* =========================================================================================================================== */
/* ================                                           TMR0                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  ISR  ========================================================== */
#define TMR0_ISR_MR0_Pos                  (0UL)                     /*!< MR0 (Bit 0)                                           */
#define TMR0_ISR_MR0_Msk                  (0x1UL)                   /*!< MR0 (Bitfield-Mask: 0x01)                             */
#define TMR0_ISR_MR1_Pos                  (1UL)                     /*!< MR1 (Bit 1)                                           */
#define TMR0_ISR_MR1_Msk                  (0x2UL)                   /*!< MR1 (Bitfield-Mask: 0x01)                             */
#define TMR0_ISR_MR2_Pos                  (2UL)                     /*!< MR2 (Bit 2)                                           */
#define TMR0_ISR_MR2_Msk                  (0x4UL)                   /*!< MR2 (Bitfield-Mask: 0x01)                             */
#define TMR0_ISR_MR3_Pos                  (3UL)                     /*!< MR3 (Bit 3)                                           */
#define TMR0_ISR_MR3_Msk                  (0x8UL)                   /*!< MR3 (Bitfield-Mask: 0x01)                             */
#define TMR0_ISR_MR4_Pos                  (4UL)                     /*!< MR4 (Bit 4)                                           */
#define TMR0_ISR_MR4_Msk                  (0x10UL)                  /*!< MR4 (Bitfield-Mask: 0x01)                             */
#define TMR0_ISR_CR1_F_Pos                (5UL)                     /*!< CR1_F (Bit 5)                                         */
#define TMR0_ISR_CR1_F_Msk                (0x20UL)                  /*!< CR1_F (Bitfield-Mask: 0x01)                           */
#define TMR0_ISR_CR1_R_Pos                (6UL)                     /*!< CR1_R (Bit 6)                                         */
#define TMR0_ISR_CR1_R_Msk                (0x40UL)                  /*!< CR1_R (Bitfield-Mask: 0x01)                           */
#define TMR0_ISR_CR2_F_Pos                (7UL)                     /*!< CR2_F (Bit 7)                                         */
#define TMR0_ISR_CR2_F_Msk                (0x80UL)                  /*!< CR2_F (Bitfield-Mask: 0x01)                           */
#define TMR0_ISR_CR2_R_Pos                (8UL)                     /*!< CR2_R (Bit 8)                                         */
#define TMR0_ISR_CR2_R_Msk                (0x100UL)                 /*!< CR2_R (Bitfield-Mask: 0x01)                           */
#define TMR0_ISR_CR3_F_Pos                (9UL)                     /*!< CR3_F (Bit 9)                                         */
#define TMR0_ISR_CR3_F_Msk                (0x200UL)                 /*!< CR3_F (Bitfield-Mask: 0x01)                           */
#define TMR0_ISR_CR3_R_Pos                (10UL)                    /*!< CR3_R (Bit 10)                                        */
#define TMR0_ISR_CR3_R_Msk                (0x400UL)                 /*!< CR3_R (Bitfield-Mask: 0x01)                           */
#define TMR0_ISR_CR4_F_Pos                (11UL)                    /*!< CR4_F (Bit 11)                                        */
#define TMR0_ISR_CR4_F_Msk                (0x800UL)                 /*!< CR4_F (Bitfield-Mask: 0x01)                           */
#define TMR0_ISR_CR4_R_Pos                (12UL)                    /*!< CR4_R (Bit 12)                                        */
#define TMR0_ISR_CR4_R_Msk                (0x1000UL)                /*!< CR4_R (Bitfield-Mask: 0x01)                           */
#define TMR0_ISR_BKI_Pos                  (13UL)                    /*!< BKI (Bit 13)                                          */
#define TMR0_ISR_BKI_Msk                  (0x2000UL)                /*!< BKI (Bitfield-Mask: 0x01)                             */
/* ==========================================================  TCR  ========================================================== */
#define TMR0_TCR_EN_Pos                   (0UL)                     /*!< EN (Bit 0)                                            */
#define TMR0_TCR_EN_Msk                   (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define TMR0_TCR_UPDATE_Pos               (1UL)                     /*!< UPDATE (Bit 1)                                        */
#define TMR0_TCR_UPDATE_Msk               (0x2UL)                   /*!< UPDATE (Bitfield-Mask: 0x01)                          */
#define TMR0_TCR_CLKSEL_Pos               (2UL)                     /*!< CLKSEL (Bit 2)                                        */
#define TMR0_TCR_CLKSEL_Msk               (0x4UL)                   /*!< CLKSEL (Bitfield-Mask: 0x01)                          */
/* ========================================================  INT_RPT  ======================================================== */
#define TMR0_INT_RPT_INT_RPT_Pos          (0UL)                     /*!< INT_RPT (Bit 0)                                       */
#define TMR0_INT_RPT_INT_RPT_Msk          (0xfUL)                   /*!< INT_RPT (Bitfield-Mask: 0x0f)                         */
/* =======================================================  INT_RPTC  ======================================================== */
#define TMR0_INT_RPTC_INT_RPTC_Pos        (0UL)                     /*!< INT_RPTC (Bit 0)                                      */
#define TMR0_INT_RPTC_INT_RPTC_Msk        (0xfUL)                   /*!< INT_RPTC (Bitfield-Mask: 0x0f)                        */
/* ==========================================================  PR  =========================================================== */
#define TMR0_PR_PR_Pos                    (0UL)                     /*!< PR (Bit 0)                                            */
#define TMR0_PR_PR_Msk                    (0xffUL)                  /*!< PR (Bitfield-Mask: 0xff)                              */
/* ==========================================================  PC  =========================================================== */
#define TMR0_PC_PC_Pos                    (0UL)                     /*!< PC (Bit 0)                                            */
#define TMR0_PC_PC_Msk                    (0xffUL)                  /*!< PC (Bitfield-Mask: 0xff)                              */
/* ==========================================================  TC  =========================================================== */
#define TMR0_TC_TC_Pos                    (0UL)                     /*!< TC (Bit 0)                                            */
#define TMR0_TC_TC_Msk                    (0xffffUL)                /*!< TC (Bitfield-Mask: 0xffff)                            */
/* ==========================================================  MCR  ========================================================== */
#define TMR0_MCR_MR0I_Pos                 (0UL)                     /*!< MR0I (Bit 0)                                          */
#define TMR0_MCR_MR0I_Msk                 (0x1UL)                   /*!< MR0I (Bitfield-Mask: 0x01)                            */
#define TMR0_MCR_MR1I_Pos                 (1UL)                     /*!< MR1I (Bit 1)                                          */
#define TMR0_MCR_MR1I_Msk                 (0x2UL)                   /*!< MR1I (Bitfield-Mask: 0x01)                            */
#define TMR0_MCR_MR2I_Pos                 (2UL)                     /*!< MR2I (Bit 2)                                          */
#define TMR0_MCR_MR2I_Msk                 (0x4UL)                   /*!< MR2I (Bitfield-Mask: 0x01)                            */
#define TMR0_MCR_MR3I_Pos                 (3UL)                     /*!< MR3I (Bit 3)                                          */
#define TMR0_MCR_MR3I_Msk                 (0x8UL)                   /*!< MR3I (Bitfield-Mask: 0x01)                            */
#define TMR0_MCR_MR4I_Pos                 (4UL)                     /*!< MR4I (Bit 4)                                          */
#define TMR0_MCR_MR4I_Msk                 (0x10UL)                  /*!< MR4I (Bitfield-Mask: 0x01)                            */
#define TMR0_MCR_MR0S_Pos                 (5UL)                     /*!< MR0S (Bit 5)                                          */
#define TMR0_MCR_MR0S_Msk                 (0x20UL)                  /*!< MR0S (Bitfield-Mask: 0x01)                            */
#define TMR0_MCR_DIR_Pos                  (6UL)                     /*!< DIR (Bit 6)                                           */
#define TMR0_MCR_DIR_Msk                  (0x40UL)                  /*!< DIR (Bitfield-Mask: 0x01)                             */
#define TMR0_MCR_DIR_RV_Pos               (7UL)                     /*!< DIR_RV (Bit 7)                                        */
#define TMR0_MCR_DIR_RV_Msk               (0x80UL)                  /*!< DIR_RV (Bitfield-Mask: 0x01)                          */
/* ==========================================================  MR0  ========================================================== */
#define TMR0_MR0_MR0_Pos                  (0UL)                     /*!< MR0 (Bit 0)                                           */
#define TMR0_MR0_MR0_Msk                  (0xffffUL)                /*!< MR0 (Bitfield-Mask: 0xffff)                           */
/* ==========================================================  MR1  ========================================================== */
#define TMR0_MR1_MR1_Pos                  (0UL)                     /*!< MR1 (Bit 0)                                           */
#define TMR0_MR1_MR1_Msk                  (0xffffUL)                /*!< MR1 (Bitfield-Mask: 0xffff)                           */
/* ==========================================================  MR2  ========================================================== */
#define TMR0_MR2_MR2_Pos                  (0UL)                     /*!< MR2 (Bit 0)                                           */
#define TMR0_MR2_MR2_Msk                  (0xffffUL)                /*!< MR2 (Bitfield-Mask: 0xffff)                           */
/* ==========================================================  MR3  ========================================================== */
#define TMR0_MR3_MR3_Pos                  (0UL)                     /*!< MR3 (Bit 0)                                           */
#define TMR0_MR3_MR3_Msk                  (0xffffUL)                /*!< MR3 (Bitfield-Mask: 0xffff)                           */
/* ==========================================================  MR4  ========================================================== */
#define TMR0_MR4_MR4_Pos                  (0UL)                     /*!< MR4 (Bit 0)                                           */
#define TMR0_MR4_MR4_Msk                  (0xffffUL)                /*!< MR4 (Bitfield-Mask: 0xffff)                           */
/* ==========================================================  CCR  ========================================================== */
#define TMR0_CCR_CAP1RE_Pos               (0UL)                     /*!< CAP1RE (Bit 0)                                        */
#define TMR0_CCR_CAP1RE_Msk               (0x1UL)                   /*!< CAP1RE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP1FE_Pos               (1UL)                     /*!< CAP1FE (Bit 1)                                        */
#define TMR0_CCR_CAP1FE_Msk               (0x2UL)                   /*!< CAP1FE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP1RST_Pos              (2UL)                     /*!< CAP1RST (Bit 2)                                       */
#define TMR0_CCR_CAP1RST_Msk              (0x4UL)                   /*!< CAP1RST (Bitfield-Mask: 0x01)                         */
#define TMR0_CCR_CAP1IE_Pos               (3UL)                     /*!< CAP1IE (Bit 3)                                        */
#define TMR0_CCR_CAP1IE_Msk               (0x8UL)                   /*!< CAP1IE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP2RE_Pos               (4UL)                     /*!< CAP2RE (Bit 4)                                        */
#define TMR0_CCR_CAP2RE_Msk               (0x10UL)                  /*!< CAP2RE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP2FE_Pos               (5UL)                     /*!< CAP2FE (Bit 5)                                        */
#define TMR0_CCR_CAP2FE_Msk               (0x20UL)                  /*!< CAP2FE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP2RST_Pos              (6UL)                     /*!< CAP2RST (Bit 6)                                       */
#define TMR0_CCR_CAP2RST_Msk              (0x40UL)                  /*!< CAP2RST (Bitfield-Mask: 0x01)                         */
#define TMR0_CCR_CAP2IE_Pos               (7UL)                     /*!< CAP2IE (Bit 7)                                        */
#define TMR0_CCR_CAP2IE_Msk               (0x80UL)                  /*!< CAP2IE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP3RE_Pos               (8UL)                     /*!< CAP3RE (Bit 8)                                        */
#define TMR0_CCR_CAP3RE_Msk               (0x100UL)                 /*!< CAP3RE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP3FE_Pos               (9UL)                     /*!< CAP3FE (Bit 9)                                        */
#define TMR0_CCR_CAP3FE_Msk               (0x200UL)                 /*!< CAP3FE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP3RST_Pos              (10UL)                    /*!< CAP3RST (Bit 10)                                      */
#define TMR0_CCR_CAP3RST_Msk              (0x400UL)                 /*!< CAP3RST (Bitfield-Mask: 0x01)                         */
#define TMR0_CCR_CAP3IE_Pos               (11UL)                    /*!< CAP3IE (Bit 11)                                       */
#define TMR0_CCR_CAP3IE_Msk               (0x800UL)                 /*!< CAP3IE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP4RE_Pos               (12UL)                    /*!< CAP4RE (Bit 12)                                       */
#define TMR0_CCR_CAP4RE_Msk               (0x1000UL)                /*!< CAP4RE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP4FE_Pos               (13UL)                    /*!< CAP4FE (Bit 13)                                       */
#define TMR0_CCR_CAP4FE_Msk               (0x2000UL)                /*!< CAP4FE (Bitfield-Mask: 0x01)                          */
#define TMR0_CCR_CAP4RST_Pos              (14UL)                    /*!< CAP4RST (Bit 14)                                      */
#define TMR0_CCR_CAP4RST_Msk              (0x4000UL)                /*!< CAP4RST (Bitfield-Mask: 0x01)                         */
#define TMR0_CCR_CAP4IE_Pos               (15UL)                    /*!< CAP4IE (Bit 15)                                       */
#define TMR0_CCR_CAP4IE_Msk               (0x8000UL)                /*!< CAP4IE (Bitfield-Mask: 0x01)                          */
/* ==========================================================  CR1  ========================================================== */
#define TMR0_CR1_CAP1_Pos                 (0UL)                     /*!< CAP1 (Bit 0)                                          */
#define TMR0_CR1_CAP1_Msk                 (0xffffUL)                /*!< CAP1 (Bitfield-Mask: 0xffff)                          */
#define TMR0_CR1_CAPEDGE_Pos              (16UL)                    /*!< CAPEDGE (Bit 16)                                      */
#define TMR0_CR1_CAPEDGE_Msk              (0x10000UL)               /*!< CAPEDGE (Bitfield-Mask: 0x01)                         */
/* ==========================================================  CR2  ========================================================== */
#define TMR0_CR2_CAP2_Pos                 (0UL)                     /*!< CAP2 (Bit 0)                                          */
#define TMR0_CR2_CAP2_Msk                 (0xffffUL)                /*!< CAP2 (Bitfield-Mask: 0xffff)                          */
#define TMR0_CR2_CAPEDGE_Pos              (16UL)                    /*!< CAPEDGE (Bit 16)                                      */
#define TMR0_CR2_CAPEDGE_Msk              (0x10000UL)               /*!< CAPEDGE (Bitfield-Mask: 0x01)                         */
/* ==========================================================  CR3  ========================================================== */
#define TMR0_CR3_CAP3_Pos                 (0UL)                     /*!< CAP3 (Bit 0)                                          */
#define TMR0_CR3_CAP3_Msk                 (0xffffUL)                /*!< CAP3 (Bitfield-Mask: 0xffff)                          */
#define TMR0_CR3_CAPEDGE_Pos              (16UL)                    /*!< CAPEDGE (Bit 16)                                      */
#define TMR0_CR3_CAPEDGE_Msk              (0x10000UL)               /*!< CAPEDGE (Bitfield-Mask: 0x01)                         */
/* ==========================================================  CR4  ========================================================== */
#define TMR0_CR4_CAP4_Pos                 (0UL)                     /*!< CAP4 (Bit 0)                                          */
#define TMR0_CR4_CAP4_Msk                 (0xffffUL)                /*!< CAP4 (Bitfield-Mask: 0xffff)                          */
#define TMR0_CR4_CAPEDGE_Pos              (16UL)                    /*!< CAPEDGE (Bit 16)                                      */
#define TMR0_CR4_CAPEDGE_Msk              (0x10000UL)               /*!< CAPEDGE (Bitfield-Mask: 0x01)                         */
/* ==========================================================  CMR  ========================================================== */
#define TMR0_CMR_MC1_Pos                  (0UL)                     /*!< MC1 (Bit 0)                                           */
#define TMR0_CMR_MC1_Msk                  (0x3UL)                   /*!< MC1 (Bitfield-Mask: 0x03)                             */
#define TMR0_CMR_MC2_Pos                  (4UL)                     /*!< MC2 (Bit 4)                                           */
#define TMR0_CMR_MC2_Msk                  (0x30UL)                  /*!< MC2 (Bitfield-Mask: 0x03)                             */
#define TMR0_CMR_MC3_Pos                  (8UL)                     /*!< MC3 (Bit 8)                                           */
#define TMR0_CMR_MC3_Msk                  (0x300UL)                 /*!< MC3 (Bitfield-Mask: 0x03)                             */
#define TMR0_CMR_MC4_Pos                  (12UL)                    /*!< MC4 (Bit 12)                                          */
#define TMR0_CMR_MC4_Msk                  (0x3000UL)                /*!< MC4 (Bitfield-Mask: 0x03)                             */
#define TMR0_CMR_PWM1_IDLE_Pos            (16UL)                    /*!< PWM1_IDLE (Bit 16)                                    */
#define TMR0_CMR_PWM1_IDLE_Msk            (0x10000UL)               /*!< PWM1_IDLE (Bitfield-Mask: 0x01)                       */
#define TMR0_CMR_PWM2_IDLE_Pos            (17UL)                    /*!< PWM2_IDLE (Bit 17)                                    */
#define TMR0_CMR_PWM2_IDLE_Msk            (0x20000UL)               /*!< PWM2_IDLE (Bitfield-Mask: 0x01)                       */
#define TMR0_CMR_PWM3_IDLE_Pos            (18UL)                    /*!< PWM3_IDLE (Bit 18)                                    */
#define TMR0_CMR_PWM3_IDLE_Msk            (0x40000UL)               /*!< PWM3_IDLE (Bitfield-Mask: 0x01)                       */
#define TMR0_CMR_PWM4_IDLE_Pos            (19UL)                    /*!< PWM4_IDLE (Bit 19)                                    */
#define TMR0_CMR_PWM4_IDLE_Msk            (0x80000UL)               /*!< PWM4_IDLE (Bitfield-Mask: 0x01)                       */
#define TMR0_CMR_PWM1n_EN_Pos             (20UL)                    /*!< PWM1n_EN (Bit 20)                                     */
#define TMR0_CMR_PWM1n_EN_Msk             (0x100000UL)              /*!< PWM1n_EN (Bitfield-Mask: 0x01)                        */
#define TMR0_CMR_PWM2n_EN_Pos             (21UL)                    /*!< PWM2n_EN (Bit 21)                                     */
#define TMR0_CMR_PWM2n_EN_Msk             (0x200000UL)              /*!< PWM2n_EN (Bitfield-Mask: 0x01)                        */
#define TMR0_CMR_PWM3n_EN_Pos             (22UL)                    /*!< PWM3n_EN (Bit 22)                                     */
#define TMR0_CMR_PWM3n_EN_Msk             (0x400000UL)              /*!< PWM3n_EN (Bitfield-Mask: 0x01)                        */
#define TMR0_CMR_PWM4n_EN_Pos             (23UL)                    /*!< PWM4n_EN (Bit 23)                                     */
#define TMR0_CMR_PWM4n_EN_Msk             (0x800000UL)              /*!< PWM4n_EN (Bitfield-Mask: 0x01)                        */
#define TMR0_CMR_BKE_Pos                  (24UL)                    /*!< BKE (Bit 24)                                          */
#define TMR0_CMR_BKE_Msk                  (0x1000000UL)             /*!< BKE (Bitfield-Mask: 0x01)                             */
#define TMR0_CMR_BKP_Pos                  (25UL)                    /*!< BKP (Bit 25)                                          */
#define TMR0_CMR_BKP_Msk                  (0x2000000UL)             /*!< BKP (Bitfield-Mask: 0x01)                             */
#define TMR0_CMR_BKI_Pos                  (26UL)                    /*!< BKI (Bit 26)                                          */
#define TMR0_CMR_BKI_Msk                  (0x4000000UL)             /*!< BKI (Bitfield-Mask: 0x01)                             */
/* ==========================================================  DT  =========================================================== */
#define TMR0_DT_DT_Pos                    (0UL)                     /*!< DT (Bit 0)                                            */
#define TMR0_DT_DT_Msk                    (0xffUL)                  /*!< DT (Bitfield-Mask: 0xff)                              */


/* =========================================================================================================================== */
/* ================                                           TMR2                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  ISR  ========================================================== */
#define TMR2_ISR_OV_Pos                   (0UL)                     /*!< OV (Bit 0)                                            */
#define TMR2_ISR_OV_Msk                   (0x1UL)                   /*!< OV (Bitfield-Mask: 0x01)                              */
/* ==========================================================  TCR  ========================================================== */
#define TMR2_TCR_EN_Pos                   (0UL)                     /*!< EN (Bit 0)                                            */
#define TMR2_TCR_EN_Msk                   (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define TMR2_TCR_UPDATE_Pos               (1UL)                     /*!< UPDATE (Bit 1)                                        */
#define TMR2_TCR_UPDATE_Msk               (0x2UL)                   /*!< UPDATE (Bitfield-Mask: 0x01)                          */
/* ==========================================================  PR  =========================================================== */
#define TMR2_PR_PR_Pos                    (0UL)                     /*!< PR (Bit 0)                                            */
#define TMR2_PR_PR_Msk                    (0xffUL)                  /*!< PR (Bitfield-Mask: 0xff)                              */
/* ==========================================================  PC  =========================================================== */
#define TMR2_PC_PC_Pos                    (0UL)                     /*!< PC (Bit 0)                                            */
#define TMR2_PC_PC_Msk                    (0xffUL)                  /*!< PC (Bitfield-Mask: 0xff)                              */
/* ==========================================================  TC  =========================================================== */
#define TMR2_TC_TC_Pos                    (0UL)                     /*!< TC (Bit 0)                                            */
#define TMR2_TC_TC_Msk                    (0xffffUL)                /*!< TC (Bitfield-Mask: 0xffff)                            */
/* ==========================================================  MCR  ========================================================== */
#define TMR2_MCR_MR0I_Pos                 (0UL)                     /*!< MR0I (Bit 0)                                          */
#define TMR2_MCR_MR0I_Msk                 (0x1UL)                   /*!< MR0I (Bitfield-Mask: 0x01)                            */
#define TMR2_MCR_MR0R_Pos                 (1UL)                     /*!< MR0R (Bit 1)                                          */
#define TMR2_MCR_MR0R_Msk                 (0x2UL)                   /*!< MR0R (Bitfield-Mask: 0x01)                            */
#define TMR2_MCR_MR0S_Pos                 (2UL)                     /*!< MR0S (Bit 2)                                          */
#define TMR2_MCR_MR0S_Msk                 (0x4UL)                   /*!< MR0S (Bitfield-Mask: 0x01)                            */
#define TMR2_MCR_DIR_Pos                  (3UL)                     /*!< DIR (Bit 3)                                           */
#define TMR2_MCR_DIR_Msk                  (0x8UL)                   /*!< DIR (Bitfield-Mask: 0x01)                             */
/* ==========================================================  MR0  ========================================================== */
#define TMR2_MR0_MR0_Pos                  (0UL)                     /*!< MR0 (Bit 0)                                           */
#define TMR2_MR0_MR0_Msk                  (0xffffUL)                /*!< MR0 (Bitfield-Mask: 0xffff)                           */


/* =========================================================================================================================== */
/* ================                                           BEEP                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  CR  =========================================================== */
#define BEEP_CR_EN_Pos                    (0UL)                     /*!< EN (Bit 0)                                            */
#define BEEP_CR_EN_Msk                    (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define BEEP_CR_CPSR_Pos                  (1UL)                     /*!< CPSR (Bit 1)                                          */
#define BEEP_CR_CPSR_Msk                  (0x3eUL)                  /*!< CPSR (Bitfield-Mask: 0x1f)                            */
#define BEEP_CR_SUBDIV_Pos                (6UL)                     /*!< SUBDIV (Bit 6)                                        */
#define BEEP_CR_SUBDIV_Msk                (0xc0UL)                  /*!< SUBDIV (Bitfield-Mask: 0x03)                          */


/* =========================================================================================================================== */
/* ================                                          SYSWDG                                           ================ */
/* =========================================================================================================================== */

/* ==========================================================  RLR  ========================================================== */
#define SYSWDG_RLR_RL_Pos                 (0UL)                     /*!< RL (Bit 0)                                            */
#define SYSWDG_RLR_RL_Msk                 (0xffffffffUL)            /*!< RL (Bitfield-Mask: 0xffffffff)                        */
/* =========================================================  COUNT  ========================================================= */
#define SYSWDG_COUNT_VALUE_Pos            (0UL)                     /*!< VALUE (Bit 0)                                         */
#define SYSWDG_COUNT_VALUE_Msk            (0xffffffffUL)            /*!< VALUE (Bitfield-Mask: 0xffffffff)                     */
/* ==========================================================  CR  =========================================================== */
#define SYSWDG_CR_INTE_Pos                (0UL)                     /*!< INTE (Bit 0)                                          */
#define SYSWDG_CR_INTE_Msk                (0x1UL)                   /*!< INTE (Bitfield-Mask: 0x01)                            */
#define SYSWDG_CR_RSTE_Pos                (1UL)                     /*!< RSTE (Bit 1)                                          */
#define SYSWDG_CR_RSTE_Msk                (0x2UL)                   /*!< RSTE (Bitfield-Mask: 0x01)                            */
#define SYSWDG_CR_DBGE_Pos                (2UL)                     /*!< DBGE (Bit 2)                                          */
#define SYSWDG_CR_DBGE_Msk                (0x4UL)                   /*!< DBGE (Bitfield-Mask: 0x01)                            */
/* =========================================================  FWDG  ========================================================== */
#define SYSWDG_FWDG_INTCLR_Pos            (0UL)                     /*!< INTCLR (Bit 0)                                        */
#define SYSWDG_FWDG_INTCLR_Msk            (0xffffffffUL)            /*!< INTCLR (Bitfield-Mask: 0xffffffff)                    */
/* ==========================================================  RIS  ========================================================== */
#define SYSWDG_RIS_RVU_Pos                (0UL)                     /*!< RVU (Bit 0)                                           */
#define SYSWDG_RIS_RVU_Msk                (0x1UL)                   /*!< RVU (Bitfield-Mask: 0x01)                             */
/* ==========================================================  EIS  ========================================================== */
#define SYSWDG_EIS_RVU_Pos                (0UL)                     /*!< RVU (Bit 0)                                           */
#define SYSWDG_EIS_RVU_Msk                (0x1UL)                   /*!< RVU (Bitfield-Mask: 0x01)                             */
/* ==========================================================  KR  =========================================================== */
#define SYSWDG_KR_LOCK_Pos                (0UL)                     /*!< LOCK (Bit 0)                                          */
#define SYSWDG_KR_LOCK_Msk                (0x1UL)                   /*!< LOCK (Bitfield-Mask: 0x01)                            */


/* =========================================================================================================================== */
/* ================                                           UART0                                           ================ */
/* =========================================================================================================================== */

/* ==========================================================  BR  =========================================================== */
#define UART0_BR_BR_Pos                   (0UL)                     /*!< BR (Bit 0)                                            */
#define UART0_BR_BR_Msk                   (0x1ffUL)                 /*!< BR (Bitfield-Mask: 0x1ff)                             */
/* ==========================================================  CR  =========================================================== */
#define UART0_CR_MODE_Pos                 (0UL)                     /*!< MODE (Bit 0)                                          */
#define UART0_CR_MODE_Msk                 (0x7UL)                   /*!< MODE (Bitfield-Mask: 0x07)                            */
#define UART0_CR_STOP_Pos                 (3UL)                     /*!< STOP (Bit 3)                                          */
#define UART0_CR_STOP_Msk                 (0x18UL)                  /*!< STOP (Bitfield-Mask: 0x03)                            */
#define UART0_CR_PBR_Pos                  (5UL)                     /*!< PBR (Bit 5)                                           */
#define UART0_CR_PBR_Msk                  (0x20UL)                  /*!< PBR (Bitfield-Mask: 0x01)                             */
#define UART0_CR_LPB_Pos                  (6UL)                     /*!< LPB (Bit 6)                                           */
#define UART0_CR_LPB_Msk                  (0x40UL)                  /*!< LPB (Bitfield-Mask: 0x01)                             */
#define UART0_CR_BRUN_Pos                 (7UL)                     /*!< BRUN (Bit 7)                                          */
#define UART0_CR_BRUN_Msk                 (0x80UL)                  /*!< BRUN (Bitfield-Mask: 0x01)                            */
#define UART0_CR_RXEN_Pos                 (8UL)                     /*!< RXEN (Bit 8)                                          */
#define UART0_CR_RXEN_Msk                 (0x100UL)                 /*!< RXEN (Bitfield-Mask: 0x01)                            */
#define UART0_CR_RXPOL_Pos                (16UL)                    /*!< RXPOL (Bit 16)                                        */
#define UART0_CR_RXPOL_Msk                (0x10000UL)               /*!< RXPOL (Bitfield-Mask: 0x01)                           */
#define UART0_CR_TXPOL_Pos                (17UL)                    /*!< TXPOL (Bit 17)                                        */
#define UART0_CR_TXPOL_Msk                (0x20000UL)               /*!< TXPOL (Bitfield-Mask: 0x01)                           */
#define UART0_CR_OWE_Pos                  (20UL)                    /*!< OWE (Bit 20)                                          */
#define UART0_CR_OWE_Msk                  (0x100000UL)              /*!< OWE (Bitfield-Mask: 0x01)                             */
#define UART0_CR_OWD_Pos                  (21UL)                    /*!< OWD (Bit 21)                                          */
#define UART0_CR_OWD_Msk                  (0x200000UL)              /*!< OWD (Bitfield-Mask: 0x01)                             */
/* ==========================================================  BRR  ========================================================== */
#define UART0_BRR_BRR_Pos                 (0UL)                     /*!< BRR (Bit 0)                                           */
#define UART0_BRR_BRR_Msk                 (0xffffUL)                /*!< BRR (Bitfield-Mask: 0xffff)                           */
#define UART0_BRR_SRR_Pos                 (16UL)                    /*!< SRR (Bit 16)                                          */
#define UART0_BRR_SRR_Msk                 (0x30000UL)               /*!< SRR (Bitfield-Mask: 0x03)                             */
/* ==========================================================  IER  ========================================================== */
#define UART0_IER_RXNEIE_Pos              (0UL)                     /*!< RXNEIE (Bit 0)                                        */
#define UART0_IER_RXNEIE_Msk              (0x1UL)                   /*!< RXNEIE (Bitfield-Mask: 0x01)                          */
#define UART0_IER_RXHFIE_Pos              (1UL)                     /*!< RXHFIE (Bit 1)                                        */
#define UART0_IER_RXHFIE_Msk              (0x2UL)                   /*!< RXHFIE (Bitfield-Mask: 0x01)                          */
#define UART0_IER_RXFIE_Pos               (2UL)                     /*!< RXFIE (Bit 2)                                         */
#define UART0_IER_RXFIE_Msk               (0x4UL)                   /*!< RXFIE (Bitfield-Mask: 0x01)                           */
#define UART0_IER_TONEIE_Pos              (3UL)                     /*!< TONEIE (Bit 3)                                        */
#define UART0_IER_TONEIE_Msk              (0x8UL)                   /*!< TONEIE (Bitfield-Mask: 0x01)                          */
#define UART0_IER_TOIDLEIE_Pos            (4UL)                     /*!< TOIDLEIE (Bit 4)                                      */
#define UART0_IER_TOIDLEIE_Msk            (0x10UL)                  /*!< TOIDLEIE (Bitfield-Mask: 0x01)                        */
#define UART0_IER_PERRIE_Pos              (5UL)                     /*!< PERRIE (Bit 5)                                        */
#define UART0_IER_PERRIE_Msk              (0x20UL)                  /*!< PERRIE (Bitfield-Mask: 0x01)                          */
#define UART0_IER_FERRIE_Pos              (6UL)                     /*!< FERRIE (Bit 6)                                        */
#define UART0_IER_FERRIE_Msk              (0x40UL)                  /*!< FERRIE (Bitfield-Mask: 0x01)                          */
#define UART0_IER_OVERRIE_Pos             (7UL)                     /*!< OVERRIE (Bit 7)                                       */
#define UART0_IER_OVERRIE_Msk             (0x80UL)                  /*!< OVERRIE (Bitfield-Mask: 0x01)                         */
#define UART0_IER_TXEIE_Pos               (8UL)                     /*!< TXEIE (Bit 8)                                         */
#define UART0_IER_TXEIE_Msk               (0x100UL)                 /*!< TXEIE (Bitfield-Mask: 0x01)                           */
#define UART0_IER_TXHEIE_Pos              (9UL)                     /*!< TXHEIE (Bit 9)                                        */
#define UART0_IER_TXHEIE_Msk              (0x200UL)                 /*!< TXHEIE (Bitfield-Mask: 0x01)                          */
#define UART0_IER_TXFIE_Pos               (10UL)                    /*!< TXFIE (Bit 10)                                        */
#define UART0_IER_TXFIE_Msk               (0x400UL)                 /*!< TXFIE (Bitfield-Mask: 0x01)                           */
#define UART0_IER_TXENDIE_Pos             (11UL)                    /*!< TXENDIE (Bit 11)                                      */
#define UART0_IER_TXENDIE_Msk             (0x800UL)                 /*!< TXENDIE (Bitfield-Mask: 0x01)                         */
/* ==========================================================  SR  =========================================================== */
#define UART0_SR_RXNE_Pos                 (0UL)                     /*!< RXNE (Bit 0)                                          */
#define UART0_SR_RXNE_Msk                 (0x1UL)                   /*!< RXNE (Bitfield-Mask: 0x01)                            */
#define UART0_SR_RXHF_Pos                 (1UL)                     /*!< RXHF (Bit 1)                                          */
#define UART0_SR_RXHF_Msk                 (0x2UL)                   /*!< RXHF (Bitfield-Mask: 0x01)                            */
#define UART0_SR_RXF_Pos                  (2UL)                     /*!< RXF (Bit 2)                                           */
#define UART0_SR_RXF_Msk                  (0x4UL)                   /*!< RXF (Bitfield-Mask: 0x01)                             */
#define UART0_SR_TONE_Pos                 (3UL)                     /*!< TONE (Bit 3)                                          */
#define UART0_SR_TONE_Msk                 (0x8UL)                   /*!< TONE (Bitfield-Mask: 0x01)                            */
#define UART0_SR_TOIDLE_Pos               (4UL)                     /*!< TOIDLE (Bit 4)                                        */
#define UART0_SR_TOIDLE_Msk               (0x10UL)                  /*!< TOIDLE (Bitfield-Mask: 0x01)                          */
#define UART0_SR_PERR_Pos                 (5UL)                     /*!< PERR (Bit 5)                                          */
#define UART0_SR_PERR_Msk                 (0x20UL)                  /*!< PERR (Bitfield-Mask: 0x01)                            */
#define UART0_SR_FERR_Pos                 (6UL)                     /*!< FERR (Bit 6)                                          */
#define UART0_SR_FERR_Msk                 (0x40UL)                  /*!< FERR (Bitfield-Mask: 0x01)                            */
#define UART0_SR_OVER_Pos                 (7UL)                     /*!< OVER (Bit 7)                                          */
#define UART0_SR_OVER_Msk                 (0x80UL)                  /*!< OVER (Bitfield-Mask: 0x01)                            */
#define UART0_SR_TXE_Pos                  (8UL)                     /*!< TXE (Bit 8)                                           */
#define UART0_SR_TXE_Msk                  (0x100UL)                 /*!< TXE (Bitfield-Mask: 0x01)                             */
#define UART0_SR_TXHE_Pos                 (9UL)                     /*!< TXHE (Bit 9)                                          */
#define UART0_SR_TXHE_Msk                 (0x200UL)                 /*!< TXHE (Bitfield-Mask: 0x01)                            */
#define UART0_SR_TXF_Pos                  (10UL)                    /*!< TXF (Bit 10)                                          */
#define UART0_SR_TXF_Msk                  (0x400UL)                 /*!< TXF (Bitfield-Mask: 0x01)                             */
#define UART0_SR_TXEND_Pos                (11UL)                    /*!< TXEND (Bit 11)                                        */
#define UART0_SR_TXEND_Msk                (0x800UL)                 /*!< TXEND (Bitfield-Mask: 0x01)                           */
/* =========================================================  SRCLR  ========================================================= */
#define UART0_SRCLR_PERR_Pos              (4UL)                     /*!< PERR (Bit 4)                                          */
#define UART0_SRCLR_PERR_Msk              (0x10UL)                  /*!< PERR (Bitfield-Mask: 0x01)                            */
#define UART0_SRCLR_FERR_Pos              (5UL)                     /*!< FERR (Bit 5)                                          */
#define UART0_SRCLR_FERR_Msk              (0x20UL)                  /*!< FERR (Bitfield-Mask: 0x01)                            */
#define UART0_SRCLR_OVER_Pos              (6UL)                     /*!< OVER (Bit 6)                                          */
#define UART0_SRCLR_OVER_Msk              (0x40UL)                  /*!< OVER (Bitfield-Mask: 0x01)                            */
/* ==========================================================  GTR  ========================================================== */
#define UART0_GTR_GTR_Pos                 (0UL)                     /*!< GTR (Bit 0)                                           */
#define UART0_GTR_GTR_Msk                 (0xffUL)                  /*!< GTR (Bitfield-Mask: 0xff)                             */
/* ==========================================================  TOR  ========================================================== */
#define UART0_TOR_TO_Pos                  (0UL)                     /*!< TO (Bit 0)                                            */
#define UART0_TOR_TO_Msk                  (0xffUL)                  /*!< TO (Bitfield-Mask: 0xff)                              */
/* ==========================================================  TRR  ========================================================== */
#define UART0_TRR_TXFR_Pos                (0UL)                     /*!< TXFR (Bit 0)                                          */
#define UART0_TRR_TXFR_Msk                (0xffffffffUL)            /*!< TXFR (Bitfield-Mask: 0xffffffff)                      */
/* ==========================================================  RRR  ========================================================== */
#define UART0_RRR_RRR_Pos                 (0UL)                     /*!< RRR (Bit 0)                                           */
#define UART0_RRR_RRR_Msk                 (0xffffffffUL)            /*!< RRR (Bitfield-Mask: 0xffffffff)                       */
/* ======================================================  ISO7816_CR  ======================================================= */
#define UART0_ISO7816_CR_EN_Pos           (0UL)                     /*!< EN (Bit 0)                                            */
#define UART0_ISO7816_CR_EN_Msk           (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define UART0_ISO7816_CR_DIR_Pos          (1UL)                     /*!< DIR (Bit 1)                                           */
#define UART0_ISO7816_CR_DIR_Msk          (0x2UL)                   /*!< DIR (Bitfield-Mask: 0x01)                             */
#define UART0_ISO7816_CR_CLKDIV_Pos       (4UL)                     /*!< CLKDIV (Bit 4)                                        */
#define UART0_ISO7816_CR_CLKDIV_Msk       (0x70UL)                  /*!< CLKDIV (Bitfield-Mask: 0x07)                          */
/* =========================================================  IR_CR  ========================================================= */
#define UART0_IR_CR_EN_Pos                (0UL)                     /*!< EN (Bit 0)                                            */
#define UART0_IR_CR_EN_Msk                (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define UART0_IR_CR_TXPOL_Pos             (1UL)                     /*!< TXPOL (Bit 1)                                         */
#define UART0_IR_CR_TXPOL_Msk             (0x2UL)                   /*!< TXPOL (Bitfield-Mask: 0x01)                           */
#define UART0_IR_CR_SPD_Pos               (4UL)                     /*!< SPD (Bit 4)                                           */
#define UART0_IR_CR_SPD_Msk               (0x30UL)                  /*!< SPD (Bitfield-Mask: 0x03)                             */
#define UART0_IR_CR_RST_Pos               (11UL)                    /*!< RST (Bit 11)                                          */
#define UART0_IR_CR_RST_Msk               (0x800UL)                 /*!< RST (Bitfield-Mask: 0x01)                             */
#define UART0_IR_CR_SSB_WIDTH_Pos         (16UL)                    /*!< SSB_WIDTH (Bit 16)                                    */
#define UART0_IR_CR_SSB_WIDTH_Msk         (0xf0000UL)               /*!< SSB_WIDTH (Bitfield-Mask: 0x0f)                       */
/* =======================================================  IRTX_PWMC  ======================================================= */
#define UART0_IRTX_PWMC_PWMC_Pos          (0UL)                     /*!< PWMC (Bit 0)                                          */
#define UART0_IRTX_PWMC_PWMC_Msk          (0xfffUL)                 /*!< PWMC (Bitfield-Mask: 0xfff)                           */


/* =========================================================================================================================== */
/* ================                                           SPI0                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  CR0  ========================================================== */
#define SPI0_CR0_DSS_Pos                  (0UL)                     /*!< DSS (Bit 0)                                           */
#define SPI0_CR0_DSS_Msk                  (0xfUL)                   /*!< DSS (Bitfield-Mask: 0x0f)                             */
#define SPI0_CR0_FRF_Pos                  (4UL)                     /*!< FRF (Bit 4)                                           */
#define SPI0_CR0_FRF_Msk                  (0x30UL)                  /*!< FRF (Bitfield-Mask: 0x03)                             */
#define SPI0_CR0_CPOL_Pos                 (6UL)                     /*!< CPOL (Bit 6)                                          */
#define SPI0_CR0_CPOL_Msk                 (0x40UL)                  /*!< CPOL (Bitfield-Mask: 0x01)                            */
#define SPI0_CR0_CPHA_Pos                 (7UL)                     /*!< CPHA (Bit 7)                                          */
#define SPI0_CR0_CPHA_Msk                 (0x80UL)                  /*!< CPHA (Bitfield-Mask: 0x01)                            */
#define SPI0_CR0_SCR_Pos                  (8UL)                     /*!< SCR (Bit 8)                                           */
#define SPI0_CR0_SCR_Msk                  (0xff00UL)                /*!< SCR (Bitfield-Mask: 0xff)                             */
/* ==========================================================  CR1  ========================================================== */
#define SPI0_CR1_LOOPBACK_Pos             (0UL)                     /*!< LOOPBACK (Bit 0)                                      */
#define SPI0_CR1_LOOPBACK_Msk             (0x1UL)                   /*!< LOOPBACK (Bitfield-Mask: 0x01)                        */
#define SPI0_CR1_SPIEN_Pos                (1UL)                     /*!< SPIEN (Bit 1)                                         */
#define SPI0_CR1_SPIEN_Msk                (0x2UL)                   /*!< SPIEN (Bitfield-Mask: 0x01)                           */
#define SPI0_CR1_MSTR_Pos                 (2UL)                     /*!< MSTR (Bit 2)                                          */
#define SPI0_CR1_MSTR_Msk                 (0x4UL)                   /*!< MSTR (Bitfield-Mask: 0x01)                            */
#define SPI0_CR1_SOD_Pos                  (3UL)                     /*!< SOD (Bit 3)                                           */
#define SPI0_CR1_SOD_Msk                  (0x8UL)                   /*!< SOD (Bitfield-Mask: 0x01)                             */
/* ==========================================================  DR  =========================================================== */
#define SPI0_DR_DATA_Pos                  (0UL)                     /*!< DATA (Bit 0)                                          */
#define SPI0_DR_DATA_Msk                  (0xffffUL)                /*!< DATA (Bitfield-Mask: 0xffff)                          */
/* ==========================================================  SR  =========================================================== */
#define SPI0_SR_TFE_Pos                   (0UL)                     /*!< TFE (Bit 0)                                           */
#define SPI0_SR_TFE_Msk                   (0x1UL)                   /*!< TFE (Bitfield-Mask: 0x01)                             */
#define SPI0_SR_TFNF_Pos                  (1UL)                     /*!< TFNF (Bit 1)                                          */
#define SPI0_SR_TFNF_Msk                  (0x2UL)                   /*!< TFNF (Bitfield-Mask: 0x01)                            */
#define SPI0_SR_RFNE_Pos                  (2UL)                     /*!< RFNE (Bit 2)                                          */
#define SPI0_SR_RFNE_Msk                  (0x4UL)                   /*!< RFNE (Bitfield-Mask: 0x01)                            */
#define SPI0_SR_RFF_Pos                   (3UL)                     /*!< RFF (Bit 3)                                           */
#define SPI0_SR_RFF_Msk                   (0x8UL)                   /*!< RFF (Bitfield-Mask: 0x01)                             */
#define SPI0_SR_BUSY_Pos                  (4UL)                     /*!< BUSY (Bit 4)                                          */
#define SPI0_SR_BUSY_Msk                  (0x10UL)                  /*!< BUSY (Bitfield-Mask: 0x01)                            */
/* =========================================================  CPSR  ========================================================== */
#define SPI0_CPSR_CPSDVSR_Pos             (0UL)                     /*!< CPSDVSR (Bit 0)                                       */
#define SPI0_CPSR_CPSDVSR_Msk             (0xffUL)                  /*!< CPSDVSR (Bitfield-Mask: 0xff)                         */
/* ==========================================================  IE  =========================================================== */
#define SPI0_IE_RFOF_Pos                  (0UL)                     /*!< RFOF (Bit 0)                                          */
#define SPI0_IE_RFOF_Msk                  (0x1UL)                   /*!< RFOF (Bitfield-Mask: 0x01)                            */
#define SPI0_IE_RFNEOT_Pos                (1UL)                     /*!< RFNEOT (Bit 1)                                        */
#define SPI0_IE_RFNEOT_Msk                (0x2UL)                   /*!< RFNEOT (Bitfield-Mask: 0x01)                          */
#define SPI0_IE_RFHF_Pos                  (2UL)                     /*!< RFHF (Bit 2)                                          */
#define SPI0_IE_RFHF_Msk                  (0x4UL)                   /*!< RFHF (Bitfield-Mask: 0x01)                            */
#define SPI0_IE_TFHF_Pos                  (3UL)                     /*!< TFHF (Bit 3)                                          */
#define SPI0_IE_TFHF_Msk                  (0x8UL)                   /*!< TFHF (Bitfield-Mask: 0x01)                            */
/* ==========================================================  RIS  ========================================================== */
#define SPI0_RIS_RFOVF_Pos                (0UL)                     /*!< RFOVF (Bit 0)                                         */
#define SPI0_RIS_RFOVF_Msk                (0x1UL)                   /*!< RFOVF (Bitfield-Mask: 0x01)                           */
#define SPI0_RIS_RFNETO_Pos               (1UL)                     /*!< RFNETO (Bit 1)                                        */
#define SPI0_RIS_RFNETO_Msk               (0x2UL)                   /*!< RFNETO (Bitfield-Mask: 0x01)                          */
#define SPI0_RIS_RFHF_Pos                 (2UL)                     /*!< RFHF (Bit 2)                                          */
#define SPI0_RIS_RFHF_Msk                 (0x4UL)                   /*!< RFHF (Bitfield-Mask: 0x01)                            */
#define SPI0_RIS_TFHF_Pos                 (3UL)                     /*!< TFHF (Bit 3)                                          */
#define SPI0_RIS_TFHF_Msk                 (0x8UL)                   /*!< TFHF (Bitfield-Mask: 0x01)                            */
/* ==========================================================  EIS  ========================================================== */
#define SPI0_EIS_RFOVF_Pos                (0UL)                     /*!< RFOVF (Bit 0)                                         */
#define SPI0_EIS_RFOVF_Msk                (0x1UL)                   /*!< RFOVF (Bitfield-Mask: 0x01)                           */
#define SPI0_EIS_RFNETO_Pos               (1UL)                     /*!< RFNETO (Bit 1)                                        */
#define SPI0_EIS_RFNETO_Msk               (0x2UL)                   /*!< RFNETO (Bitfield-Mask: 0x01)                          */
#define SPI0_EIS_RFHF_Pos                 (2UL)                     /*!< RFHF (Bit 2)                                          */
#define SPI0_EIS_RFHF_Msk                 (0x4UL)                   /*!< RFHF (Bitfield-Mask: 0x01)                            */
#define SPI0_EIS_TFHF_Pos                 (3UL)                     /*!< TFHF (Bit 3)                                          */
#define SPI0_EIS_TFHF_Msk                 (0x8UL)                   /*!< TFHF (Bitfield-Mask: 0x01)                            */
/* ==========================================================  ICR  ========================================================== */
#define SPI0_ICR_RFOVF_Pos                (0UL)                     /*!< RFOVF (Bit 0)                                         */
#define SPI0_ICR_RFOVF_Msk                (0x1UL)                   /*!< RFOVF (Bitfield-Mask: 0x01)                           */
#define SPI0_ICR_RFNETO_Pos               (1UL)                     /*!< RFNETO (Bit 1)                                        */
#define SPI0_ICR_RFNETO_Msk               (0x2UL)                   /*!< RFNETO (Bitfield-Mask: 0x01)                          */
/* =========================================================  CSCR  ========================================================== */
#define SPI0_CSCR_SWSEL_Pos               (2UL)                     /*!< SWSEL (Bit 2)                                         */
#define SPI0_CSCR_SWSEL_Msk               (0x4UL)                   /*!< SWSEL (Bitfield-Mask: 0x01)                           */
#define SPI0_CSCR_SWCS_Pos                (3UL)                     /*!< SWCS (Bit 3)                                          */
#define SPI0_CSCR_SWCS_Msk                (0x8UL)                   /*!< SWCS (Bitfield-Mask: 0x01)                            */


/* =========================================================================================================================== */
/* ================                                           IIC0                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  CSR  ========================================================== */
#define IIC0_CSR_CR0_Pos                  (0UL)                     /*!< CR0 (Bit 0)                                           */
#define IIC0_CSR_CR0_Msk                  (0x1UL)                   /*!< CR0 (Bitfield-Mask: 0x01)                             */
#define IIC0_CSR_CR1_Pos                  (1UL)                     /*!< CR1 (Bit 1)                                           */
#define IIC0_CSR_CR1_Msk                  (0x2UL)                   /*!< CR1 (Bitfield-Mask: 0x01)                             */
#define IIC0_CSR_ACK_Pos                  (2UL)                     /*!< ACK (Bit 2)                                           */
#define IIC0_CSR_ACK_Msk                  (0x4UL)                   /*!< ACK (Bitfield-Mask: 0x01)                             */
#define IIC0_CSR_IS_Pos                   (3UL)                     /*!< IS (Bit 3)                                            */
#define IIC0_CSR_IS_Msk                   (0x8UL)                   /*!< IS (Bitfield-Mask: 0x01)                              */
#define IIC0_CSR_STOP_Pos                 (4UL)                     /*!< STOP (Bit 4)                                          */
#define IIC0_CSR_STOP_Msk                 (0x10UL)                  /*!< STOP (Bitfield-Mask: 0x01)                            */
#define IIC0_CSR_START_Pos                (5UL)                     /*!< START (Bit 5)                                         */
#define IIC0_CSR_START_Msk                (0x20UL)                  /*!< START (Bitfield-Mask: 0x01)                           */
#define IIC0_CSR_EN_Pos                   (6UL)                     /*!< EN (Bit 6)                                            */
#define IIC0_CSR_EN_Msk                   (0x40UL)                  /*!< EN (Bitfield-Mask: 0x01)                              */
#define IIC0_CSR_CR2_Pos                  (7UL)                     /*!< CR2 (Bit 7)                                           */
#define IIC0_CSR_CR2_Msk                  (0x80UL)                  /*!< CR2 (Bitfield-Mask: 0x01)                             */
/* ==========================================================  SR  =========================================================== */
#define IIC0_SR_STAT_Pos                  (3UL)                     /*!< STAT (Bit 3)                                          */
#define IIC0_SR_STAT_Msk                  (0xf8UL)                  /*!< STAT (Bitfield-Mask: 0x1f)                            */
/* ==========================================================  DR  =========================================================== */
#define IIC0_DR_DATA_Pos                  (0UL)                     /*!< DATA (Bit 0)                                          */
#define IIC0_DR_DATA_Msk                  (0xffUL)                  /*!< DATA (Bitfield-Mask: 0xff)                            */
/* ==========================================================  OAR  ========================================================== */
#define IIC0_OAR_ADDR_Pos                 (0UL)                     /*!< ADDR (Bit 0)                                          */
#define IIC0_OAR_ADDR_Msk                 (0xffUL)                  /*!< ADDR (Bitfield-Mask: 0xff)                            */
/* ==========================================================  CCR  ========================================================== */
#define IIC0_CCR_CR0_Pos                  (0UL)                     /*!< CR0 (Bit 0)                                           */
#define IIC0_CCR_CR0_Msk                  (0x1UL)                   /*!< CR0 (Bitfield-Mask: 0x01)                             */
#define IIC0_CCR_CR1_Pos                  (1UL)                     /*!< CR1 (Bit 1)                                           */
#define IIC0_CCR_CR1_Msk                  (0x2UL)                   /*!< CR1 (Bitfield-Mask: 0x01)                             */
#define IIC0_CCR_ACK_Pos                  (2UL)                     /*!< ACK (Bit 2)                                           */
#define IIC0_CCR_ACK_Msk                  (0x4UL)                   /*!< ACK (Bitfield-Mask: 0x01)                             */
#define IIC0_CCR_IS_Pos                   (3UL)                     /*!< IS (Bit 3)                                            */
#define IIC0_CCR_IS_Msk                   (0x8UL)                   /*!< IS (Bitfield-Mask: 0x01)                              */
#define IIC0_CCR_STOP_Pos                 (4UL)                     /*!< STOP (Bit 4)                                          */
#define IIC0_CCR_STOP_Msk                 (0x10UL)                  /*!< STOP (Bitfield-Mask: 0x01)                            */
#define IIC0_CCR_START_Pos                (5UL)                     /*!< START (Bit 5)                                         */
#define IIC0_CCR_START_Msk                (0x20UL)                  /*!< START (Bitfield-Mask: 0x01)                           */
#define IIC0_CCR_EN_Pos                   (6UL)                     /*!< EN (Bit 6)                                            */
#define IIC0_CCR_EN_Msk                   (0x40UL)                  /*!< EN (Bitfield-Mask: 0x01)                              */
#define IIC0_CCR_CR2_Pos                  (7UL)                     /*!< CR2 (Bit 7)                                           */
#define IIC0_CCR_CR2_Msk                  (0x80UL)                  /*!< CR2 (Bitfield-Mask: 0x01)                             */


/* =========================================================================================================================== */
/* ================                                            ADC                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  CR  =========================================================== */
#define ADC_CR_ADEN_Pos                   (0UL)                     /*!< ADEN (Bit 0)                                          */
#define ADC_CR_ADEN_Msk                   (0x1UL)                   /*!< ADEN (Bitfield-Mask: 0x01)                            */
#define ADC_CR_CONT_Pos                   (1UL)                     /*!< CONT (Bit 1)                                          */
#define ADC_CR_CONT_Msk                   (0x2UL)                   /*!< CONT (Bitfield-Mask: 0x01)                            */
#define ADC_CR_SOCSEL_Pos                 (2UL)                     /*!< SOCSEL (Bit 2)                                        */
#define ADC_CR_SOCSEL_Msk                 (0xcUL)                   /*!< SOCSEL (Bitfield-Mask: 0x03)                          */
#define ADC_CR_TMRSEL_Pos                 (4UL)                     /*!< TMRSEL (Bit 4)                                        */
#define ADC_CR_TMRSEL_Msk                 (0x30UL)                  /*!< TMRSEL (Bitfield-Mask: 0x03)                          */
#define ADC_CR_ADCAL_Pos                  (6UL)                     /*!< ADCAL (Bit 6)                                         */
#define ADC_CR_ADCAL_Msk                  (0x40UL)                  /*!< ADCAL (Bitfield-Mask: 0x01)                           */
#define ADC_CR_HSSMP_Pos                  (7UL)                     /*!< HSSMP (Bit 7)                                         */
#define ADC_CR_HSSMP_Msk                  (0x80UL)                  /*!< HSSMP (Bitfield-Mask: 0x01)                           */
#define ADC_CR_CLK_DIV_SEL_Pos            (8UL)                     /*!< CLK_DIV_SEL (Bit 8)                                   */
#define ADC_CR_CLK_DIV_SEL_Msk            (0x300UL)                 /*!< CLK_DIV_SEL (Bitfield-Mask: 0x03)                     */
#define ADC_CR_EOCIE_Pos                  (10UL)                    /*!< EOCIE (Bit 10)                                        */
#define ADC_CR_EOCIE_Msk                  (0x400UL)                 /*!< EOCIE (Bitfield-Mask: 0x01)                           */
#define ADC_CR_ALIGN_Pos                  (11UL)                    /*!< ALIGN (Bit 11)                                        */
#define ADC_CR_ALIGN_Msk                  (0x800UL)                 /*!< ALIGN (Bitfield-Mask: 0x01)                           */
#define ADC_CR_ADSTART_Pos                (12UL)                    /*!< ADSTART (Bit 12)                                      */
#define ADC_CR_ADSTART_Msk                (0x1000UL)                /*!< ADSTART (Bitfield-Mask: 0x01)                         */
#define ADC_CR_CHSEL_Pos                  (16UL)                    /*!< CHSEL (Bit 16)                                        */
#define ADC_CR_CHSEL_Msk                  (0xf0000UL)               /*!< CHSEL (Bitfield-Mask: 0x0f)                           */
#define ADC_CR_SDIF_Pos                   (20UL)                    /*!< SDIF (Bit 20)                                         */
#define ADC_CR_SDIF_Msk                   (0x100000UL)              /*!< SDIF (Bitfield-Mask: 0x01)                            */
/* =========================================================  TRSTN  ========================================================= */
#define ADC_TRSTN_TRSTN_Pos               (0UL)                     /*!< TRSTN (Bit 0)                                         */
#define ADC_TRSTN_TRSTN_Msk               (0x3fUL)                  /*!< TRSTN (Bitfield-Mask: 0x3f)                           */
/* ==========================================================  SR  =========================================================== */
#define ADC_SR_RDY_Pos                    (0UL)                     /*!< RDY (Bit 0)                                           */
#define ADC_SR_RDY_Msk                    (0x1UL)                   /*!< RDY (Bitfield-Mask: 0x01)                             */
#define ADC_SR_DONE_Pos                   (1UL)                     /*!< DONE (Bit 1)                                          */
#define ADC_SR_DONE_Msk                   (0x2UL)                   /*!< DONE (Bitfield-Mask: 0x01)                            */
/* ==========================================================  DR  =========================================================== */
#define ADC_DR_DATA_Pos                   (0UL)                     /*!< DATA (Bit 0)                                          */
#define ADC_DR_DATA_Msk                   (0xffffUL)                /*!< DATA (Bitfield-Mask: 0xffff)                          */


/* =========================================================================================================================== */
/* ================                                            LED                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  CR  =========================================================== */
#define LED_CR_EN_Pos                     (0UL)                     /*!< EN (Bit 0)                                            */
#define LED_CR_EN_Msk                     (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define LED_CR_COMSEL_Pos                 (1UL)                     /*!< COMSEL (Bit 1)                                        */
#define LED_CR_COMSEL_Msk                 (0x6UL)                   /*!< COMSEL (Bitfield-Mask: 0x03)                          */
#define LED_CR_IE_Pos                     (3UL)                     /*!< IE (Bit 3)                                            */
#define LED_CR_IE_Msk                     (0x8UL)                   /*!< IE (Bitfield-Mask: 0x01)                              */
/* =========================================================  CPSR  ========================================================== */
#define LED_CPSR_PR_Pos                   (0UL)                     /*!< PR (Bit 0)                                            */
#define LED_CPSR_PR_Msk                   (0x7fUL)                  /*!< PR (Bitfield-Mask: 0x7f)                              */
/* ==========================================================  TR  =========================================================== */
#define LED_TR_DISPLAYT_Pos               (0UL)                     /*!< DISPLAYT (Bit 0)                                      */
#define LED_TR_DISPLAYT_Msk               (0xffUL)                  /*!< DISPLAYT (Bitfield-Mask: 0xff)                        */
#define LED_TR_TURNT_Pos                  (8UL)                     /*!< TURNT (Bit 8)                                         */
#define LED_TR_TURNT_Msk                  (0xff00UL)                /*!< TURNT (Bitfield-Mask: 0xff)                           */
/* ==========================================================  DR0  ========================================================== */
#define LED_DR0_DATA_Pos                  (0UL)                     /*!< DATA (Bit 0)                                          */
#define LED_DR0_DATA_Msk                  (0xffUL)                  /*!< DATA (Bitfield-Mask: 0xff)                            */
/* ==========================================================  DR1  ========================================================== */
#define LED_DR1_DATA_Pos                  (0UL)                     /*!< DATA (Bit 0)                                          */
#define LED_DR1_DATA_Msk                  (0xffUL)                  /*!< DATA (Bitfield-Mask: 0xff)                            */
/* ==========================================================  DR2  ========================================================== */
#define LED_DR2_DATA_Pos                  (0UL)                     /*!< DATA (Bit 0)                                          */
#define LED_DR2_DATA_Msk                  (0xffUL)                  /*!< DATA (Bitfield-Mask: 0xff)                            */
/* ==========================================================  DR3  ========================================================== */
#define LED_DR3_DATA_Pos                  (0UL)                     /*!< DATA (Bit 0)                                          */
#define LED_DR3_DATA_Msk                  (0xffUL)                  /*!< DATA (Bitfield-Mask: 0xff)                            */
/* ==========================================================  EIS  ========================================================== */
#define LED_EIS_DISPLAYEND_Pos            (0UL)                     /*!< DISPLAYEND (Bit 0)                                    */
#define LED_EIS_DISPLAYEND_Msk            (0x1UL)                   /*!< DISPLAYEND (Bitfield-Mask: 0x01)                      */


/* =========================================================================================================================== */
/* ================                                           COMP0                                           ================ */
/* =========================================================================================================================== */

/* ==========================================================  CR1  ========================================================== */
#define COMP0_CR1_EN_Pos                  (0UL)                     /*!< EN (Bit 0)                                            */
#define COMP0_CR1_EN_Msk                  (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define COMP0_CR1_OUTPUTPOS_Pos           (1UL)                     /*!< OUTPUTPOS (Bit 1)                                     */
#define COMP0_CR1_OUTPUTPOS_Msk           (0x2UL)                   /*!< OUTPUTPOS (Bitfield-Mask: 0x01)                       */
#define COMP0_CR1_REFSEL_Pos              (2UL)                     /*!< REFSEL (Bit 2)                                        */
#define COMP0_CR1_REFSEL_Msk              (0xcUL)                   /*!< REFSEL (Bitfield-Mask: 0x03)                          */
#define COMP0_CR1_FS_Pos                  (4UL)                     /*!< FS (Bit 4)                                            */
#define COMP0_CR1_FS_Msk                  (0x70UL)                  /*!< FS (Bitfield-Mask: 0x07)                              */
#define COMP0_CR1_HSMODE_Pos              (7UL)                     /*!< HSMODE (Bit 7)                                        */
#define COMP0_CR1_HSMODE_Msk              (0x80UL)                  /*!< HSMODE (Bitfield-Mask: 0x01)                          */
#define COMP0_CR1_OUTPUTPOL_Pos           (8UL)                     /*!< OUTPUTPOL (Bit 8)                                     */
#define COMP0_CR1_OUTPUTPOL_Msk           (0x100UL)                 /*!< OUTPUTPOL (Bitfield-Mask: 0x01)                       */
/* ==========================================================  CR2  ========================================================== */
#define COMP0_CR2_OPAEN_Pos               (0UL)                     /*!< OPAEN (Bit 0)                                         */
#define COMP0_CR2_OPAEN_Msk               (0x1UL)                   /*!< OPAEN (Bitfield-Mask: 0x01)                           */
#define COMP0_CR2_AMP_AOFM_Pos            (1UL)                     /*!< AMP_AOFM (Bit 1)                                      */
#define COMP0_CR2_AMP_AOFM_Msk            (0x2UL)                   /*!< AMP_AOFM (Bitfield-Mask: 0x01)                        */
#define COMP0_CR2_AMP_ARS_Pos             (2UL)                     /*!< AMP_ARS (Bit 2)                                       */
#define COMP0_CR2_AMP_ARS_Msk             (0x4UL)                   /*!< AMP_ARS (Bitfield-Mask: 0x01)                         */
#define COMP0_CR2_AMP_AOF_Pos             (4UL)                     /*!< AMP_AOF (Bit 4)                                       */
#define COMP0_CR2_AMP_AOF_Msk             (0x1f0UL)                 /*!< AMP_AOF (Bitfield-Mask: 0x1f)                         */
#define COMP0_CR2_AMP_AOF_CODE_Pos        (16UL)                    /*!< AMP_AOF_CODE (Bit 16)                                 */
#define COMP0_CR2_AMP_AOF_CODE_Msk        (0xffff0000UL)            /*!< AMP_AOF_CODE (Bitfield-Mask: 0xffff)                  */
/* ==========================================================  DAC  ========================================================== */
#define COMP0_DAC_DATA_Pos                (0UL)                     /*!< DATA (Bit 0)                                          */
#define COMP0_DAC_DATA_Msk                (0x1fUL)                  /*!< DATA (Bitfield-Mask: 0x1f)                            */
/* ==========================================================  IE  =========================================================== */
#define COMP0_IE_FALL_Pos                 (0UL)                     /*!< FALL (Bit 0)                                          */
#define COMP0_IE_FALL_Msk                 (0x1UL)                   /*!< FALL (Bitfield-Mask: 0x01)                            */
#define COMP0_IE_RISE_Pos                 (1UL)                     /*!< RISE (Bit 1)                                          */
#define COMP0_IE_RISE_Msk                 (0x2UL)                   /*!< RISE (Bitfield-Mask: 0x01)                            */
#define COMP0_IE_FALL_WAKE_Pos            (2UL)                     /*!< FALL_WAKE (Bit 2)                                     */
#define COMP0_IE_FALL_WAKE_Msk            (0x4UL)                   /*!< FALL_WAKE (Bitfield-Mask: 0x01)                       */
#define COMP0_IE_RISE_WAKE_Pos            (3UL)                     /*!< RISE_WAKE (Bit 3)                                     */
#define COMP0_IE_RISE_WAKE_Msk            (0x8UL)                   /*!< RISE_WAKE (Bitfield-Mask: 0x01)                       */
/* ==========================================================  EIS  ========================================================== */
#define COMP0_EIS_FIF_Pos                 (0UL)                     /*!< FIF (Bit 0)                                           */
#define COMP0_EIS_FIF_Msk                 (0x1UL)                   /*!< FIF (Bitfield-Mask: 0x01)                             */
#define COMP0_EIS_RIF_Pos                 (1UL)                     /*!< RIF (Bit 1)                                           */
#define COMP0_EIS_RIF_Msk                 (0x2UL)                   /*!< RIF (Bitfield-Mask: 0x01)                             */
#define COMP0_EIS_FIF_WAKE_Pos            (2UL)                     /*!< FIF_WAKE (Bit 2)                                      */
#define COMP0_EIS_FIF_WAKE_Msk            (0x4UL)                   /*!< FIF_WAKE (Bitfield-Mask: 0x01)                        */
#define COMP0_EIS_RIF_WAKE_Pos            (3UL)                     /*!< RIF_WAKE (Bit 3)                                      */
#define COMP0_EIS_RIF_WAKE_Msk            (0x8UL)                   /*!< RIF_WAKE (Bitfield-Mask: 0x01)                        */
/* =======================================================  INITDELAY  ======================================================= */
#define COMP0_INITDELAY_INIT_DELAY_Pos    (0UL)                     /*!< INIT_DELAY (Bit 0)                                    */
#define COMP0_INITDELAY_INIT_DELAY_Msk    (0x3ffUL)                 /*!< INIT_DELAY (Bitfield-Mask: 0x3ff)                     */


/* =========================================================================================================================== */
/* ================                                            CRC                                            ================ */
/* =========================================================================================================================== */

/* ==========================================================  CR  =========================================================== */
#define CRC_CR_EN_Pos                     (0UL)                     /*!< EN (Bit 0)                                            */
#define CRC_CR_EN_Msk                     (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define CRC_CR_INIT_Pos                   (1UL)                     /*!< INIT (Bit 1)                                          */
#define CRC_CR_INIT_Msk                   (0x2UL)                   /*!< INIT (Bitfield-Mask: 0x01)                            */
#define CRC_CR_DINWIDTH_Pos               (2UL)                     /*!< DINWIDTH (Bit 2)                                      */
#define CRC_CR_DINWIDTH_Msk               (0x4UL)                   /*!< DINWIDTH (Bitfield-Mask: 0x01)                        */
#define CRC_CR_INPUT_BITREV_Pos           (3UL)                     /*!< INPUT_BITREV (Bit 3)                                  */
#define CRC_CR_INPUT_BITREV_Msk           (0x8UL)                   /*!< INPUT_BITREV (Bitfield-Mask: 0x01)                    */
#define CRC_CR_INPUT_BYTEREV_Pos          (4UL)                     /*!< INPUT_BYTEREV (Bit 4)                                 */
#define CRC_CR_INPUT_BYTEREV_Msk          (0x10UL)                  /*!< INPUT_BYTEREV (Bitfield-Mask: 0x01)                   */
#define CRC_CR_OUTPUT_BITREV_Pos          (5UL)                     /*!< OUTPUT_BITREV (Bit 5)                                 */
#define CRC_CR_OUTPUT_BITREV_Msk          (0x20UL)                  /*!< OUTPUT_BITREV (Bitfield-Mask: 0x01)                   */
/* ==========================================================  SDR  ========================================================== */
#define CRC_SDR_CRC_SEED_Pos              (0UL)                     /*!< CRC_SEED (Bit 0)                                      */
#define CRC_SDR_CRC_SEED_Msk              (0xffffUL)                /*!< CRC_SEED (Bitfield-Mask: 0xffff)                      */
/* =========================================================  POLY  ========================================================== */
#define CRC_POLY_POLY_Pos                 (0UL)                     /*!< POLY (Bit 0)                                          */
#define CRC_POLY_POLY_Msk                 (0xffffUL)                /*!< POLY (Bitfield-Mask: 0xffff)                          */
/* ==========================================================  DIN  ========================================================== */
#define CRC_DIN_DIN_Pos                   (0UL)                     /*!< DIN (Bit 0)                                           */
#define CRC_DIN_DIN_Msk                   (0xffffUL)                /*!< DIN (Bitfield-Mask: 0xffff)                           */
/* =========================================================  DOUT  ========================================================== */
#define CRC_DOUT_DOUT_Pos                 (0UL)                     /*!< DOUT (Bit 0)                                          */
#define CRC_DOUT_DOUT_Msk                 (0xffffUL)                /*!< DOUT (Bitfield-Mask: 0xffff)                          */


/* =========================================================================================================================== */
/* ================                                        ANALOG_MISC                                        ================ */
/* =========================================================================================================================== */

/* ======================================================  VDDLVDCTRL  ======================================================= */
#define ANALOG_MISC_VDDLVDCTRL_EN_Pos     (0UL)                     /*!< EN (Bit 0)                                            */
#define ANALOG_MISC_VDDLVDCTRL_EN_Msk     (0x1UL)                   /*!< EN (Bitfield-Mask: 0x01)                              */
#define ANALOG_MISC_VDDLVDCTRL_LVD_TRIP_Pos (1UL)                   /*!< LVD_TRIP (Bit 1)                                      */
#define ANALOG_MISC_VDDLVDCTRL_LVD_TRIP_Msk (0xeUL)                 /*!< LVD_TRIP (Bitfield-Mask: 0x07)                        */
/* ======================================================  LDOLVDCTRL  ======================================================= */
#define ANALOG_MISC_LDOLVDCTRL_TRIP_Pos   (0UL)                     /*!< TRIP (Bit 0)                                          */
#define ANALOG_MISC_LDOLVDCTRL_TRIP_Msk   (0x7UL)                   /*!< TRIP (Bitfield-Mask: 0x07)                            */
/* =======================================================  EOSCCON1  ======================================================== */
#define ANALOG_MISC_EOSCCON1_EOSCEN_Pos   (0UL)                     /*!< EOSCEN (Bit 0)                                        */
#define ANALOG_MISC_EOSCCON1_EOSCEN_Msk   (0x1UL)                   /*!< EOSCEN (Bitfield-Mask: 0x01)                          */
#define ANALOG_MISC_EOSCCON1_AUTOAMP_Pos  (1UL)                     /*!< AUTOAMP (Bit 1)                                       */
#define ANALOG_MISC_EOSCCON1_AUTOAMP_Msk  (0x2UL)                   /*!< AUTOAMP (Bitfield-Mask: 0x01)                         */
#define ANALOG_MISC_EOSCCON1_EXCLKEN_Pos  (2UL)                     /*!< EXCLKEN (Bit 2)                                       */
#define ANALOG_MISC_EOSCCON1_EXCLKEN_Msk  (0x4UL)                   /*!< EXCLKEN (Bitfield-Mask: 0x01)                         */
#define ANALOG_MISC_EOSCCON1_EOSCDIVEN_Pos (3UL)                    /*!< EOSCDIVEN (Bit 3)                                     */
#define ANALOG_MISC_EOSCCON1_EOSCDIVEN_Msk (0x8UL)                  /*!< EOSCDIVEN (Bitfield-Mask: 0x01)                       */
#define ANALOG_MISC_EOSCCON1_EOSCRANG_Pos (4UL)                     /*!< EOSCRANG (Bit 4)                                      */
#define ANALOG_MISC_EOSCCON1_EOSCRANG_Msk (0x10UL)                  /*!< EOSCRANG (Bitfield-Mask: 0x01)                        */
#define ANALOG_MISC_EOSCCON1_EOSCDEGLITCH_Pos (8UL)                 /*!< EOSCDEGLITCH (Bit 8)                                  */
#define ANALOG_MISC_EOSCCON1_EOSCDEGLITCH_Msk (0x300UL)             /*!< EOSCDEGLITCH (Bitfield-Mask: 0x03)                    */
#define ANALOG_MISC_EOSCCON1_BYPASSEN_Pos (10UL)                    /*!< BYPASSEN (Bit 10)                                     */
#define ANALOG_MISC_EOSCCON1_BYPASSEN_Msk (0x400UL)                 /*!< BYPASSEN (Bitfield-Mask: 0x01)                        */
/* =======================================================  EOSCCON2  ======================================================== */
#define ANALOG_MISC_EOSCCON2_EOSCDRIVE_Pos (0UL)                    /*!< EOSCDRIVE (Bit 0)                                     */
#define ANALOG_MISC_EOSCCON2_EOSCDRIVE_Msk (0x7UL)                  /*!< EOSCDRIVE (Bitfield-Mask: 0x07)                       */
#define ANALOG_MISC_EOSCCON2_EOSCLOADCAP_Pos (4UL)                  /*!< EOSCLOADCAP (Bit 4)                                   */
#define ANALOG_MISC_EOSCCON2_EOSCLOADCAP_Msk (0x70UL)               /*!< EOSCLOADCAP (Bitfield-Mask: 0x07)                     */
#define ANALOG_MISC_EOSCCON2_EOSCFBRES_Pos (8UL)                    /*!< EOSCFBRES (Bit 8)                                     */
#define ANALOG_MISC_EOSCCON2_EOSCFBRES_Msk (0x300UL)                /*!< EOSCFBRES (Bitfield-Mask: 0x03)                       */
/* ======================================================  IOSC24MCON  ======================================================= */
#define ANALOG_MISC_IOSC24MCON_IOSCEN_Pos (0UL)                     /*!< IOSCEN (Bit 0)                                        */
#define ANALOG_MISC_IOSC24MCON_IOSCEN_Msk (0x1UL)                   /*!< IOSCEN (Bitfield-Mask: 0x01)                          */
#define ANALOG_MISC_IOSC24MCON_IOSC_24M_TRIM_USER_ON_Pos (8UL)      /*!< IOSC_24M_TRIM_USER_ON (Bit 8)                         */
#define ANALOG_MISC_IOSC24MCON_IOSC_24M_TRIM_USER_ON_Msk (0xff00UL) /*!< IOSC_24M_TRIM_USER_ON (Bitfield-Mask: 0xff)           */
#define ANALOG_MISC_IOSC24MCON_IOSC_24M_TRIM_Pos (16UL)             /*!< IOSC_24M_TRIM (Bit 16)                                */
#define ANALOG_MISC_IOSC24MCON_IOSC_24M_TRIM_Msk (0xff0000UL)       /*!< IOSC_24M_TRIM (Bitfield-Mask: 0xff)                   */
/* ======================================================  IOSC32KCON  ======================================================= */
#define ANALOG_MISC_IOSC32KCON_IOSCEN_Pos (0UL)                     /*!< IOSCEN (Bit 0)                                        */
#define ANALOG_MISC_IOSC32KCON_IOSCEN_Msk (0x1UL)                   /*!< IOSCEN (Bitfield-Mask: 0x01)                          */
#define ANALOG_MISC_IOSC32KCON_IOSC_32K_TRIM_Pos (4UL)              /*!< IOSC_32K_TRIM (Bit 4)                                 */
#define ANALOG_MISC_IOSC32KCON_IOSC_32K_TRIM_Msk (0xf0UL)           /*!< IOSC_32K_TRIM (Bitfield-Mask: 0x0f)                   */
#define ANALOG_MISC_IOSC32KCON_IOSC_32K_TRIM_USER_ON_Pos (8UL)      /*!< IOSC_32K_TRIM_USER_ON (Bit 8)                         */
#define ANALOG_MISC_IOSC32KCON_IOSC_32K_TRIM_USER_ON_Msk (0xff00UL) /*!< IOSC_32K_TRIM_USER_ON (Bitfield-Mask: 0xff)           */
/* =========================================================  FDCON  ========================================================= */
#define ANALOG_MISC_FDCON_FDEN_Pos        (0UL)                     /*!< FDEN (Bit 0)                                          */
#define ANALOG_MISC_FDCON_FDEN_Msk        (0x1UL)                   /*!< FDEN (Bitfield-Mask: 0x01)                            */
/* ======================================================  DEGLITCHCON  ====================================================== */
#define ANALOG_MISC_DEGLITCHCON_COMP0_Pos (0UL)                     /*!< COMP0 (Bit 0)                                         */
#define ANALOG_MISC_DEGLITCHCON_COMP0_Msk (0x3UL)                   /*!< COMP0 (Bitfield-Mask: 0x03)                           */
#define ANALOG_MISC_DEGLITCHCON_COMP1_Pos (2UL)                     /*!< COMP1 (Bit 2)                                         */
#define ANALOG_MISC_DEGLITCHCON_COMP1_Msk (0xcUL)                   /*!< COMP1 (Bitfield-Mask: 0x03)                           */
#define ANALOG_MISC_DEGLITCHCON_PA_Pos    (4UL)                     /*!< PA (Bit 4)                                            */
#define ANALOG_MISC_DEGLITCHCON_PA_Msk    (0x30UL)                  /*!< PA (Bitfield-Mask: 0x03)                              */
#define ANALOG_MISC_DEGLITCHCON_PB_Pos    (6UL)                     /*!< PB (Bit 6)                                            */
#define ANALOG_MISC_DEGLITCHCON_PB_Msk    (0xc0UL)                  /*!< PB (Bitfield-Mask: 0x03)                              */
#define ANALOG_MISC_DEGLITCHCON_PF_Pos    (8UL)                     /*!< PF (Bit 8)                                            */
#define ANALOG_MISC_DEGLITCHCON_PF_Msk    (0x300UL)                 /*!< PF (Bitfield-Mask: 0x03)                              */
/* =======================================================  HSINKCON  ======================================================== */
#define ANALOG_MISC_HSINKCON_COM0_Pos     (0UL)                     /*!< COM0 (Bit 0)                                          */
#define ANALOG_MISC_HSINKCON_COM0_Msk     (0x1UL)                   /*!< COM0 (Bitfield-Mask: 0x01)                            */
#define ANALOG_MISC_HSINKCON_COM1_Pos     (1UL)                     /*!< COM1 (Bit 1)                                          */
#define ANALOG_MISC_HSINKCON_COM1_Msk     (0x2UL)                   /*!< COM1 (Bitfield-Mask: 0x01)                            */
#define ANALOG_MISC_HSINKCON_COM2_Pos     (2UL)                     /*!< COM2 (Bit 2)                                          */
#define ANALOG_MISC_HSINKCON_COM2_Msk     (0x4UL)                   /*!< COM2 (Bitfield-Mask: 0x01)                            */
#define ANALOG_MISC_HSINKCON_COM3_Pos     (3UL)                     /*!< COM3 (Bit 3)                                          */
#define ANALOG_MISC_HSINKCON_COM3_Msk     (0x8UL)                   /*!< COM3 (Bitfield-Mask: 0x01)                            */
/* =======================================================  MCODIVCON  ======================================================= */
#define ANALOG_MISC_MCODIVCON_DIV_Pos     (0UL)                     /*!< DIV (Bit 0)                                           */
#define ANALOG_MISC_MCODIVCON_DIV_Msk     (0x7UL)                   /*!< DIV (Bitfield-Mask: 0x07)                             */


/* =========================================================================================================================== */
/* ================                                           FLASH                                           ================ */
/* =========================================================================================================================== */

/* ==========================================================  ACR  ========================================================== */
#define FLASH_ACR_START_Pos               (0UL)                     /*!< START (Bit 0)                                         */
#define FLASH_ACR_START_Msk               (0x1UL)                   /*!< START (Bitfield-Mask: 0x01)                           */
#define FLASH_ACR_CMD_Pos                 (1UL)                     /*!< CMD (Bit 1)                                           */
#define FLASH_ACR_CMD_Msk                 (0xeUL)                   /*!< CMD (Bitfield-Mask: 0x07)                             */
#define FLASH_ACR_LATENCY_Pos             (5UL)                     /*!< LATENCY (Bit 5)                                       */
#define FLASH_ACR_LATENCY_Msk             (0xe0UL)                  /*!< LATENCY (Bitfield-Mask: 0x07)                         */
#define FLASH_ACR_MODE_Pos                (8UL)                     /*!< MODE (Bit 8)                                          */
#define FLASH_ACR_MODE_Msk                (0x100UL)                 /*!< MODE (Bitfield-Mask: 0x01)                            */
#define FLASH_ACR_DPSTB_Pos               (11UL)                    /*!< DPSTB (Bit 11)                                        */
#define FLASH_ACR_DPSTB_Msk               (0x800UL)                 /*!< DPSTB (Bitfield-Mask: 0x01)                           */
#define FLASH_ACR_AINC_Pos                (13UL)                    /*!< AINC (Bit 13)                                         */
#define FLASH_ACR_AINC_Msk                (0x2000UL)                /*!< AINC (Bitfield-Mask: 0x01)                            */
#define FLASH_ACR_KEYCODE_Pos             (16UL)                    /*!< KEYCODE (Bit 16)                                      */
#define FLASH_ACR_KEYCODE_Msk             (0xffff0000UL)            /*!< KEYCODE (Bitfield-Mask: 0xffff)                       */
/* ==========================================================  ISR  ========================================================== */
#define FLASH_ISR_WREND_Pos               (0UL)                     /*!< WREND (Bit 0)                                         */
#define FLASH_ISR_WREND_Msk               (0x1UL)                   /*!< WREND (Bitfield-Mask: 0x01)                           */
#define FLASH_ISR_EREND_Pos               (1UL)                     /*!< EREND (Bit 1)                                         */
#define FLASH_ISR_EREND_Msk               (0x2UL)                   /*!< EREND (Bitfield-Mask: 0x01)                           */
#define FLASH_ISR_PROTECT_EREND_Pos       (2UL)                     /*!< PROTECT_EREND (Bit 2)                                 */
#define FLASH_ISR_PROTECT_EREND_Msk       (0x4UL)                   /*!< PROTECT_EREND (Bitfield-Mask: 0x01)                   */
#define FLASH_ISR_CMD_ERR_Pos             (4UL)                     /*!< CMD_ERR (Bit 4)                                       */
#define FLASH_ISR_CMD_ERR_Msk             (0x10UL)                  /*!< CMD_ERR (Bitfield-Mask: 0x01)                         */
#define FLASH_ISR_ADDR_ERR_Pos            (6UL)                     /*!< ADDR_ERR (Bit 6)                                      */
#define FLASH_ISR_ADDR_ERR_Msk            (0x40UL)                  /*!< ADDR_ERR (Bitfield-Mask: 0x01)                        */
/* ==========================================================  IER  ========================================================== */
#define FLASH_IER_WRENDIE_Pos             (0UL)                     /*!< WRENDIE (Bit 0)                                       */
#define FLASH_IER_WRENDIE_Msk             (0x1UL)                   /*!< WRENDIE (Bitfield-Mask: 0x01)                         */
#define FLASH_IER_ERENDIE_Pos             (1UL)                     /*!< ERENDIE (Bit 1)                                       */
#define FLASH_IER_ERENDIE_Msk             (0x2UL)                   /*!< ERENDIE (Bitfield-Mask: 0x01)                         */
#define FLASH_IER_PRERENDIE_Pos           (2UL)                     /*!< PRERENDIE (Bit 2)                                     */
#define FLASH_IER_PRERENDIE_Msk           (0x4UL)                   /*!< PRERENDIE (Bitfield-Mask: 0x01)                       */
#define FLASH_IER_CMDERIE_Pos             (4UL)                     /*!< CMDERIE (Bit 4)                                       */
#define FLASH_IER_CMDERIE_Msk             (0x10UL)                  /*!< CMDERIE (Bitfield-Mask: 0x01)                         */
#define FLASH_IER_ADERIE_Pos              (6UL)                     /*!< ADERIE (Bit 6)                                        */
#define FLASH_IER_ADERIE_Msk              (0x40UL)                  /*!< ADERIE (Bitfield-Mask: 0x01)                          */
/* ==========================================================  AR  =========================================================== */
#define FLASH_AR_BADDR_Pos                (0UL)                     /*!< BADDR (Bit 0)                                         */
#define FLASH_AR_BADDR_Msk                (0x3UL)                   /*!< BADDR (Bitfield-Mask: 0x03)                           */
#define FLASH_AR_FAR0_Pos                 (2UL)                     /*!< FAR0 (Bit 2)                                          */
#define FLASH_AR_FAR0_Msk                 (0x4UL)                   /*!< FAR0 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR1_Pos                 (3UL)                     /*!< FAR1 (Bit 3)                                          */
#define FLASH_AR_FAR1_Msk                 (0x8UL)                   /*!< FAR1 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR2_Pos                 (4UL)                     /*!< FAR2 (Bit 4)                                          */
#define FLASH_AR_FAR2_Msk                 (0x10UL)                  /*!< FAR2 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR3_Pos                 (5UL)                     /*!< FAR3 (Bit 5)                                          */
#define FLASH_AR_FAR3_Msk                 (0x20UL)                  /*!< FAR3 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR4_Pos                 (6UL)                     /*!< FAR4 (Bit 6)                                          */
#define FLASH_AR_FAR4_Msk                 (0x40UL)                  /*!< FAR4 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR5_Pos                 (7UL)                     /*!< FAR5 (Bit 7)                                          */
#define FLASH_AR_FAR5_Msk                 (0x80UL)                  /*!< FAR5 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR6_Pos                 (8UL)                     /*!< FAR6 (Bit 8)                                          */
#define FLASH_AR_FAR6_Msk                 (0x100UL)                 /*!< FAR6 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR7_Pos                 (9UL)                     /*!< FAR7 (Bit 9)                                          */
#define FLASH_AR_FAR7_Msk                 (0x200UL)                 /*!< FAR7 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR8_Pos                 (10UL)                    /*!< FAR8 (Bit 10)                                         */
#define FLASH_AR_FAR8_Msk                 (0x400UL)                 /*!< FAR8 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR9_Pos                 (11UL)                    /*!< FAR9 (Bit 11)                                         */
#define FLASH_AR_FAR9_Msk                 (0x800UL)                 /*!< FAR9 (Bitfield-Mask: 0x01)                            */
#define FLASH_AR_FAR10_Pos                (12UL)                    /*!< FAR10 (Bit 12)                                        */
#define FLASH_AR_FAR10_Msk                (0x1000UL)                /*!< FAR10 (Bitfield-Mask: 0x01)                           */
#define FLASH_AR_FAR11_Pos                (13UL)                    /*!< FAR11 (Bit 13)                                        */
#define FLASH_AR_FAR11_Msk                (0x2000UL)                /*!< FAR11 (Bitfield-Mask: 0x01)                           */
#define FLASH_AR_FAR12_Pos                (14UL)                    /*!< FAR12 (Bit 14)                                        */
#define FLASH_AR_FAR12_Msk                (0x4000UL)                /*!< FAR12 (Bitfield-Mask: 0x01)                           */
#define FLASH_AR_FAR13_Pos                (15UL)                    /*!< FAR13 (Bit 15)                                        */
#define FLASH_AR_FAR13_Msk                (0x8000UL)                /*!< FAR13 (Bitfield-Mask: 0x01)                           */
/* ==========================================================  DR  =========================================================== */
#define FLASH_DR_FDR_Pos                  (0UL)                     /*!< FDR (Bit 0)                                           */
#define FLASH_DR_FDR_Msk                  (0xffffffffUL)            /*!< FDR (Bitfield-Mask: 0xffffffff)                       */
/* ==========================================================  DIV  ========================================================== */
#define FLASH_DIV_FLDIV_Pos               (0UL)                     /*!< FLDIV (Bit 0)                                         */
#define FLASH_DIV_FLDIV_Msk               (0xffUL)                  /*!< FLDIV (Bitfield-Mask: 0xff)                           */

/** @} */ /* End of group PosMask_peripherals */


#ifdef __cplusplus
}
#endif

#endif /* PT32X031_H */


/** @} */ /* End of group PT32X031 */

/** @} */ /* End of group  */
